/** 
 *******************************************************************************
 * @file    bsp_config_adc.c
 * @brief   This file provides all the functions prototypes for ADC Driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp_config_adc.h"

#if defined(__BSP_CONFIG_ADC_H)

/**
 *  @addtogroup BSP BSP
 *  @{
 */


/** 
 *  @addtogroup BSP_CONFIG_ADC BSP_CONFIG_ADC
 *  @{
 */


/*------------------------------------------------------------------------------*/
/*  Exported Macro                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Exported_macro BSP_CONFIG_ADC Exported Macro
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Exported_macro BSP_CONFIG_ADC Exported Macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_config BSP_CONFIG_ADC Private Config
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief   Thermistors AD Value Table.
 * @details  V   = AVCC*(TH1/TH1+R60)
 * @        AD   = V/(AVCC/0xFFF)
 * @               AVCC :5(v)
 * @               R60  :10(k-ohm)
 * @               TH1  :Refer thermistors temperature characteristics.
 * @        Resolution  :12 bit(=0xFFF).

*/
/*----------------------------------*/
static const int32_t NCP15XV103J03RC[][4] = 
{
    /*----------------------------------------*/
    /* TEMP. | AD-low   | AD-center| AD-high  */
    /* deg.C | -        | -        | -        */
    /*----------------------------------------*/
    { -40, 0xF72, 0xF86, 0xF96 },
    { -39, 0xF69, 0xF7E, 0xF8F },
    { -38, 0xF60, 0xF75, 0xF88 },
    { -37, 0xF56, 0xF6C, 0xF80 },
    { -36, 0xF4B, 0xF63, 0xF77 },
    { -35, 0xF40, 0xF59, 0xF6E },
    { -34, 0xF35, 0xF4E, 0xF65 },
    { -33, 0xF28, 0xF43, 0xF5B },
    { -32, 0xF1C, 0xF38, 0xF50 },
    { -31, 0xF0E, 0xF2C, 0xF45 },
    { -30, 0xF00, 0xF1F, 0xF3A },
    { -29, 0xEF2, 0xF12, 0xF2D },
    { -28, 0xEE2, 0xF04, 0xF21 },
    { -27, 0xED2, 0xEF5, 0xF13 },
    { -26, 0xEC2, 0xEE5, 0xF05 },
    { -25, 0xEB0, 0xED5, 0xEF6 },
    { -24, 0xE9E, 0xEC4, 0xEE6 },
    { -23, 0xE8B, 0xEB3, 0xED6 },
    { -22, 0xE77, 0xEA1, 0xEC5 },
    { -21, 0xE63, 0xE8E, 0xEB3 },
    { -20, 0xE4E, 0xE7A, 0xEA1 },
    { -19, 0xE38, 0xE65, 0xE8D },
    { -18, 0xE21, 0xE4F, 0xE79 },
    { -17, 0xE09, 0xE39, 0xE64 },
    { -16, 0xDF0, 0xE22, 0xE4E },
    { -15, 0xDD7, 0xE0A, 0xE37 },
    { -14, 0xDBD, 0xDF1, 0xE1F },
    { -13, 0xDA2, 0xDD7, 0xE07 },
    { -12, 0xD86, 0xDBC, 0xDED },
    { -11, 0xD69, 0xDA1, 0xDD3 },
    { -10, 0xD4C, 0xD84, 0xDB8 },
    {  -9, 0xD2D, 0xD67, 0xD9C },
    {  -8, 0xD0E, 0xD48, 0xD7E },
    {  -7, 0xCED, 0xD29, 0xD60 },
    {  -6, 0xCCC, 0xD09, 0xD41 },
    {  -5, 0xCAA, 0xCE8, 0xD21 },
    {  -4, 0xC88, 0xCC6, 0xD00 },
    {  -3, 0xC64, 0xCA4, 0xCDE },
    {  -2, 0xC40, 0xC80, 0xCBC },
    {  -1, 0xC1B, 0xC5C, 0xC98 },
    {   0, 0xBF6, 0xC37, 0xC74 },
    {   1, 0xBCF, 0xC11, 0xC4F },
    {   2, 0xBA8, 0xBEB, 0xC28 },
    {   3, 0xB81, 0xBC3, 0xC02 },
    {   4, 0xB59, 0xB9C, 0xBDA },
    {   5, 0xB30, 0xB73, 0xBB2 },
    {   6, 0xB07, 0xB4A, 0xB89 },
    {   7, 0xADD, 0xB20, 0xB5F },
    {   8, 0xAB3, 0xAF6, 0xB35 },
    {   9, 0xA88, 0xACB, 0xB0A },
    {  10, 0xA5D, 0xAA0, 0xADE },
    {  11, 0xA32, 0xA74, 0xAB2 },
    {  12, 0xA07, 0xA48, 0xA86 },
    {  13, 0x9DB, 0xA1C, 0xA59 },
    {  14, 0x9AF, 0x9EF, 0xA2C },
    {  15, 0x983, 0x9C2, 0x9FE },
    {  16, 0x956, 0x995, 0x9D0 },
    {  17, 0x92A, 0x968, 0x9A3 },
    {  18, 0x8FE, 0x93B, 0x974 },
    {  19, 0x8D1, 0x90D, 0x946 },
    {  20, 0x8A5, 0x8E0, 0x918 },
    {  21, 0x879, 0x8B3, 0x8E9 },
    {  22, 0x84D, 0x885, 0x8BB },
    {  23, 0x821, 0x858, 0x88D },
    {  24, 0x7F6, 0x82C, 0x85F },
    {  25, 0x7CA, 0x7FF, 0x831 },
    {  26, 0x79D, 0x7D3, 0x806 },
    {  27, 0x770, 0x7A7, 0x7DB },
    {  28, 0x743, 0x77B, 0x7B1 },
    {  29, 0x716, 0x750, 0x786 },
    {  30, 0x6EA, 0x725, 0x75D },
    {  31, 0x6BF, 0x6FA, 0x733 },
    {  32, 0x694, 0x6D0, 0x70A },
    {  33, 0x66A, 0x6A7, 0x6E1 },
    {  34, 0x640, 0x67E, 0x6B9 },
    {  35, 0x617, 0x655, 0x692 },
    {  36, 0x5EE, 0x62D, 0x66A },
    {  37, 0x5C7, 0x606, 0x644 },
    {  38, 0x5A0, 0x5DF, 0x61E },
    {  39, 0x579, 0x5B9, 0x5F8 },
    {  40, 0x553, 0x594, 0x5D3 },
    {  41, 0x52E, 0x56F, 0x5AF },
    {  42, 0x50A, 0x54B, 0x58B },
    {  43, 0x4E7, 0x528, 0x568 },
    {  44, 0x4C4, 0x505, 0x545 },
    {  45, 0x4A2, 0x4E3, 0x524 },
    {  46, 0x481, 0x4C2, 0x502 },
    {  47, 0x460, 0x4A1, 0x4E2 },
    {  48, 0x440, 0x481, 0x4C2 },
    {  49, 0x421, 0x462, 0x4A2 },
    {  50, 0x403, 0x443, 0x484 },
    {  51, 0x3E6, 0x425, 0x466 },
    {  52, 0x3C9, 0x408, 0x448 },
    {  53, 0x3AD, 0x3EC, 0x42C },
    {  54, 0x392, 0x3D0, 0x410 },
    {  55, 0x377, 0x3B5, 0x3F4 },
    {  56, 0x35D, 0x39B, 0x3DA },
    {  57, 0x344, 0x381, 0x3BF },
    {  58, 0x32C, 0x368, 0x3A6 },
    {  59, 0x314, 0x350, 0x38D },
    {  60, 0x2FD, 0x338, 0x375 },
    {  61, 0x2E6, 0x321, 0x35D },
    {  62, 0x2D0, 0x30A, 0x346 },
    {  63, 0x2BB, 0x2F4, 0x330 },
    {  64, 0x2A6, 0x2DF, 0x31A },
    {  65, 0x292, 0x2CA, 0x304 },
    {  66, 0x27F, 0x2B6, 0x2F0 },
    {  67, 0x26C, 0x2A2, 0x2DB },
    {  68, 0x25A, 0x28F, 0x2C7 },
    {  69, 0x248, 0x27D, 0x2B4 },
    {  70, 0x236, 0x26B, 0x2A1 },
    {  71, 0x226, 0x259, 0x28F },
    {  72, 0x216, 0x248, 0x27E },
    {  73, 0x206, 0x238, 0x26C },
    {  74, 0x1F7, 0x228, 0x25C },
    {  75, 0x1E8, 0x218, 0x24C },
    {  76, 0x1DA, 0x209, 0x23C },
    {  77, 0x1CC, 0x1FB, 0x22C },
    {  78, 0x1BE, 0x1ED, 0x21E },
    {  79, 0x1B1, 0x1DF, 0x20F },
    {  80, 0x1A5, 0x1D1, 0x201 },
    {  81, 0x199, 0x1C4, 0x1F3 },
    {  82, 0x18D, 0x1B8, 0x1E6 },
    {  83, 0x181, 0x1AC, 0x1D9 },
    {  84, 0x176, 0x1A0, 0x1CC },
    {  85, 0x16B, 0x194, 0x1C0 },
    {  86, 0x161, 0x189, 0x1B4 },
    {  87, 0x157, 0x17E, 0x1A9 },
    {  88, 0x14D, 0x174, 0x19E },
    {  89, 0x143, 0x169, 0x193 },
    {  90, 0x13A, 0x160, 0x188 },
    {  91, 0x131, 0x156, 0x17E },
    {  92, 0x129, 0x14D, 0x174 },
    {  93, 0x120, 0x144, 0x16A },
    {  94, 0x118, 0x13B, 0x161 },
    {  95, 0x110, 0x132, 0x158 },
    {  96, 0x109, 0x12A, 0x14F },
    {  97, 0x101, 0x122, 0x146 },
    {  98,  0xFA, 0x11A, 0x13E },
    {  99,  0xF3, 0x113, 0x136 },
    { 100,  0xED, 0x10C, 0x12E },
    { 101,  0xE6, 0x104, 0x126 },
    { 102,  0xE0,  0xFE, 0x11E },
    { 103,  0xDA,  0xF7, 0x117 },
    { 104,  0xD4,  0xF0, 0x110 },
    { 105,  0xCE,  0xEA, 0x109 },
    { 106,  0xC8,  0xE4, 0x103 },
    { 107,  0xC3,  0xDE,  0xFC },
    { 108,  0xBE,  0xD8,  0xF6 },
    { 109,  0xB9,  0xD3,  0xF0 },
    { 110,  0xB4,  0xCE,  0xEA },
    { 111,  0xAF,  0xC8,  0xE4 },
    { 112,  0xAA,  0xC3,  0xDF },
    { 113,  0xA6,  0xBE,  0xD9 },
    { 114,  0xA2,  0xB9,  0xD4 },
    { 115,  0x9D,  0xB5,  0xCF },
    { 116,  0x99,  0xB0,  0xCA },
    { 117,  0x95,  0xAC,  0xC5 },
    { 118,  0x92,  0xA8,  0xC0 },
    { 119,  0x8E,  0xA3,  0xBC },
    { 120,  0x8A,  0x9F,  0xB7 },
    { 121,  0x87,  0x9B,  0xB3 },
    { 122,  0x83,  0x98,  0xAF },
    { 123,  0x80,  0x94,  0xAB },
    { 124,  0x7D,  0x90,  0xA7 },
    { 125,  0x7A,  0x8D,  0xA3 }
};

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_config */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_define BSP_CONFIG_ADC Private Define
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_enum BSP_CONFIG_ADC Private Enum
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_typedef BSP_CONFIG_ADC Private Typedef
 *  @{
 */
/**
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Exported_functions BSP_CONFIG_ADC Exported Functions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  GPIO_ADC_C_Config
  * @param  -
  * @return -
  * @retval -
  * @note   -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void GPIO_ADC_C_Config(void)
{
    /* Select not output mode on BSP_VR_1 port */
    BSP_VR_1_CR  = GPIO_DISABLE;
    /* Select not open-drain on BSP_VR_1 port */
    BSP_VR_1_OD  = GPIO_DISABLE;
    /* Select not input mode on BSP_VR_1 port */
    BSP_VR_1_IE  = GPIO_DISABLE;
    /* Select pull-up disable on BSP_VR_1 port */
    BSP_VR_1_PUP = GPIO_DISABLE;
    /* Select pull-down disable on BSP_VR_1 port */
    BSP_VR_1_PDN = GPIO_DISABLE;
}

/*--------------------------------------------------*/
/** 
  * @brief  bsp_get_thermistors_degC
  * @param  uint32_t data
  * @return int32t celsius
  * @note   -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
int32_t bsp_get_thermistors_degC(uint32_t adc_value)
{

    uint32_t i;
    uint32_t num = (sizeof(NCP15XV103J03RC) / sizeof(NCP15XV103J03RC[0]));
    int32_t celsius = 30;

    for (i = 0; i < num; i++)
    {
        /* Compare to AD-low & AD-hgh. */
        if (((uint32_t)NCP15XV103J03RC[i][1] <= adc_value) && (adc_value <= (uint32_t)NCP15XV103J03RC[i][3]))
        {
            celsius = NCP15XV103J03RC[i][0];
            break;
        }
    }

    return celsius;
}

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Exported_functions */

/**
 *  @}
 */ /* End of group BSP_CONFIG_ADC */

/**
 *  @} 
 */ /* End of group BSP */
#endif  /* defined(__BSP_CONFIG_ADC_H) */

#ifdef __cplusplus
}
#endif /* __cplusplus */

