/** 
 *******************************************************************************
 * @file    bsp_config_adc.h
 * @brief   This file provides all the functions prototypes for ADC Driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __BSP_CONFIG_ADC_H
#define __BSP_CONFIG_ADC_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp.h"

/**
 *  @addtogroup BSP BSP
 *  @{
 */


/** 
 *  @addtogroup BSP_CONFIG_ADC BSP_CONFIG_ADC
 *  @{
 */


/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_macro BSP_CONFIG_ADC Private Macro
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_config BSP_CONFIG_ADC Private Config
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_config */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_define BSP_CONFIG_ADC Private Define
 *  @{
 */
/* Sample : ADC_SoftwareTrigger */
#define BSP_VR_1_CR             TSB_PJ_CR_PJ0C      /*!< output enable register */
#define BSP_VR_1_OD             TSB_PJ_OD_PJ0OD     /*!< open-drain enable register */
#define BSP_VR_1_IE             TSB_PJ_IE_PJ0IE     /*!< input enable register */
#define BSP_VR_1_PUP            TSB_PJ_PUP_PJ0UP    /*!< pull-up enable register */
#define BSP_VR_1_PDN            TSB_PJ_PDN_PJ0DN    /*!< pull-down enable register */


/* Self Diagnosis : AIN Sample */
/* same as ADC_SoftwareTrigger  */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_enum BSP_CONFIG_ADC Private Enum
 *  @{
 */
/*----------------------------------*/
/** 
 * @brief  ADC.
*/
/*----------------------------------*/
typedef enum
{
    BSP_THERMISTORS_1 = 0,  /*!< BSP_ADC_1 : none */
    BSP_VR_1 = 1,           /*!< BSP_ADC_2 : VR1  */
    BSP_VR_2 = 2,           /*!< BSP_ADC_3 : none */
    /*>>> be set bottom */
    BSP_ADC_MAX             /*!< max */
    /*<<< be set bottom */
} BSP_ADC_PORT;

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Private_typedef BSP_CONFIG_ADC Private Typedef
 *  @{
 */
/**
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_ADC_Exported_functions
 *  @{
 */
void GPIO_ADC_C_Config(void);
int32_t bsp_get_thermistors_degC(uint32_t);

/** 
 *  @}
 */ /* End of group BSP_CONFIG_ADC_Exported_functions */

/**
 *  @}
 */ /* End of group BSP_CONFIG_ADC */

/**
 *  @} 
 */ /* End of group BSP */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __BSP_CONFIG_ADC_H */

