/** 
 *******************************************************************************
 * @file    bsp_config_led.h
 * @brief   This file provides all the functions prototypes for LED Driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __BSP_CONFIG_LED_H
#define __BSP_CONFIG_LED_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp.h"

/**
 *  @addtogroup BSP BSP
 *  @{
 */


/** 
 *  @addtogroup BSP_CONFIG_LED BSP_CONFIG_LED
 *  @{
 */


/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Private_macro BSP_CONFIG_LED Private Macro
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_LED_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Private_config BSP_CONFIG_LED Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_LED_Private_config */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Private_define BSP_CONFIG_LED Private Define
 *  @{
 */
/** 
 *  @addtogroup  LED LED OFF/ON
 *  @brief     LED OFF/ON
 *  @{
 */
#define LED_OFF             0       /*!< LED OFF                 */
#define LED_ON              1       /*!< LED ON                  */
/** 
 *  @}
 */ /* End of group GPIO_EN */

#define BSP_LED_1_DATA      TSB_PB_DATA_PB0     /*!< data register */
#define BSP_LED_2_DATA      TSB_PB_DATA_PB2     /*!< data register */
#define BSP_LED_3_DATA      TSB_PB_DATA_PB4     /*!< data register */
#define BSP_LED_4_DATA      TSB_PV_DATA_PV0     /*!< data register */

#define BSP_LED_1_CR        TSB_PB_CR_PB0C      /*!< output enable register */
#define BSP_LED_2_CR        TSB_PB_CR_PB2C      /*!< output enable register */
#define BSP_LED_3_CR        TSB_PB_CR_PB4C      /*!< output enable register */
#define BSP_LED_4_CR        TSB_PV_CR_PV0C      /*!< output enable register */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_LED_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Private_emum BSP_CONFIG_LED Private Emum
 *  @{
 */

/*----------------------------------*/
/** 
 * @brief  PORT LED.
*/
/*----------------------------------*/
typedef enum
{
    BSP_LED_1 = 0,          /*!< PORT LED1 */
    BSP_LED_2,              /*!< PORT LED2 */
    BSP_LED_3,              /*!< PORT LED3 */
    BSP_LED_4,              /*!< PORT LED4 */
    /*>>> be set bottom */
    BSP_LED_MAX             /*!< max */
    /*<<< be set bottom */
} BSP_LED_PORT;

/** 
 *  @}
 */ /* End of group BSP_CONFIG_LED_Private_emum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Private_typedef BSP_CONFIG_LED Private Typedef
 *  @{
 */
/**
 *  @}
 */ /* End of group BSP_CONFIG_LED_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_LED_Exported_functions BSP_CONFIG_LED Exported Functions
 *  @{
 */
void GPIO_LED_Config(void);

void GPIO_LED1_ON(void);
void GPIO_LED2_ON(void);
void GPIO_LED3_ON(void);
void GPIO_LED4_ON(void);

void GPIO_LED1_OFF(void);
void GPIO_LED2_OFF(void);
void GPIO_LED3_OFF(void);
void GPIO_LED4_OFF(void);

void GPIO_LED1_FLIP(void);
void GPIO_LED2_FLIP(void);
void GPIO_LED3_FLIP(void);
void GPIO_LED4_FLIP(void);


/* Self-Diagnosis */
bool Get_param_DIO_LED2_CR(void);
void Set_param_DIO_LED2_SSW1(uint32_t);

/** 
 *  @}
 */ /* End of group BSP_CONFIG_LED_Exported_functions */

/**
 *  @}
 */ /* End of group BSP_CONFIG_LED */

/**
 *  @} 
 */ /* End of group BSP */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __BSP_CONFIG_LED_H */

