/** 
 *******************************************************************************
 * @file    bsp_config_sw.h
 * @brief   This file provides all the functions prototypes for SW Driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __BSP_CONFIG_SW_H
#define __BSP_CONFIG_SW_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp.h"

/**
 *  @addtogroup BSP BSP
 *  @{
 */


/** 
 *  @addtogroup BSP_CONFIG_SW BSP_CONFIG_SW
 *  @{
 */


/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Private_macro BSP_CONFIG_SW Private Macro
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_SW_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Private_config BSP_CONFIG_SW Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_SW_Private_config */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Private_define BSP_CONFIG_SW Private Define
 *  @{
 */

#define BSP_PSW_1_DATA          TSB_PD_DATA_PD1     /*!< data register */
#define BSP_PSW_1_IE            TSB_PD_IE_PD1IE     /*!< input enable register */

#define BSP_PSW_2_DATA          TSB_PD_DATA_PD0     /*!< data register */
#define BSP_PSW_2_IE            TSB_PD_IE_PD0IE     /*!< input enable register */

#define BSP_PSW_5_DATA          BSP_SSW_1_DATA      /*!< use BSP_SSW_1 */
#define BSP_PSW_5_IE            BSP_SSW_1_IE        /*!< use BSP_SSW_1 */

#define BSP_SSW_1_DATA          TSB_PG_DATA_PG3     /*!< data register */
#define BSP_SSW_1_IE            TSB_PG_IE_PG3IE     /*!< input enable register */

#define BSP_SSW_2_DATA          TSB_PG_DATA_PG4     /*!< data register */
#define BSP_SSW_2_IE            TSB_PG_IE_PG4IE     /*!< input enable register */

#define BSP_SSW_3_DATA          TSB_PG_DATA_PG5     /*!< data register */
#define BSP_SSW_3_IE            TSB_PG_IE_PG5IE     /*!< input enable register */

#define BSP_SSW_4_DATA          TSB_PG_DATA_PG6     /*!< data register */
#define BSP_SSW_4_IE            TSB_PG_IE_PG6IE     /*!< input enable register */


/* Extint */
#define BSP_PSW_EXTINT_DATA     BSP_SSW_1_DATA      /*!< use BSP_SSW_1 */
#define BSP_PSW_EXTINT_IE       BSP_SSW_1_IE        /*!< use BSP_SSW_1 */

#define BSP_PSW_ON              0x00000000          /*!< use BSP_PSW_ON  */
#define BSP_PSW_OFF             0x00000001          /*!< use BSP_PSW_OFF */

/* Self-Diagnosis DIO_Sample */
#define BSP_DIAGNOSIS_DIGITALIO_DATA    TSB_PJ_DATA_PJ3     /*!< data register */
#define BSP_DIAGNOSIS_DIGITALIO_IE      TSB_PJ_IE_PJ3IE     /*!< input enable register */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_SW_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Private_emum BSP_CONFIG_SW Private Emum
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_SW_Private_emum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Private_typedef BSP_CONFIG_SW Private Typedef
 *  @{
 */
/**
 *  @}
 */ /* End of group BSP_CONFIG_SW_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_SW_Exported_functions BSP_CONFIG_SW Exported Functions
 *  @{
 */
void GPIO_SW_Config(void);
void GPIO_SW_EXTINT_Config(void);
bool Get_PSW1_input(void);
bool Get_PSW2_input(void);


/* Self-Diagnosis BSP_DIAGNOSIS_DIGITALIO */
void DIO_DIGITALIO_Config_IE(void);
void DIO_DIGITALIO_High(void);
bool Get_param_DIGITALIO_output(void);
bool Get_param_DIGITALIO_input(void);
void DIO_DIGITALIO_Low(void);
bool Get_param_DIO_SSW1_IE(void);
bool Get_param_DIO_SSW1_input(void);

/** 
 *  @}
 */ /* End of group BSP_CONFIG_SW_Exported_functions */

/**
 *  @}
 */ /* End of group BSP_CONFIG_SW */

/**
 *  @} 
 */ /* End of group BSP */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __BSP_CONFIG_SW_H */

