/** 
 *******************************************************************************
 * @file    bsp_config_uart.h
 * @brief   This file provides all the functions prototypes for UART Driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __BSP_CONFIG_UART_H
#define __BSP_CONFIG_UART_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp.h"

/**
 *  @addtogroup BSP BSP
 *  @{
 */


/** 
 *  @addtogroup BSP_CONFIG_UART BSP_CONFIG_UART
 *  @{
 */


/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Private_macro BSP_CONFIG_UART Private Macro
 *  @{
 */

/** 
 *  @}
 */ /* End of group BSP_CONFIG_UART_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Private_config BSP_CONFIG_UART Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_UART_Private_config */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Private_define BSP_CONFIG_UART Private Define
 *  @{
 */

#define BSP_UART1_TXD_DATA      TSB_PC_DATA_PC0
#define BSP_UART1_TXD_FR        TSB_PC_FR1_PC0F1    /*!< function register */
#define BSP_UART1_TXD_CR        TSB_PC_CR_PC0C      /*!< output enable register */

#define BSP_UART1_RXD_FR        TSB_PC_FR1_PC1F1    /*!< funtion register */
#define BSP_UART1_RXD_IE        TSB_PC_IE_PC1IE     /*!< input enable register */



/* Self-Diagnosis */
/* UART ch.0 */
#define UT0TXD_DATA             TSB_PC_DATA_PC0
#define UT0TXD_FR1              TSB_PC_FR1_PC0F1
#define UT0TXD_FR2              TSB_PC_FR2_PC0F2
#define UT0TXD_FR4              TSB_PC_FR4_PC0F4
#define UT0TXD_FR5              TSB_PC_FR5_PC0F5
#define UT0TXD_FR6              TSB_PC_FR6_PC0F6
#define UT0TXD_IE               TSB_PC_IE_PC0IE
#define UT0TXD_CR               TSB_PC_CR_PC0C

#define UT0RXD_DATA             TSB_PC_DATA_PC1
#define UT0RXD_FR1              TSB_PC_FR1_PC1F1
#define UT0RXD_FR2              TSB_PC_FR2_PC1F2
#define UT0RXD_FR4              TSB_PC_FR4_PC1F4
#define UT0RXD_FR5              TSB_PC_FR5_PC1F5
#define UT0RXD_FR6              TSB_PC_FR6_PC1F6
#define UT0RXD_IE               TSB_PC_IE_PC1IE
#define UT0RXD_CR               TSB_PC_CR_PC1C

/* UART ch.1 */
#define UT1TXD_DATA             TSB_PC_DATA_PC4
#define UT1TXD_FR1              TSB_PC_FR1_PC4F1
#define UT1TXD_FR2              TSB_PC_FR2_PC4F2
#define UT1TXD_FR3              TSB_PC_FR3_PC4F3
#define UT1TXD_IE               TSB_PC_IE_PC4IE
#define UT1TXD_CR               TSB_PC_CR_PC4C

#define UT1RXD_DATA             TSB_PC_DATA_PC5
#define UT1RXD_FR1              TSB_PC_FR1_PC5F1
#define UT1RXD_FR2              TSB_PC_FR2_PC5F2
#define UT1RXD_FR3              TSB_PC_FR3_PC5F3
#define UT1RXD_IE               TSB_PC_IE_PC5IE
#define UT1RXD_CR               TSB_PC_CR_PC5C

/* UART ch.2 */
#define UT2TXD_DATA             TSB_PU_DATA_PU0
#define UT2TXD_FR1              TSB_PU_FR1_PU0F1
#define UT2TXD_FR2              TSB_PU_FR2_PU0F2
#define UT2TXD_FR3              TSB_PU_FR3_PU0F3
#define UT2TXD_FR4              TSB_PU_FR4_PU0F4
#define UT2TXD_FR6              TSB_PU_FR6_PU0F6
#define UT2TXD_IE               TSB_PU_IE_PU0IE
#define UT2TXD_CR               TSB_PU_CR_PU0C

#define UT2RXD_DATA             TSB_PU_DATA_PU1
#define UT2RXD_FR1              TSB_PU_FR1_PU1F1
#define UT2RXD_FR2              TSB_PU_FR2_PU1F2
#define UT2RXD_FR3              TSB_PU_FR3_PU1F3
#define UT2RXD_FR4              TSB_PU_FR4_PU1F4
#define UT2RXD_FR5              TSB_PU_FR5_PU1F5
#define UT2RXD_FR6              TSB_PU_FR6_PU1F6
#define UT2RXD_IE               TSB_PU_IE_PU1IE
#define UT2RXD_CR               TSB_PU_CR_PU1C

/* UART ch.3 */
#define UT3TXD_DATA             TSB_PF_DATA_PF3
#define UT3TXD_FR1              TSB_PF_FR1_PF3F1
#define UT3TXD_FR2              TSB_PF_FR2_PF3F2
#define UT3TXD_FR4              TSB_PF_FR4_PF3F4
#define UT3TXD_FR5              TSB_PF_FR5_PF3F5
#define UT3TXD_FR6              TSB_PF_FR6_PF3F6
#define UT3TXD_FR7              TSB_PF_FR7_PF3F7
#define UT3TXD_IE               TSB_PF_IE_PF3IE
#define UT3TXD_CR               TSB_PF_CR_PF3C

#define UT3RXD_DATA             TSB_PF_DATA_PF4
#define UT3RXD_FR1              TSB_PF_FR1_PF4F1
#define UT3RXD_FR2              TSB_PF_FR2_PF4F2
#define UT3RXD_FR3              TSB_PF_FR3_PF4F3
#define UT3RXD_FR4              TSB_PF_FR4_PF4F4
#define UT3RXD_FR5              TSB_PF_FR5_PF4F5
#define UT3RXD_FR6              TSB_PF_FR6_PF4F6
#define UT3RXD_FR7              TSB_PF_FR7_PF4F7
#define UT3RXD_IE               TSB_PF_IE_PF4IE
#define UT3RXD_CR               TSB_PF_CR_PF4C


/** 
 *  @}
 */ /* End of group BSP_CONFIG_UART_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Private_emum BSP_CONFIG_UART Private Emum
 *  @{
 */


/** 
 *  @}
 */ /* End of group BSP_CONFIG_UART_Private_emum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Private_typedef BSP_CONFIG_UART Private Typedef
 *  @{
 */
/**
 *  @}
 */ /* End of group BSP_CONFIG_UART_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup BSP_CONFIG_UART_Exported_functions BSP_CONFIG_UART Exported Functions
 *  @{
 */
void GPIO_UART0_Config(void);


/* Self-Diagnosis */
void GPIO_UART0test_Config(void);


/** 
 *  @}
 */ /* End of group BSP_CONFIG_UART_Exported_functions */

/**
 *  @}
 */ /* End of group BSP_CONFIG_UART */

/**
 *  @} 
 */ /* End of group BSP */

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __BSP_CONFIG_UART_H */

