/** 
 *******************************************************************************
 * @file    main.c
 * @brief   A-ENC32 Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "aenc32.h"
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_adc.h"
#include "bsp_aenc32.h"
#include "bsp_led.h"
#include "uart_io.h"
#include "sys_timer.h"

/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @addtogroup A-ENC32 A-ENC32 Sample Appli
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup A-ENC32_Private_macro A-ENC32 Private Macro
 *  @{
 */

/** 
 *  @addtogroup LEDBlinkConfiguration LED Blink Time Configuration
 *  @brief    LED Blink Off Time.
 *  @{
 */
#define CFG_LED_OFF_TIME             ((uint32_t)(50))
/** 
 *  @}
 */ /* End of group LEDBlinkConfiguration */

/** 
 *  @addtogroup CountConfiguration Time Configuration
 *  @brief    Interval Time(Interrupt Cycle).
 *  @{
 */
#define CFG_OUTPUT_COUNT_TIME       ((uint32_t)(10))
/** 
 *  @}
 */ /* End of group CountConfiguration */


/** 
 *  @}
 */ /* End of group A-ENC32_Private_macro */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup A-ENC32_Private_variables A-ENC32 Private Variables
 *  @{
 */
static uint32_t enccount = 0;                     /* ENC Counter           */
static uint32_t enccount_old = 0;                 /* ENC Counter old       */
static volatile uint32_t speed = 0;               /* speed                 */
static uint32_t sec_count = 0;                    /* 1sec timer            */
static volatile int32_t cw_flag = 0;              /* Direction of Rotation */
static uint32_t counter =  CFG_OUTPUT_COUNT_TIME; /* Time Counter          */
/**
 *  @}
 */ /* End of group A-ENC32_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup A-ENC32_Private_fuctions A-ENC32 Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group A-ENC32_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup A-ENC32_Exported_functions A-ENC32 Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    GPIO_ENC_CH0_enable_fsys();
    GPIO_ENC_CH0_Config();
  
    T32A_CH0_enable_fsys();
    T32A0_A_IntervalTimer_Config();
    NVIC_EnableIRQ(INTT32A00AC_IRQn);
    T32A0_A_Start();
    /*------------------------*/
    /* T32A CountUp Setting   */
    /*------------------------*/ 
    ENC_CH0_enable_fsys();
    ENC0_Config();
    /* Timer Start */
    ENC0_Start();
    /*------------------------*/
    /* Loop */
    /*------------------------*/
    /* LED0 blink speed based on the rolling of mouse wheel */
    while(1)
    {
        if(speed > 0)
        {
            if(cw_flag == 1)
            {
                GPIO_LED1_ON();
                wait(speed);
                GPIO_LED1_OFF();
                wait(CFG_LED_OFF_TIME);
            }
            else if(cw_flag == 2)
            {
                GPIO_LED2_ON();
                wait(speed);
                GPIO_LED2_OFF();
                wait(CFG_LED_OFF_TIME);
            }
        }
        else
        {
            GPIO_LED1_OFF();
            GPIO_LED2_OFF();
        }
    } 
}
/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: T32A ch1 TimmerA/C compare match detection / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    bool     cw;
    uint32_t t32a_status;

    t32a_status = Get_param_T32A0_INTA1();
    if(t32a_status == T32AxSTA_INTA1_MASK )
    {
        Clear_flag_T32A0_INTA();
        if (counter-- == 0)
        {
            counter = CFG_OUTPUT_COUNT_TIME;

            cw = Get_param_ENC0_UD();
            if(cw == true )
            {
                cw_flag = 1;
                GPIO_LED2_OFF();
            }
            else
            {
                cw_flag = 2;
                GPIO_LED1_OFF();
            }
            if(sec_count++ >= 100)
            {
                sec_count = 0;
                enccount = Get_ENC0_CNT_value();
                speed = abs((int)(enccount - enccount_old));
                enccount_old = enccount;
            }
        }
    }
}

/**
 *  @}
 */ /* End of group A-ENC32_Exported_functions */

/**
 *  @}
 */ /* End of group A-ENC32 */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
