/** 
 *******************************************************************************
 * @file    main.c
 * @brief   CRC Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "crc.h"
#include "uart_io.h"
#include "bsp.h"
#include "bsp_led.h"

/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup CRC CRC
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_config CRC Config
 *  @{
 */

#define CRC16
/*#define CRC32*/

#define CRC_MEMORY
/*#define CRC_RAM*/

#define MEMORY_SIZE     ((uint32_t)9)      /*!< Size                    */

/** 
 *  @}
 */ /* End of group CRC_config */


/*------------------------------------------------------------------------------*/
/*  Public Member                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_Public_variables CRC Public Variables
 *  @{
 */
/**
 *  @}
 */ /* End of group CRC_Public_variables */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_Private_variables CRC Private Variables
 *  @{
 */
#ifdef CRC_MEMORY
const uint8_t comp_data[MEMORY_SIZE] = "123456789";
#else
#ifdef CRC_RAM
uint8_t comp_data[MEMORY_SIZE] = "123456789";
#endif
#endif

uint32_t crc_clc_value;
/**
 *  @}
 */ /* End of group CRC_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_Private_fuctions CRC Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group CRC_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup CRC_Exported_functions CRC Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    uint32_t    work;

    uint32_t    memory_top;
    uint32_t    memory_size;
    uint32_t    crctyp_init;
    uint32_t    crcclc_init;


#ifdef CRC16
    crctyp_init = (CRCTYP_CFMT_CRC16 | CRCTYP_DBIT_32BIT);
    crcclc_init = CRCCLC_CRC16_INIT;
#else
#ifdef CRC32
    crctyp_init = (CRCTYP_CFMT_CRC32 | CRCTYP_DBIT_32BIT);
    crcclc_init = CRCCLC_CRC32_INIT;
#endif
#endif

    memory_top = (uint32_t )comp_data;
    memory_size = MEMORY_SIZE;
    
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    
    /*------------------------*/
    /* UART Setting           */
    /*------------------------*/
    uart_io_initialize();

    /*------------------------*/
    /* CRC Setting            */
    /*------------------------*/
    CRC_enable_fsys();
    CRC_Config(crctyp_init , crcclc_init);

    CRC_calculation(memory_top , memory_size);
    crc_clc_value = Get_CRC_CLC_value();
    {
        work = (uint32_t)crc_clc_value;
#ifdef CRC16
        CRC_OneTime_calc((uint32_t)CRCTYP_DBIT_16BIT , work);
#else
#ifdef CRC32
        CRC_OneTime_calc((uint32_t)CRCTYP_DBIT_32BIT , work);
#endif
#endif
        if(Get_CRC_CLC_value() == 0x00000000)
        {
            GPIO_LED1_ON();
            GPIO_LED2_OFF();
        }
        else
        {
            GPIO_LED1_OFF();
            GPIO_LED2_ON();
        }
        printf("START = 0x%08X\n" , memory_top);
        printf("END   = 0x%08X\n" , memory_top + memory_size -1);
        printf("CRC   = 0x%08X\n\n" , crc_clc_value);
    }

    /*------------------------*/
    /*          Loop          */
    /*------------------------*/ 
    while(1){}
}

/**
 *  @}
 */ /* End of group CRC_Exported_functions */

/**
 *  @}
 */ /* End of group CRC */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
