/** 
 *******************************************************************************
 * @file    main.c
 * @brief   I2C Master Receive Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "bsp_i2c.h"

#include "except.h"
#include "i2c.h"


/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup I2C_MasterReceive I2C_MasterReceive
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterReceive_config I2C_MasterReceive Config
 *  @{
 */

#define DATA_LENGTH     (16)                    /*!< Length of base data.      */
#define MCU_NAME        "TMPM4KNFYA"

/** 
 *  @}
 */ /* End of group I2C_MasterReceive_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterSlave_Private_define I2C_MasterSlave Private Define
 *  @{
 */

/** 
 *  @}
 */ /* End of group I2C_MasterSlave_Private_define */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterReceive_Private_variables I2C_MasterReceive Private Variables
 *  @{
 */
#define DUMMY_DATA   0x00

static uint32_t     rx_length;                     /*!< Length of Master Rx Data. */
static uint8_t      rx_buf[DATA_LENGTH+1];         /*!< Rx Data of Master(include the address).  */
static volatile     bool    cmp_flag;
/**
 *  @}
 */ /* End of group I2C_MasterReceive_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterReceive_Private_fuctions I2C_MasterReceive Private Fuctions
 *  @{
 */
void clear_rx_buf(void);
/**
 *  @}
 */ /* End of group I2C_MasterReceive_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterReceive_Exported_functions I2C_MasterReceive Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    /* Enable the peripheral clock of LED   */
    GPIO_LED_enable_fsys();
    /* Configure LED  */
    GPIO_LED_Config();
    
    /* Enable the peripheral clock of SW    */
    GPIO_SW_enable_fsys();
    /* Configure SW  */
    GPIO_SW_Config();
    
    /*----------------------------*/
    /* Rx length Initial Setting  */
    /*----------------------------*/
    rx_length = 0;
    clear_rx_buf();
    
    /* Enable the peripheral clock of I2C  */
    GPIO_I2C_CH1_enable_fsys();
    /* Configure I2C1_Master  */
    GPIO_I2C1_Master_Config();
    
    /*------------------------*/
    /* Interrupt Setting      */
    /*------------------------*/
    INT17a_enable_IMC061();
    NVIC_EnableIRQ( INT17_IRQn );
    
    /*------------------------*/
    /* LED Initial Setting    */
    /*------------------------*/
    GPIO_LED1_OFF();
    GPIO_LED3_OFF();
    
    /*------------------------*/
    /* I2C Interrupt Setting  */
    /*------------------------*/
    NVIC_EnableIRQ( INTI2C1NST_IRQn );
    
    /*------------------------*/
    /* I2C Master Setting     */
    /*------------------------*/
    /* Clock suply for I2C ch.1  */
    I2C_CH1_enable_fsys();
    /* Configure I2C1_Master     */
    I2C1_Master_Config();
    
    /*------------------------*/
    /*          Loop          */
    /*------------------------*/
    while(1){
      
        cmp_flag = 0;
        while( cmp_flag != 1 ) {;}

        if( strncmp((char *)(rx_buf+1), (char*)MCU_NAME,(sizeof(MCU_NAME)-1)) == 0 )
        {
            GPIO_LED1_FLIP();
            GPIO_LED3_OFF();
        }
        else
        {
            GPIO_LED3_ON();
        }

        rx_length = 0;
        clear_rx_buf();

        while( Get_param_I2C1_BB() == BUS_BUSY ){;}
        /* Configure I2C1_Master     */
        I2C1_Master_Config();

        NVIC_EnableIRQ( INT17_IRQn );
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  clear_rx_buf
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void clear_rx_buf(void)
{
    memset( rx_buf, 0, sizeof( rx_buf ) );
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1NST IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void INTI2C1NST_IRQHandler(void)
{    
    if( rx_length >= DATA_LENGTH)
    {

        rx_buf[rx_length] = Get_I2C1_DBR_value();
        rx_length++;

        Clear_flag_I2C1_I2C();

        cmp_flag = 1;

        I2C1_stop_condition();
    }
    else
    {
        if( rx_length >= (DATA_LENGTH - 1))
        {
            rx_buf[rx_length] = Get_I2C1_DBR_value();
            rx_length++;

            Set_param_I2C1_MFACK();
            Set_I2C1_DBR_value( DUMMY_DATA );
            Clear_flag_I2C1_I2C();
        }
        else
        {
            Clear_flag_I2C1_I2C();

            rx_buf[rx_length] = Get_I2C1_DBR_value();
            rx_length++;

            Set_I2C1_DBR_value( DUMMY_DATA );
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17:  Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    Clear_flag_INTNCLR_IMC061();
    
    NVIC_DisableIRQ( INT17_IRQn );
    
    GPIO_LED3_OFF();
    
    I2C1_start_condition(false);
}

/**
 *  @}
 */ /* End of group I2C_MasterReceive_Exported_functions */

/**
 *  @}
 */ /* End of group I2C_MasterReceive */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
