/** 
 *******************************************************************************
 * @file    main.c
 * @brief   I2C Slave Receive Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "bsp_i2c.h"

#include "except.h"
#include "i2c.h"


/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup I2C_SlaveReceive I2C_SlaveReceive
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveReceive_config I2C_SlaveReceive Config
 *  @{
 */

#define DATA_LENGTH     (16)                    /*!< Length of base data.      */
#define MCU_NAME        "TMPM4KNFYA"

/** 
 *  @}
 */ /* End of group I2C_SlaveReceive_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterSlave_Private_define I2C_MasterSlave Private Define
 *  @{
 */

/** 
 *  @}
 */ /* End of group I2C_MasterSlave_Private_define */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveReceive_Private_variables I2C_SlaveReceive Private Variables
 *  @{
 */
#define DUMMY_DATA      0x00

static uint32_t         rx_length;                     /*!< Length of Master Rx Data. */
static uint8_t          rx_buf[DATA_LENGTH+1];           /*!< Rx Data of Master.        */
static volatile bool    cmp_flag;
/**
 *  @}
 */ /* End of group I2C_SlaveReceive_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveReceive_Private_fuctions I2C_SlaveReceive Private Fuctions
 *  @{
 */
void clear_rx_buf(void);
/**
 *  @}
 */ /* End of group I2C_SlaveReceive_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveReceive_Exported_functions I2C_SlaveReceive Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    /* Enable the peripheral clock of LED    */
    GPIO_LED_enable_fsys();
    /* Configure LED  */
    GPIO_LED_Config();
    
    /* Enable the peripheral clock of SW     */
    GPIO_SW_enable_fsys();
    /* Configure SW  */
    GPIO_SW_Config();
    
    /* Enable the peripheral clock of I2C    */
    GPIO_I2C_CH1_enable_fsys();
    /* Configure I2C1_Slave  */
    GPIO_I2C1_Slave_Config();
    
    INT17a_enable_IMC061();
    
    /*------------------------*/
    /* I2C Slave Setting      */
    /*------------------------*/
    /* Clock suply for I2C ch.1  */
    I2C_CH1_enable_fsys();
    /* Configure I2C1_Slave      */
    I2C1_Slave_Config();
    
    /*------------------------*/
    /* LED Initial Setting    */
    /*------------------------*/
    GPIO_LED2_OFF();
    GPIO_LED3_OFF();
      
    /*----------------------------*/
    /* Rx length Initial Setting  */
    /*----------------------------*/
    rx_length = 0;
    clear_rx_buf();
    
    NVIC_EnableIRQ( INT17_IRQn );
    
    /*------------------------*/
    /*          Loop          */
    /*------------------------*/
    while(1){

        cmp_flag = 0;
        while( cmp_flag != 1 ) {;}

        if( strncmp((char *)(rx_buf+1), (char*)MCU_NAME,(sizeof(MCU_NAME)-1)) == 0 )
        {
            GPIO_LED2_FLIP();
            GPIO_LED3_OFF();
        }
        else
        {
            GPIO_LED3_ON();
        }

        rx_length = 0;
        clear_rx_buf();  

        /* Configure I2C1_Slave      */
        I2C1_Slave_Config();
        /* Interrupt Enable */
        NVIC_EnableIRQ(INT17_IRQn);     /* interrupt pin 0 enable */
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  clear_rx_buf
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void clear_rx_buf(void)
{
    memset( rx_buf, 0, sizeof( rx_buf ) );
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1NST IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void INTI2C1NST_IRQHandler(void)
{
    Clear_flag_I2C1_I2C();
    
    if( rx_length == (DATA_LENGTH-1))
    {
        rx_buf[rx_length] = Get_I2C1_DBR_value();
        Set_I2C1_DBR_value( DUMMY_DATA );

        NVIC_EnableIRQ( INT17_IRQn );
        NVIC_DisableIRQ( INTI2C1NST_IRQn );

        cmp_flag = 1;
    }
    else
    {
        rx_buf[rx_length] = Get_I2C1_DBR_value();
        rx_length++;

        Set_I2C1_DBR_value( DUMMY_DATA );
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17:  Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    Clear_flag_INTNCLR_IMC061();
    
    NVIC_DisableIRQ( INT17_IRQn );
    
    GPIO_LED3_OFF();
    
    NVIC_EnableIRQ( INTI2C1NST_IRQn );
}

/**
 *  @}
 */ /* End of group I2C_SlaveReceive_Exported_functions */

/**
 *  @}
 */ /* End of group I2C_SlaveReceive */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
