/** 
 *******************************************************************************
 * @file    main.c
 * @brief   I2C Slave Trans Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "bsp_i2c.h"

#include "except.h"
#include "i2c.h"


/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup I2C_SlaveTrans I2C_SlaveTrans
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveTrans_config I2C_SlaveTrans Config
 *  @{
 */

#define DATA_LENGTH     (16)                    /*!< Length of base data.      */
#define MCU_NAME        "TMPM4KNFYA"
#define SINGLE_CHAR      ' '

/** 
 *  @}
 */ /* End of group I2C_SlaveTrans_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MasterSlave_Private_define I2C_MasterSlave Private Define
 *  @{
 */

/** 
 *  @}
 */ /* End of group I2C_MasterSlave_Private_define */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveTrans_Private_variables I2C_SlaveTrans Private Variables
 *  @{
 */
#define DUMMY_DATA      0x00

static uint32_t         tx_length;                     /*!< Length of Master Rx Data. */
static uint8_t          tx_buf[DATA_LENGTH];           /*!< Rx Data of Master.        */
static volatile bool    cmp_flag;
/**
 *  @}
 */ /* End of group I2C_SlaveTrans_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveTrans_Private_fuctions I2C_SlaveTrans Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group I2C_SlaveTrans_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_SlaveTrans_Exported_functions I2C_SlaveTrans Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    /* Enable the peripheral clock of LED    */
    GPIO_LED_enable_fsys();
    /* Configure LED  */
    GPIO_LED_Config();
    
    /* Enable the peripheral clock of SW    */
    GPIO_SW_enable_fsys();
    /* Configure SW  */
    GPIO_SW_Config();
    
    /* Enable the peripheral clock of I2C  */
    GPIO_I2C_CH1_enable_fsys();
    /* Configure I2C1_Slave  */
    GPIO_I2C1_Slave_Config();
    
    /*------------------------*/
    /* I2C INT17a Setting     */
    /*------------------------*/
    INT17a_enable_IMC061();
    
    /*------------------------*/
    /* LED Initial Setting    */
    /*------------------------*/
    GPIO_LED2_OFF();
    GPIO_LED3_OFF();
    
    /*------------------------*/
    /* I2C Slave Setting      */
    /*------------------------*/
    /* Clock suply for I2C ch.1  */
    I2C_CH1_enable_fsys();
    /* Configure I2C1_Slave      */
    I2C1_Slave_Config();
    
    /*------------------------*/
    /* I2C INT17a Enable      */
    /*------------------------*/
    NVIC_EnableIRQ( INT17_IRQn );
      
    /*------------------------*/
    /* Send Data Setting      */
    /*------------------------*/
    strcpy( (char *)tx_buf , MCU_NAME );
    cmp_flag = 0;
    tx_length = 0;

    /*------------------------*/
    /*          Loop          */
    /*------------------------*/
    while(1){

        while( cmp_flag != 1 ) {;}

        NVIC_DisableIRQ( INTI2C1NST_IRQn );
        NVIC_DisableIRQ( INTI2C1NA_IRQn );
        NVIC_EnableIRQ(  INT17_IRQn );

        tx_length = 0;
        GPIO_LED2_FLIP();
        Set_I2C1_Slave_mode();
        cmp_flag = 0;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1NA IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void INTI2C1NA_IRQHandler(void)
{
    if( tx_length >= DATA_LENGTH )
    {
        tx_length = 0;
        GPIO_LED2_FLIP();
        Clear_flag_I2C1_I2C();
        Set_I2C1_DBR_value( DUMMY_DATA );
        Set_I2C1_Slave_mode();

        NVIC_DisableIRQ( INTI2C1NST_IRQn );
        NVIC_DisableIRQ( INTI2C1NA_IRQn );
        NVIC_EnableIRQ(  INT17_IRQn );
    }
    else
    {
        cmp_flag = 1;
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INTI2C1NST IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note 
  */
/*--------------------------------------------------*/
void INTI2C1NST_IRQHandler(void)
{
    if( Get_param_I2C1_NACK() == FLAG_NOT_DETECT )
    {
        if( Get_param_I2C1_LRB() == LRB_0 )
        {
            Clear_flag_I2C1_I2C();
            if(tx_length < (sizeof(MCU_NAME)-1))
            {
                Set_I2C1_DBR_value( tx_buf[tx_length] );
            }
            else
            {
                Set_I2C1_DBR_value( SINGLE_CHAR ); 
            }
            tx_length++;

            if( tx_length >= DATA_LENGTH )
            {
                cmp_flag = 1;
            }
        }
        else
        {
            GPIO_LED3_ON();

            NVIC_EnableIRQ(  INT17_IRQn );

            tx_length = 0;
            Set_I2C1_Slave_mode();
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17:  Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    Clear_flag_INTNCLR_IMC061();
    
    NVIC_DisableIRQ( INT17_IRQn );
    NVIC_EnableIRQ(  INTI2C1NST_IRQn );
    NVIC_EnableIRQ(  INTI2C1NA_IRQn );
    
    GPIO_LED3_OFF();
}

/**
 *  @}
 */ /* End of group I2C_SlaveTrans_Exported_functions */

/**
 *  @}
 */ /* End of group I2C_SlaveTrans */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
