/** 
 *******************************************************************************
 * @file    main.c
 * @brief   OFD Sample Application.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "except.h"
#include "ofd.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"

/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @addtogroup OFD OFD Sample Appli
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup OFD_Private_macro OFD Private Macro
 *  @{
 */
/** 
 *  @addtogroup LEDBlinkConfiguration LED Blink Time Configuration
 *  @brief    LED Blink Interval Time(Interrupt Cycle).
 *  @{
 */
#define CFG_LED_BLINK_TIME             ((uint32_t)(100))
/** 
 *  @}
 */ /* End of group LEDBlinkConfiguration */
/** 
 *  @addtogroup OFD_CFG OFD Configrations
 *  @brief    OFD Configrations.
 *  @{
 */
/*  fIHOSC2: Min   9.0MHz, TYP 10MHz, MAX  11.0MHz
    fEHOSC : Min   9.9MHz, TYP 10MHz, MAX  10.1MHz
    fc     : Min 158.4MHz, TYP160.0MHz, MAX 161.6MHz  */
#define OFD_LOWER_COUNT  ((uint32_t)0x1CCU)     /* (158.4/11)*32 = 460.8 : 460 = 0x1CC */
#define OFD_HIGHER_COUNT ((uint32_t)0x23EU)     /* (161.6/ 9)*32 = 574.5 : 574 = 0x23E */

#define OFD_LOWER_COUNT_EXTERNAL  ((uint32_t)0x01CU) /*  (9.9/11)*32 = 28.8 : 28 = 0x01C */
#define OFD_HIGHER_COUNT_EXTERNAL ((uint32_t)0x023U) /*  (10.1/9)*32 = 35.9 : 35 = 0x023 */

/**
 *  @}
 */ /* End of group OFD_CFG*/

/** 
 *  @addtogroup OFD_OFDMON OFDMON Register Setting
 *  @brief    OFDMON Register Macro Define.
 *  @{
 */
#define OFD_OFDMON_EOHSC              ((uint32_t)0x0U)     /* OFD Ditection Moniter for EOHSC   */
#define OFD_OFDMON_FC                 ((uint32_t)0x1U)     /* OFD Ditection Moniter for fc      */
/**
 *  @}
 */ /* End of group OFD_OFDMON*/

/** 
 *  @}
 */ /* End of group OFD_Private_macro */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup OFD_Private_variables OFD Private Variables
 *  @{
 */
static uint32_t counter  = CFG_LED_BLINK_TIME;    /* Blink Time Counter        */
static uint32_t reset_flag = 0U;                  /* Reset Flag                */
volatile bool err_flag = false;
/**
 *  @}
 */ /* End of group OFD_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup OFD_Private_fuctions OFD Private Fuctions
 *  @{
 */
/**
 *  @}
 */ /* End of group OFD_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup OFD_Exported_functions OFD Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    bool ofdrstf = false;
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();

    T32A_CH0_enable_fsys();
    T32A0_A_IntervalTimer_Config();
    NVIC_EnableIRQ(INTT32A00AC_IRQn);
    T32A0_A_Start();

    /* OFD Reset flag Check */
    ofdrstf = Get_param_RLM1_OFDRSTF();
    if( ofdrstf )
    {
        reset_flag = 1;
        /* OFD Reset flag Clear */
        Clear_flag_RLM1_OFDRSTF();
    }
    else
    {
        /* IHOSC2 Enable */
        enable_IHOSC2();
    }
    /*----------------------*/
    /* OFD                  */
    /*----------------------*/
    if(reset_flag == 0U)
    {
        OFD_enable_fsys();
        err_flag = OFD_Config( OFD_OFDMON_EOHSC,
                               OFD_LOWER_COUNT_EXTERNAL, OFD_HIGHER_COUNT_EXTERNAL, 
                               OFD_LOWER_COUNT, OFD_HIGHER_COUNT );
    }
    else
    {
        /* OFD Reset Occurred */
        err_flag = true;
        reset_flag = 0U;
    }
    while(1)
    {
    }
}
/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: T32A ch1 TimmerA/C compare match detection / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    uint32_t t32a_status;

    t32a_status = Get_param_T32A0_INTA1();
    if( t32a_status == T32AxSTA_INTA1_MASK )
    {
        Clear_flag_T32A0_INTA();

        if (counter-- == 0)
        {
            counter = CFG_LED_BLINK_TIME;
            if( err_flag == false )
            {
                GPIO_LED1_ON();
                GPIO_LED2_OFF();
            }
            else
            {
                GPIO_LED1_OFF();
                GPIO_LED2_ON();
            }
        }
        else
        {
            /* no processing */
        }
    }
}

/**
 *  @}
 */ /* End of group OFD_Exported_functions */

/**
 *  @}
 */ /* End of group OFD */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
