/** 
 *******************************************************************************
 * @file    main.c
 * @brief   PORT Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"

/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @addtogroup PORT PORT Sample Appli
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup PORT_Private_macro PORT Private Macro
 *  @{
 */
/**
 *  @addtogroup PORT_Sample_Configuration PORT Sample Configuration
 *  @brief    LED Timer / SW Timer / Chattering Count.
 *  @{
 */
#define CFG_SW_TIME             ((uint32_t)(10))
#define CFG_SW_NF               ((uint32_t)(3))
#define CFG_LED_TIME            ((uint32_t)(10))
 /**
  *  @}
  */ /* End of group PORT_Sample_Configuration */


/** 
 *  @}
 */ /* End of group PORT_Private_macro */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/**
 *  @addtogroup LVD_Private_variables LVD Private Variables
 *  @{
 */
static uint32_t counter_A;                   /* SW Time Counter         */
static uint32_t counter_B;                   /* LED Reflesh Counter     */
static bool     chat_flag = false;           /* chattering flag         */
static bool     refresh_led = false;         /* chattering flag         */
static bool     PSW1_old = BSP_PSW_OFF;      /* PSW1 old                */
static bool     PSW1_now = BSP_PSW_OFF;      /* PSW1 now                */
static bool     PSW2_old = BSP_PSW_OFF;      /* PSW1 old                */
static bool     PSW2_now = BSP_PSW_OFF;      /* PSW1 now                */
static uint32_t chat_PSW1 = (uint32_t) 0;    /* PSW1 chattering count   */
static uint32_t chat_PSW2 = (uint32_t) 0;    /* PSW2 chattering count   */
static uint32_t output_LED1 = (uint32_t) 0;  /* LED1 chattering count   */
static uint32_t output_LED2 = (uint32_t) 0;  /* LED2 chattering count   */
static uint32_t output_LED3 = (uint32_t) 0;  /* LED3 chattering count   */
static uint32_t output_LED4 = (uint32_t) 0;  /* LED4 chattering count   */
 /**
  *  @}
  */ /* End of group LVD_Private_variables */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup PORT_Private_fuctions PORT Private Fuctions
 *  @{
 */
void psw1_nf(void);
void psw2_nf(void);
void led_out(void);

/**
 *  @}
 */ /* End of group PORT_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup PORT_Exported_functions PORT Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{

    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    GPIO_SW_enable_fsys();
    GPIO_SW_Config();

    T32A_CH0_enable_fsys();
    T32A0_A_IntervalTimer_Config();
    NVIC_EnableIRQ( INTT32A00AC_IRQn );

    counter_A = CFG_SW_TIME;
    counter_B = CFG_LED_TIME;

    T32A0_A_Start();

    while(1)
    {
        if( chat_flag )
        {
            chat_flag = false;
            psw1_nf();
            psw2_nf();
        }
        if( refresh_led )
        {
            led_out();
        }
    }

}

/*--------------------------------------------------*/
/** 
  * @brief  psw1_nf
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void psw1_nf(void)
{
    PSW1_now = Get_PSW1_input();
    if ( PSW1_old != PSW1_now )
    {
        PSW1_old = PSW1_now;
        chat_PSW1 = 0; 
    }
    else
    {
        chat_PSW1 ++;
        if(chat_PSW1 > CFG_SW_NF)
        {
            chat_PSW1 = 0;
            if ( PSW1_now == BSP_PSW_ON )
            {
                output_LED1 = 1;
            }
            else
            {
                output_LED1 = 0;
            }
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  psw2_nf
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void psw2_nf(void)
{
    PSW2_now = Get_PSW2_input();
    if ( PSW2_old != PSW2_now )
    {
        PSW2_old = PSW2_now;
        chat_PSW2 = 0; 
    }
    else
    {
        chat_PSW2 ++;
        if(chat_PSW2 > CFG_SW_NF)
        {
            chat_PSW2 = 0;
            if ( PSW2_now == BSP_PSW_ON )
            {
                output_LED2 = 1;
            }
            else
            {
                output_LED2 = 0;
            }
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  led_out
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void led_out(void)
{
    refresh_led = 0;
    if ( output_LED1 == 1 )
    {
        GPIO_LED1_ON();
    }
    else
    {
        GPIO_LED1_OFF();
    }
    if ( output_LED2 == 1 )
    {
        GPIO_LED2_ON();
    }
    else
    {
        GPIO_LED2_OFF();
    }
    if ( output_LED3 == 1 )
    {
        GPIO_LED3_ON();
    }
    else
    {
        GPIO_LED3_OFF();
    }
    if ( output_LED4 == 1 )
    {
        GPIO_LED4_ON();
    }
    else
    {
        GPIO_LED4_OFF();
    }

}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: T32A ch1 TimmerA/C compare match detection / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    uint32_t t32a_status;

    t32a_status = Get_param_T32A0_INTA1();
    if( t32a_status == T32AxSTA_INTA1_MASK )
    {
        Clear_flag_T32A0_INTA();
        if (counter_A -- == 0)
        {
            counter_A = CFG_SW_TIME;
            chat_flag = true;
        }
        if (counter_B -- == 0)
        {
            counter_B = CFG_LED_TIME;
            refresh_led = true;
        }
    }
}


/**
 *  @}
 */ /* End of group PORT_Exported_functions */

/**
 *  @}
 */ /* End of group PORT */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
