/** 
 *******************************************************************************
 * @file    main.c
 * @brief   SIWDT Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "except.h"
#include "siwdt.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "sys_timer.h"

/**
 *  @addtogroup Example
 *  @{
 */

/** 
 *  @addtogroup SIWDT SIWDT Sample Appli
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_macro SIWDT Private Macro
 *  @{
 */

/*#define DEMO_WDT_CLEAR*/
    /* When you comment out this line,  NMI interrupt is occurred by WDT */ 

/** 
 *  @addtogroup LEDBlinkConfiguration LED Blink Time Configuration
 *  @brief    LED Blink Interval Time(Interrupt Cycle).
 *  @{
 */
#define CFG_LED_BLINK_TIME             ((uint32_t)(200))
/** 
 *  @}
 */ /* End of group LEDBlinkConfiguration */

/** 
 *  @}
 */ /* End of group SIWDT_Private_macro */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_variables SIWDT Private Variables
 *  @{
 */
static uint32_t counter  = CFG_LED_BLINK_TIME;    /* Blink Time Counter        */
/**
 *  @}
 */ /* End of group SIWDT_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Private_fuctions SIWDT Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group SIWDT_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SIWDT_Exported_functions SIWDT Exported Functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    SIWDT_enable_fsys();

    /*----------------------*/
    /* WDT Disable          */
    /*----------------------*/
    disable_SIWDT();
    SIWDT_Config();

    T32A_CH0_enable_fsys();
    T32A0_A_IntervalTimer_Config();
    NVIC_EnableIRQ( INTT32A00AC_IRQn );
    T32A0_A_Start();

    /*----------------------*/
    /* WDT Enable          */
    /*----------------------*/   
    enable_SIWDT();

    while (1) {
#ifdef DEMO_WDT_CLEAR
        wait(500);
        Set_WDCR_clear_code();
#endif
    }
}


/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: T32A ch1 TimmerA/C compare match detection / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    uint32_t t32a_status;

    t32a_status = Get_param_T32A0_INTA1();
    if( t32a_status == T32AxSTA_INTA1_MASK )
    {
        Clear_flag_T32A0_INTA();
        if ( counter-- == 0 )
        {
            GPIO_LED1_FLIP();
            GPIO_LED2_FLIP();
            GPIO_LED3_FLIP();
            GPIO_LED4_FLIP();

            counter  = CFG_LED_BLINK_TIME;
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  NMI Handler
  * @param  -
  * @return -
  * @retval -
  */
/*--------------------------------------------------*/
void NMI_Handler(void)
{

    if( Get_param_INT016FLG() == 1 )
    {
        disable_SIWDT();
        /*--- IBNIC00: INTPCLR ---*/
        Clear_flag_IBNIC00_INTPCLR();

        T32A0_A_Stop();

        /* LED turn off */
        GPIO_LED1_OFF();
        GPIO_LED2_OFF();
        GPIO_LED3_OFF();
        GPIO_LED4_OFF();
    }
}
/**
 *  @}
 */ /* End of group SIWDT_Exported_functions */

/**
 *  @}
 */ /* End of group SIWDT */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
