/** 
 *******************************************************************************
 * @file    main.c
 * @brief   T32A Interval Timer Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "dnf.h"
#include "except.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"

/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup T32A_IntervalTimer T32A_IntervalTimer
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_IntervalTimer_config T32A_IntervalTimer Config
 *  @{
 */

/** 
 *  @addtogroup CountConfiguration Time Configuration
 *  @brief    Interval Time(Interrupt Cycle).
 *  @{
 */
#define CFG_OUTPUT_COUNT_TIME           ((uint32_t)(500))
/** 
 *  @}
 */ /* End of group CountConfiguration */

/** 
 *  @}
 */ /* End of group T32A_IntervalTimer_config */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_IntervalTimer_Private_variables T32A_IntervalTimer Private Variables
 *  @{
 */
static uint32_t counter = CFG_OUTPUT_COUNT_TIME;   /*!< T32A value output Time Counter  */
/**
 *  @}
 */ /* End of group T32A_IntervalTimer_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_IntervalTimer_Private_fuctions T32A_IntervalTimer Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group T32A_IntervalTimer_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_IntervalTimer_Exported_functions T32A_IntervalTimer Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{

    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    
    GPIO_SW_enable_fsys();
    GPIO_SW_Config();
    
    INT17a_enable_IMC061();
    INT17b_enable_IMC062();
    NVIC_EnableIRQ( INT17_IRQn );
    
    /*------------------------*/
    /* DNF Setting            */
    /*------------------------*/
    /* Enable the peripheral clock of DNF */
    DNF_enable_fsys();
    /* DNF initial setting */
    DNF_B_Config();
    
    /*------------------------*/
    /* T32A Interval TimerSetting */
    /*------------------------*/
    /* Enable the peripheral clock of T32A00 */
    T32A_CH0_enable_fsys();
    /* T32A Interval Timer Setting */
    T32A0_A_IntervalTimer_Config();
    /* Interrupt Enable */
    NVIC_EnableIRQ( INTT32A00AC_IRQn );   /* T32A ch.0 TimmerA compare match detection */

    /*------------------------*/
    /*          Loop          */
    /*------------------------*/ 
    while(1){}
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17: Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    if( Get_param_INT157FLG() )
    {
        Clear_flag_INTNCLR_IMC061();
        
        T32A0_A_Stop();
        
        GPIO_LED1_OFF();
        GPIO_LED2_OFF();
        GPIO_LED3_OFF();
        GPIO_LED4_OFF();
    }
    else
    {
        if( Get_param_INT158FLG() )
        {
            Clear_flag_INTNCLR_IMC062();
            
            T32A0_A_Stop();

            counter  = CFG_OUTPUT_COUNT_TIME;
            
            GPIO_LED1_ON();
            GPIO_LED2_ON();
            GPIO_LED3_ON();
            GPIO_LED4_ON();
            
            T32A0_A_Start();
        }
    }
}
/*--------------------------------------------------*/
/** 
  * @brief  INTT32A00AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   95: T32A ch1 TimmerA/C compare match detection / Over flow / under flow
  */
/*--------------------------------------------------*/
void INTT32A00AC_IRQHandler(void)
{
    if( Get_param_T32A0_INTA1() )
    {
        Clear_flag_T32A0_INTA();
        if ( counter-- == 0 )
        {
            counter = CFG_OUTPUT_COUNT_TIME;
            GPIO_LED1_FLIP();
            GPIO_LED2_FLIP();
            GPIO_LED3_FLIP();
            GPIO_LED4_FLIP();
        }
    }
}


/**
 *  @}
 */ /* End of group T32A_IntervalTimer_Exported_functions */

/**
 *  @}
 */ /* End of group T32A_IntervalTimer */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
