/** 
 *******************************************************************************
 * @file    main.c
 * @brief   T32A MEASURE Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "dnf.h"
#include "except.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_timer.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "uart_io.h"


/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup T32A_MEASURE T32A_MEASURE
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_MEASURE_config T32A_MEASURE Config
 *  @{
 */

/** 
 *  @}
 */ /* End of group T32A_MEASURE_config */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_MEASURE_Private_variables T32A_MEASURE Private Variables
 *  @{
 */
uint8_t count = 0U;
uint8_t update_flag = 0U; 
uint32_t pre_value = 0U;
uint32_t now_value = 0U;
uint32_t diff_value = 0U; 
uint32_t freq_value = 0U; 
/**
 *  @}
 */ /* End of group T32A_MEASURE_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_MEASURE_Private_fuctions T32A_MEASURE Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group T32A_MEASURE_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_MEASURE_Exported_functions T32A_MEASURE Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_T32A_CH1_enable_fsys();
    GPIO_T32A1_CAP_Config();
    GPIO_T32A_CH3_enable_fsys();
    GPIO_T32A3_PPG2_Config();
    
    /*------------------------*/
    /* UART Setting            */
    /*------------------------*/
    uart_io_initialize();

    /*------------------------*/
    /* T32A Capture Setting */
    /*------------------------*/
    /* Enable the peripheral clock of T32A01 */
    T32A_CH1_enable_fsys();
    /* T32A Interval Timer Setting */
    T32A1_A_CAP_Config();
    
    /*------------------------*/
    /* T32A PPG Setting */
    /*------------------------*/
    /* Enable the peripheral clock of T32A03 */
    T32A_CH3_enable_fsys();
    /* T32A Interval Timer Setting */
    T32A3_B_PPG2_Config();
    /* Interrupt Enable */
    NVIC_EnableIRQ( INTT32A03B_IRQn );   /* T32A ch.3 TimmerB compare match detection */

    /* Timer Start */
    T32A1_A_Start();
    T32A3_B_Start();

    printf("measuring in progress\n\n");

    /*------------------------*/
    /*          Loop          */
    /*------------------------*/ 
    while(1){
        if( update_flag == 1 )
        {
            update_flag = 0;
            now_value = Get_T32A1_CAPA0_value();
            diff_value = now_value - pre_value;
            pre_value = now_value;
            freq_value = diff_value * 2;
            printf("Frequency = %7dHz\n", freq_value);
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INTT32A03AC IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   101: T32A ch3 Timer A/C Compare match detection / Over flow / Under flow
  */
/*--------------------------------------------------*/
void INTT32A03B_IRQHandler(void)
{
    if( Get_param_T32A3_INTB1() )
    {
        Clear_flag_T32A3_INTB();
        if( ++count >= 2 )
        {
            count = 0;
            update_flag = 1;
        }
    }
}
/**
 *  @}
 */ /* End of group T32A_PPG_Exported_functions */

/**
 *  @}
 */ /* End of group T32A_PPG */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
