/** 
 *******************************************************************************
 * @file    main.c
 * @brief   T32A PPG Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "dnf.h"
#include "except.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_timer.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "uart_io.h"


/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup T32A_PPG T32A_PPG
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_PPG_config T32A_PPG Config
 *  @{
 */

#define MAIN_NULL       ((void *)0)     /*!< NULL. */
#define USER_ID_REMOTE  ((uint32_t)0)   /*!< User ID :Remote Control (Any value) */
#define USER_ID_UART    ((uint32_t)1)   /*!< User ID :USB UART (Any value) */

#define LEADINGMAX      0x05U           /* LEADING RATE COUNTER MAX */
#define LEADINGINIT     0U              /* LEADING RATE COUNTER Initialize */

/** 
 *  @}
 */ /* End of group T32A_PPG_config */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_PPG_Private_variables T32A_PPG Private Variables
 *  @{
 */
static uint8_t Rate = 0U;
static uint32_t tgtRisingTiming[5U] = { 10U, 25U, 50U, 75U, 90U }; /* rigingtiming: 10%, 25%, 50%, 75%, 90% */ 
static uint32_t RisingTimingus[5U] = {0x4650U, 0x3A98U, 0x2710U, 0x1388U, 0x7D0U}; /* Low Time  90%, 75%, 50%, 25%, 10% */

static uint8_t logNum = 0U; 
static uint8_t i = 0U;
/**
 *  @}
 */ /* End of group T32A_PPG_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_PPG_Private_fuctions T32A_PPG Private Fuctions
 *  @{
 */

/**
 *  @}
 */ /* End of group T32A_PPG_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup T32A_PPG_Exported_functions T32A_PPG Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{

    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    
    GPIO_SW_enable_fsys();
    GPIO_SW_Config();
    
    GPIO_T32A_CH3_enable_fsys();
    GPIO_T32A3_PPG1_Config();

    INT17a_enable_IMC061();
    INT17b_enable_IMC062();
    NVIC_EnableIRQ( INT17_IRQn );
    
    /*------------------------*/
    /* DNF Setting            */
    /*------------------------*/
    /* Enable the peripheral clock of DNF */
    DNF_enable_fsys();
    /* DNF initial setting */
    DNF_B_Config();

    /*------------------------*/
    /* UART Setting            */
    /*------------------------*/
    uart_io_initialize();

    /*------------------------*/
    /* T32A PPG Setting */
    /*------------------------*/
    /* Enable the peripheral clock of T32A03 */
    T32A_CH3_enable_fsys();
    /* T32A Interval Timer Setting */
    T32A3_A_PPG1_Config();

    /* Timer Start -> Set duty only, not Start */
    for( i = 0; i < 5; ++i )
    {
        RisingTimingus[i] = T32AxRGA1_PPG1_INIT * (100U-tgtRisingTiming[i]) /100U;
    }
    Set_T32A3_RGA0_value( RisingTimingus[Rate] );

    /*------------------------*/
    /*          Loop          */
    /*------------------------*/ 
    while(1){
        switch ( logNum )
        {
            case 1:
                printf("PPG Output\n");
                printf("Duty: %d%%\n" , tgtRisingTiming[Rate]);
                logNum = 0;
                break;

            case 2:
                printf("PPG Stop\n");
                logNum = 0;
                break;

            case 3:
                printf("Change to Duty: %d%%\n" , tgtRisingTiming[Rate]);
                logNum = 0;
                break;

            default:
                break;
        }
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17: Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    if( Get_param_INT157FLG() )
    {
        Clear_flag_INTNCLR_IMC061();
        
        /* Check the Timer is running */
        if( Get_param_T32A3_RUNFLGA() )
        {
            logNum = 2;
            T32A3_A_Stop();
        }
        else
        {
            logNum = 1;
            T32A3_A_Start();
        }
    }
    else
    {
        if( Get_param_INT158FLG() )
        {
            Clear_flag_INTNCLR_IMC062();

            logNum = 3;
            Rate++;
            if( Rate >= LEADINGMAX )
            {
                /* change leadingtiming rate */
                Rate = LEADINGINIT;
            }

            /* Check the Timer is running */
            if( Get_param_T32A3_RUNFLGA() )
            {
                T32A3_A_Stop();
                Set_T32A3_RGA0_value( RisingTimingus[Rate] );
                T32A3_A_Start();
            }
            else
            {
                Set_T32A3_RGA0_value( RisingTimingus[Rate] );
            }
        }
    }
}

/**
 *  @}
 */ /* End of group T32A_PPG_Exported_functions */

/**
 *  @}
 */ /* End of group T32A_PPG */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
