/** 
 *******************************************************************************
 * @file    main.c
 * @brief   TRM Sample Application.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "t32a.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "bsp_timer.h"

#include "except.h"
#include "flash.h"
#include "t32a.h"
#include "uart_io.h"
#include "trm.h"

/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup Flash_Protect Flash_Protect
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup Flash_Protect_config Flash_Protect Config
 *  @{
 */
#define COUNTMAX           (10)            /*!< retry counter max value1    */

#define TRM_SELECT_TYPE    PPG_SELECT
/*#define TRM_SELECT_TYPE    UART_SELECT*/

/** 
 *  @}
 */ /* End of group Flash_Protect_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup Flash_Protect_Private_define Flash_Protect Private Define
 *  @{
 */

/** 
 *  @}
 */ /* End of group Flash_Protect_Private_define */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup Flash_Protect_Private_variables Flash_Protect Private Variables
 *  @{
 */
static uint32_t RetryCount = 0;              /*!< Retry counter                 */
static int32_t  AdjustResult;

/**
 *  @}
 */ /* End of group Flash_Protect_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup Flash_Protect_Private_fuctions Flash_Protect Private Fuctions
 *  @{
 */
void _TRMOSC_DONE(void);
void _TRMOSC_RUN(void);
void _TRMOSC_ERROR(void);

/**
 *  @}
 */ /* End of group Flash_Protect_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup Flash_Protect_Exported_functions Flash_Protect Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    /* Enable the peripheral clock of T32A CH1   */
    GPIO_T32A_CH1_enable_fsys();
    /* Configure T32A CH1     */
    GPIO_T32A1_CAP_Config();
    
    /* Enable the peripheral clock of T32A CH3   */
    GPIO_T32A_CH3_enable_fsys();
    /* Configure T32A CH3     */
    GPIO_T32A3_PPG2_Config();
    
    /*------------------------*/
    /* UART Setting           */
    /*------------------------*/
    uart_io_initialize();
    
    /* Enable the peripheral clock of T32A CH1   */
    T32A_CH1_enable_fsys();
    
    /* Enable the peripheral clock of T32A CH3   */
    T32A_CH3_enable_fsys();
    /* Configure T32A CH3 PPG */
    T32A3_B_PPG2_TRM_Config();
    
    /* Enable the peripheral clock of TRM        */
    TRM_enable_fsys();
    /* Configure TRM          */
    TRM_Config();
    
    /*------------------------*/
    /* Timer Start            */
    /*------------------------*/
    T32A1_A_Start();
    T32A3_B_Start();
    
    {
        uint32_t i;
        if( printf("%s\n", "please wait..." ) < 0 ){ /* Do Nothing */ };
        for( i = 0 ; i<0x00400000 ; i++ ){};
        if( printf("%s\n", "---------------") < 0 ){ /* Do Nothing */ };
        if( printf("%s\n", "|    start    |") < 0 ){ /* Do Nothing */ };
        if( printf("%s\n", "---------------") < 0 ){ /* Do Nothing */ };
    }
    
    /*------------------------*/
    /*          Loop          */
    /*------------------------*/
    for( RetryCount = 0; ; RetryCount++ )
    {
        if(RetryCount >= COUNTMAX )
        {
            _TRMOSC_ERROR();
            break;
        }

        AdjustResult = IOSCAdjustment( TRM_SELECT_TYPE );
        if( AdjustResult == TRMOSC_DONE )
        {
            _TRMOSC_DONE(); 
            break;
        }
        else if( AdjustResult == TRMOSC_RUN )
        {
            _TRMOSC_RUN();
        }
        else
        {
            _TRMOSC_ERROR();
            break;
        }
    }
    
    while(1){};
}
/*--------------------------------------------------*/
/** 
  * @brief  _TRMOSC_DONE.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void _TRMOSC_DONE(void)
{
    if( printf("%s\n", "TRMOSC_DONE") < 0 ){ /* Do Nothing */ };
    
    if( GetTrimmingControlValue() )
    {
        uint32_t tmp = GetSetTrimValue();

        if( printf("%s%X\n", "<TRIMSET>:", tmp) < 0 ){ /* Do Nothing */ };
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  _TRMOSC_RUN.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void _TRMOSC_RUN(void)
{
    if( printf("%s\n", "TRMOSC_RUN") < 0 ){ /* Do Nothing */ };
    
    if( GetTrimmingControlValue() )
    {
        uint32_t tmp = GetSetTrimValue();

        if( printf("%s%X\n", "<TRIMSET>:", tmp) < 0 ){ /* Do Nothing */ };
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  _TRMOSC_ERROR.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void _TRMOSC_ERROR(void)
{
    if( printf("%s\n", "TRMOSC_Error") < 0 ){ /* Do Nothing */ };
}

/**
 *  @}
 */ /* End of group Flash_Protect_Exported_functions */

/**
 *  @}
 */ /* End of group Flash_Protect */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
