/** 
 *******************************************************************************
 * @file    main.c
 * @brief   UART RECEIVE Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "dnf.h"
#include "except.h"
#include "uart.h"
#include "uart_io_dma.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_uart.h"

/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup UART_RECEIVE UART_RECEIVE
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_RECEIVE_config UART_RECEIVE Config
 *  @{
 */
#define NODMAC
/*#define DMAC*/

/** 
 *  @}
 */ /* End of group UART_RECEIVE_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_Private_define UART ECHO Private Define
 *  @{
 */
 
/** 
 *  @}
 */ /* End of group UART_Private_define */
 

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_RECEIVE_Private_variables UART_RECEIVE Private Variables
 *  @{
 */

uint8_t mcuWord[11] = "TMPM4KNFYA\n";
uint8_t receiveCharBuff[11] = {0};
uint32_t sizeOfWord = sizeof(mcuWord);
uint32_t receiveCharLength = 0;
uint32_t cmp_flag = 0;
uint32_t proc;
uint8_t rx_data[11] = {0};
uint32_t i = 0;
uint32_t dummy_buffer;

/**
 *  @}
 */ /* End of group UART_RECEIVE_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_RECEIVE_Private_fuctions UART_RECEIVE Private Fuctions
 *  @{
 */
#ifdef DMAC
void proc_PROC_DMA_RECV(void);
#endif

/**
 *  @}
 */ /* End of group UART_RECEIVE_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_RECEIVE_Exported_functions UART_RECEIVE Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{
    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    
    /*------------------------*/
    /* UART RECEIVE Setting     */
    /*------------------------*/
    /* Enable the peripheral clock of UART RECEIVE */
    GPIO_UART_CH0_enable_fsys();
    /* UART RECEIVE Setting */
    GPIO_UART0_Config();

#ifdef NODMAC
    /*------------------------*/
    /* UART RECEIVE NODMAC    */
    /*------------------------*/
    UART_CH0_enable_fsys();
    UART0_RX_Config();
    NVIC_EnableIRQ( INTSC0RX_IRQn ); /* Enable UART0_IRQn */
    NVIC_EnableIRQ( INTSC0ERR_IRQn ); /* Enable UART0ERR_IRQn */
    while(1) {
        if( cmp_flag == 1 )
        {
            if ( strncmp((const char *)receiveCharBuff , (const char *)mcuWord , 11 ) == 0 )
            {
                GPIO_LED1_ON();
                GPIO_LED3_OFF();
            }
            else
            {
                GPIO_LED1_OFF();
                GPIO_LED3_OFF();
            }
            
            for( i = 0; i < 11; i++ )
            {
                receiveCharBuff[i] = 0;
            }
            enable_UART0_RXE();
            cmp_flag = 0;
         }
    }
#endif
#ifdef DMAC
    /*------------------------*/
    /* UART RECEIVE DMAC      */
    /*------------------------*/
    DMAC_A_enable_fsys();
    DMA_Config();
    UART_CH0_enable_fsys();
    UART0_RX_DMAC_Config();
    NVIC_EnableIRQ( INTDMAATC_IRQn );
    NVIC_EnableIRQ( INTDMAAERR_IRQn );
    NVIC_EnableIRQ( INTSC0ERR_IRQn ); /* Enable UART0ERR_IRQn */
    
    /*------------------------*/
    /* Wait Data Receive      */
    /*------------------------*/ 
    while(1) {
        if( UART_DMA_Receive(11) )
        {
            if ( strncmp((char *)rx_data , (const char *)mcuWord , 11 ) == 0 )
            {
                GPIO_LED1_ON();
                GPIO_LED3_OFF();
            }
            else
            {
                GPIO_LED1_OFF();
                GPIO_LED3_OFF();
            }
        }
        else
        {
            GPIO_LED1_OFF();
            GPIO_LED3_ON();
        }

        for ( i = 0; i < 11; ++i )
        { 
            rx_data[i]=0;
        }
    }
#endif
}

#ifdef NODMAC
/*--------------------------------------------------*/
/** 
  * @brief  INTSC0RX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   60: TSPI/UART ch0 Reception interrupt
  */
/*--------------------------------------------------*/
void INTSC0RX_IRQHandler(void)
{
    disable_UART0_RXE();
    
    if( Get_param_UART0_RXRUN() )
    {
        GPIO_LED1_OFF();
        GPIO_LED3_ON();
        cmp_flag = 1;
        receiveCharLength = 0;
    }
    else
    {
        receiveCharBuff[receiveCharLength] = Get_UART0_DR_value();
        enable_UART0_RXE();
        receiveCharLength++;
        
        if( receiveCharLength >= sizeOfWord )
        {
            cmp_flag = 1;
            receiveCharLength = 0;
            Clear_flag_UART0_RXEND();
        }
    }
}
#endif
/*--------------------------------------------------*/
/** 
  * @brief  INTSC0ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   62: TSPI/UART ch0 Error interrupt
  */
/*--------------------------------------------------*/
void INTSC0ERR_IRQHandler(void)
{
    uint32_t fill_level = Get_UART0_Fill_level();

    if( Get_param_UART0_OVRERR() )
    {
        disable_UART0_RXE();
        for( i = 0; i < fill_level; i++ ){
            dummy_buffer = Get_UART0_DR_value();
        }
        while( Get_param_UART0_RXRUN() )
        {
            /* no processing */ 
        }
        Clear_flag_UART0_OVRERR();
        enable_UART0_RXE();
    }
    Clear_allflag_UART0_ERR();
    GPIO_LED3_ON();
}


/**
 *  @}
 */ /* End of group UART_RECEIVE_Exported_functions */

/**
 *  @}
 */ /* End of group UART_RECEIVE */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
