/** 
 *******************************************************************************
 * @file    main.c
 * @brief   UART TRANS Sample Application. \n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< Group Header file. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "cg.h"
#include "dnf.h"
#include "except.h"
#include "uart.h"
#include "uart_io_dma.h"
#include "bsp.h"
#include "bsp_led.h"
#include "bsp_sw.h"
#include "bsp_uart.h"

/**
 *  @addtogroup Example Example
 *  @{
 */

/** 
 *  @addtogroup UART_TRANS UART_TRANS
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_TRANS_config UART_TRANS Config
 *  @{
 */
#define NODMAC
/*#define DMAC*/

/** 
 *  @}
 */ /* End of group UART_TRANS_config */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_Private_define UART ECHO Private Define
 *  @{
 */
#ifdef DMAC
/*----------------------------------*/
/** 
 * @brief  Processing mode.
*/
/*----------------------------------*/
typedef enum
{
    PROC_START,             /*!< Start.                       */
    PROC_SW_WAIT,           /*!< SW wait.                     */
    PROC_DMA_TRANS,         /*!< DMA transfer.                */
    PROC_ERROR              /*!< Error.                       */
} Processing;
#endif
/** 
 *  @}
 */ /* End of group UART_Private_define */


/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_TRANS_Private_variables UART_TRANS Private Variables
 *  @{
 */

uint8_t sendWord[11] = "TMPM4KNFYA\n";
uint32_t sendCharLength = 0;
uint32_t proc;
uint8_t rx_data[11] = {0};
/**
 *  @}
 */ /* End of group UART_TRANS_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_TRANS_Private_fuctions UART_TRANS Private Fuctions
 *  @{
 */
#ifdef DMAC
void proc_PROC_DMA_TRANS(void);
#endif

/**
 *  @}
 */ /* End of group UART_TRANS_Private_fuctions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_TRANS_Exported_functions UART_TRANS Exported Functions
 *  @{
 */
 
/*--------------------------------------------------*/
/** 
  * @brief  Main Function.
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
int main(void)
{

    /*------------------------*/
    /* Port Setting           */
    /*------------------------*/
    GPIO_LED_enable_fsys();
    GPIO_LED_Config();
    
    GPIO_SW_enable_fsys();
    GPIO_SW_Config();
    
    /*------------------------*/
    /* UART TRANS Setting     */
    /*------------------------*/
    /* Enable the peripheral clock of UART TRANS */
    GPIO_UART_CH0_enable_fsys();
    /* UART TRANS Setting */
    GPIO_UART0_Config();
    /* Interrupt Enable */
    INT17a_enable_IMC061();
    /* DNF Settting */
    DNF_enable_fsys();
    DNF_B_Config();

#ifdef NODMAC
    /*------------------------*/
    /* UART SEND NODMAC       */
    /*------------------------*/
    UART_CH0_enable_fsys();
    UART0_TX_Config();
    NVIC_EnableIRQ( INT17_IRQn );
    NVIC_EnableIRQ( INTSC0TX_IRQn ); /* Enable UART0_IRQn */
    NVIC_EnableIRQ( INTSC0ERR_IRQn ); /* Enable UART0ERR_IRQn */

    while(1){};
#endif
#ifdef DMAC
    /*------------------------*/
    /* UART SEND MAC          */
    /*------------------------*/
    DMAC_A_enable_fsys();
    DMA_Config();
    UART_CH0_enable_fsys();
    UART0_TX_DMAC_Config();
    NVIC_EnableIRQ( INTSC0ERR_IRQn ); /* Enable UART0ERR_IRQn */
    /*----------------------*/
    /* Main Processing      */
    /*----------------------*/
    while( proc != PROC_ERROR )
    {
        switch(proc)
        {
            /*--- Start ---*/
            /*--- PROC_START ---*/
            case PROC_START:
                proc = PROC_SW_WAIT;
                NVIC_EnableIRQ( INT17_IRQn );
                break;
            /*--- PROC_SW_WAIT ---*/
            case PROC_SW_WAIT:
                break;
           /*--- PROC_DMA_TRANS ---*/
            case PROC_DMA_TRANS:
                proc_PROC_DMA_TRANS();
                break;
            /*--- Default ---*/
            default:
                break;
        }
    }
#endif
}
#ifdef DMAC
void proc_PROC_DMA_TRANS(void)
{
    if ( UART_DMA_Trans(11) )
    {
        GPIO_LED2_FLIP();
        GPIO_LED3_OFF();
    }
    else
    {
        GPIO_LED2_OFF();
        GPIO_LED3_ON();
    }
    proc = PROC_START;
}
#endif

/*--------------------------------------------------*/
/** 
  * @brief  INT17 IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   17: Interrupt pin 17a/17b
  */
/*--------------------------------------------------*/
void INT17_IRQHandler(void)
{
    Clear_flag_INTNCLR_IMC061();

    NVIC_DisableIRQ( INT17_IRQn );
    
#ifdef NODMAC
    Set_UART0_DR_value( sendWord[0] );
    enable_UART0_TXE();
    sendCharLength++;
    NVIC_EnableIRQ( INTSC0TX_IRQn );
#endif
#ifdef DMAC
    proc = PROC_DMA_TRANS;
#endif
    NVIC_EnableIRQ( INT17_IRQn );
    
}

#ifdef NODMAC
/*--------------------------------------------------*/
/** 
  * @brief  INTSC0TX IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   61: TSPI/UART ch0 Transmit interrupt
  */
/*--------------------------------------------------*/
void INTSC0TX_IRQHandler(void)
{
    disable_UART0_TXE();
    
    if( Get_param_UART0_TXRUN() )
    {
        NVIC_DisableIRQ( INTSC0TX_IRQn );
        GPIO_LED2_OFF();
        GPIO_LED3_ON();
    }
    else
    {
        if( sendCharLength >= sizeof(sendWord) )
        {
            sendCharLength = 0;
            Clear_flag_UART0_TXEND();
            GPIO_LED2_FLIP();
            GPIO_LED3_OFF();
            NVIC_EnableIRQ( INT17_IRQn );
        }
        else
        {
            Set_UART0_DR_value( sendWord[sendCharLength] );
            enable_UART0_TXE();
            sendCharLength++;
        }
    }
}
#endif
/*--------------------------------------------------*/
/** 
  * @brief  INTSC0ERR IRQ Handler
  * @param  -
  * @return -
  * @retval -
  * @note   62: TSPI/UART ch0 Error interrupt
  */
/*--------------------------------------------------*/
void INTSC0ERR_IRQHandler(void)
{
    Clear_allflag_UART0_ERR();
    GPIO_LED3_ON();
#ifdef DMAC
    proc = PROC_START;
#endif
}


/**
 *  @}
 */ /* End of group UART_TRANS_Exported_functions */

/**
 *  @}
 */ /* End of group UART_TRANS */

/**
 *  @} 
 */ /* End of group Example */

#ifdef __cplusplus
}
#endif /* __cplusplus */
