/**
 *******************************************************************************
 * @file    system.c
 * @brief   CMSIS Cortex-M4 Device Peripheral Access Layer Source File.\n
 * 
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#include "system.h"

/*-------- DEFINES -----------------------------------------------------------*/

/**
 * Initialize the system
 *
 * @param  none
 * @return none
 *
 * @brief  Update SystemCoreClock according register values.
 */
void SystemCoreClockUpdate(void)
{                               /* Get Core Clock Frequency */

    cg_get_system_core_clock();
}

/**
 * Initialize the system
 *
 * @param  none
 * @return none
 *
 * @brief  Setup the microcontroller system.
 *         Initialize the System.
 */
void SystemInit(void)
{
#if (SIWD_SETUP)                  /* Watchdog Setup */
    /* SIWD Disable */
    disable_SIWDT();
#else
    /* SIWD Enable (Setting after a Reset) */
#endif

#if (__FPU_PRESENT == 1) && (__FPU_USED == 1)   /* FPU setting */
    SCB->CPACR |= ((3UL << 10*2)|(3UL << 11*2));  /* set CP10 and CP11 Full Access */
#endif

    copy_fc_function();
    fc_fixed_clock_set(FIXED_CLK_SEL);

#if (CLOCK_SETUP)               /* Clock(external) Setup */
    cg_setup_external_hosc();
#else
    /* Internal HOSC Enable (Setting after a Reset) */
#endif

    /* PLL Setup */
    cg_setup_pll();

#if (CLOCK_SETUP)               /* Clock(external) Setup */
    cg_ihosc1_disable();
#endif
}
