/**
 *******************************************************************************
 * @file    system_TRMOSC.c
 * @brief   CMSIS Cortex-M4 Device Peripheral Access Layer Source File for TRMOSC.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#include "bsp_com.h"
#include "flash.h"
#include "fc_copy.h"
#include "siwdt.h"

/*-------- DEFINES -----------------------------------------------------------*/

/* Determine core clock frequency according to settings */
/* System clock is high-speed clock*/
#undef  CORE_TALH
#define CORE_TALH (IXTALH)
#define __CORE_CLK   (CORE_TALH)
#define __CORE_SYS   (__CORE_CLK)

/**
 * Initialize the system
 *
 * @param  -
 * @return -
 *
 * @brief  Update SystemCoreClock according register values.
 */
void SystemCoreClockUpdate(void)
{                               /* Get Core Clock Frequency */
    SystemCoreClock = IXTALH;
}

/**
 * Initialize the system
 *
 * @param  -
 * @return -
 *
 * @brief  Setup the microcontroller system.
 *         Initialize the System.
 */
void SystemInit(void)
{
#if (SIWD_SETUP)                  /* Watchdog Setup */
    /* SIWD Disable */
    disable_SIWDT();
#else
    /* SIWD Enable (Setting after a Reset) */
#endif

#if (__FPU_PRESENT == 1) && (__FPU_USED == 1)   /* FPU setting */
    SCB->CPACR |= ((3UL << 10*2)|(3UL << 11*2));  /* set CP10 and CP11 Full Access */
#endif

    copy_fc_function();
    fc_read_clock_set();
}
