/**
 *******************************************************************************
 * @file    driver_com.h
 * @brief   All common macro and definition for driver.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __DRIVER_COM_H
#define __DRIVER_COM_H

/**                                                
 *  @addtogroup Periph_Driver Peripheral Driver    
 *  @{                                             
 */                                                
                                                   
/**                                                
 *  @addtogroup DRIVER_COM DRIVER_COM              
 *  @brief    Driver Com.                       
 *  @{                                             
 */                                                


/*------------------------------------------------------------------------------*/
/*  Typedef                                                                     */
/*------------------------------------------------------------------------------*/

/** @addtogroup DRIVER_COM_H_config
  * @{
  */
/* bool definition in plain C (not C++) */

/* bool definition in EWARM C (not C++) build */
/* this is from arm\inc\stdbool.h */

/* check multiple define */
#ifndef true
/* #define bool _Bool */
typedef _Bool bool;
#define true 1
#define false 0
#endif

/**
 *  @} 
 */ /* End of group DRIVER_COM_H_config */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"  /*!< TMPM4Mx Group Header file. */

/** @addtogroup DRIVER_COM_define
  * @{
  */

/* NULL define */
#ifndef RDA_NULL
#define RDA_NULL        ((void *)0)    /*!< NULL. */
#endif

/* DEBUG define */
#ifndef NDEBUG
#include <stdio.h>
/* message output in DEBUG build */
/* use DEBUGMSG(1, ("message %s", string)) kind of forms to pass multiple arguments */
/* #define DEBUGMSG(x, y)       (((x)?((void)printf y),1:0)) */
#define DEBUGMSG(x, y)      if(x){((void)printf y);}
#else
/* if you would like debug in "RELEASE" build, enable following and make build option */
/* general - library option - low level library option as semi-hosting */
/* #include <stdio.h> */
/* #define DEBUGMSG(x, y)       ((void)((x)?(printf y),1:0)) */
#define DEBUGMSG(x, y)          ((void)0)
#endif
/**
 *  @} 
 */ /* End of group DRIVER_COM_H_define */

/** @addtogroup DRIVER_COM_H_typedef
  * @{
  */
typedef enum {
    TXZ_SUCCESS = 0U,
    TXZ_ERROR = 1U
} TXZ_Result;

typedef enum {
    TXZ_BUSY = 0U,
    TXZ_DONE = 1U
} TXZ_WorkState;

typedef enum {
    TXZ_DISABLE = 0U,
    TXZ_ENABLE = 1U
} TXZ_FunctionalState;
/**
 *  @} 
 */ /* End of group DRIVER_COM_H_typedef */

/** @addtogroup DRIVER_COM_H_macro
  * @{
  */
#define IS_TXZ_FUNCTIONAL_STATE(STATE) (((STATE) == DISABLE) || ((STATE) == ENABLE))

#define IS_POINTER_NOT_NULL(param) ((void*)(param)!=(void*)0)

/**
  * @brief To report the name of the source file and source line number where the
  *        assert_param error has occurred, "DEBUG" must be defined. And detailed
  *        definition of assert_failed() is needed to be implemented, which can be
  *        done, for example, in the main.c file.
  */
#ifdef ASSERT_FAILED
void assert_failed(char *file, int32_t line);
#define assert_param(expr) ((expr) ? (void)0 : assert_failed((char *)__FILE__, __LINE__))
#else
#define assert_param(expr)
#endif /* ASSERT_FAILED */

/**
 *  @} 
 */ /* End of group DRIVER_COM_H_macro */

/**
 *  @} 
 */ /* End of group DRIVER_COM */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __DRIVER_COM_H */
