/**
 *******************************************************************************
 * @file    rda_adc_i.c
 * @brief   This file provides API functions for ADC rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "adc.h"

#if defined(__ADC_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_ADC RDA_ADC
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_config RDA_ADC Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group RDA_ADC_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_define RDA_ADC Private Define
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_num RDA_ADC Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_typedef RDA_ADC Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_variable RDA_ADC Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_ADC_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_fuctions RDA_ADC Private Functions
 *  @{
 */

/*--------------------------------------------------*/
/*!
  * @fn     void ADC_C_Config(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void ADC_C_Config(void)
{
    /* Configure ADC unit C */
    /* (1) Mode Register 0 Setting,   RCUT=0,DACON=1 */
    /* (2) Clock Register Setting, VADCLK[2:0]=000, EXAZ[3:0]=0001
           ADCLK/1, 1.0[us] (SCLK=160MHz)                          */
    /* (3) Mode Register 1 Setting,   MOD1[31:0]=0x00306122
           1.0us (SCLK=160MHz)                                     */
    /* (4) Mode Register 2 Setting,   MOD2[31:0]=0x00000000        */
    TSB_ADC->MOD0 = ADxMOD0_DACON_ON;   /* (1) */
    wait(3);
    TSB_ADC->CLK  = ADC_CLK_160MHz;     /* (2) */
    TSB_ADC->MOD1 = ADC_MOD1_160MHz;    /* (3) */
    TSB_ADC->MOD2 = ADC_MOD2_value;     /* (4) */
}

/*--------------------------------------------------*/
/*!
  * @fn     void ADC_C_CP_Config(uint32_t cmp0 , uint32_t cmp1)
  * @brief  ADC initial setting
  * @param[in] CFG_ADC_CMP_25_SMALL_THAN , CFG_ADC_CMP_35_BIG_THAN
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void ADC_C_CP_Config(uint32_t cmp0 , uint32_t cmp1)
{
    TSB_ADC_CMPEN_CMP1EN = ADxCMPEN_CMP1EN_DISABLE;     /*!< CMP1EN : Disable */
    TSB_ADC_CMPEN_CMP0EN = ADxCMPEN_CMP0EN_DISABLE;     /*!< CMP0EN : Disable */

    TSB_ADC->CMPCR0 = ADxCMPCR0_CMPCNT0_1;              /*!< CMPCNT0 : 1 times  */
    TSB_ADC->CMPCR0 |= ADxCMPCR0_CMPCND0_ACC;           /*!< CMPCND0 : continue  */
    TSB_ADC->CMPCR0 |= ADxCMPCR0_ADBIG0_SMALL;          /*!< ADBIG0 : ADxREGn > ADxCMP0  */
    TSB_ADC->CMPCR0 |= ADxCMPCR0_REGS0_REG0;            /*!< REGS0 : ADxREG0       */
    TSB_ADC->CMP0 = cmp0;                               /*!< If temp >= 25 c, Small than this value  */

    TSB_ADC->CMPCR1 = ADxCMPCR1_CMPCNT1_1;              /*!< CMPCNT0 : 1 times  */
    TSB_ADC->CMPCR1 |= ADxCMPCR1_CMPCND1_ACC;           /*!< CMPCND0 : continue  */
    TSB_ADC->CMPCR1 |= ADxCMPCR1_ADBIG1_BIG;            /*!< ADBIG0 : ADxREGn > ADxCMP0  */
    TSB_ADC->CMPCR1 |= ADxCMPCR1_REGS1_REG0;            /*!< REGS0 : ADxREG0       */
    TSB_ADC->CMP1 = cmp1;                               /*!< If temp < 36 c,  Big than this value  */

    TSB_ADC_CMPEN_CMP1EN = ADxCMPEN_CMP1EN_ENABLE;      /*!< CMP1EN : Enable */
    TSB_ADC_CMPEN_CMP0EN = ADxCMPEN_CMP0EN_ENABLE;      /*!< CMP0EN : Enable */

}

/*--------------------------------------------------*/
/*!
  * @fn     void Set_ADC_C_TSET0_value(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void Set_ADC_C_TSET0_value(void)
{
    /* Convert Program Setting */
    TSB_ADC->TSET0 = ADC_TSET0_VAL;  /*  ADxTSET0 Setting,    */
}

/*--------------------------------------------------*/
/** 
  * @fn     void ADC_C_SGL_Start(void)
  * @brief  ADC SGL start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ADC_C_SGL_Start(void)
{
    /* [ADxCR1] =0x00000000 */
    TSB_ADC->CR1 = ADC_CR1_INIT;
    /* [ADxCR0] =0x00000082 */
    TSB_ADC->CR0 = ADC_CR0_SGL_START;
}

/*--------------------------------------------------*/
/** 
  * @fn  void ADC_C_Stop(void)
  * @brief  ADC stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ADC_C_Stop(void)
{
    /* [ADxCR1] =0x00000000 */
    TSB_ADC->CR1 = ADC_CR1_INIT;
    /* [ADxCR0] =0x00000000 */
    TSB_ADC->CR0 = ADC_CR0_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_ADC_C_REG0_result_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_ADC_C_REG0_result_value(void)
{

    uint32_t tmp;

    /* ADxREG0 [AIN0] AD Result Value Get */
    do
    {
        tmp = TSB_ADC->REG0;
    } while((tmp & ADC_ADRF0_EXIST) != ADC_ADRF0_EXIST);

    return ((tmp & ADC_ADR0_MASK) >> 4);

}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_ADC_C_REG0_CP_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_ADC_C_REG0_CP_value(void)
{

    return ((TSB_ADC->REG0 & ADC_ADR0_MASK) >> 4);

}


/* Self-Diagnosis */
/*--------------------------------------------------*/
/** 
  * @brief  void AIN_VREF_Config(void)
  * @param  -
  * @return -
  * @retval -
  * @note   function of Self Diagnosis "AIN Sample".
  */
/*--------------------------------------------------*/
void AIN_VREF_Config(void)
{
    /* Configure ADC unit A */
    /* (1) Mode Register 0 Setting,   RCUT=0,DACON=1 */
    /* (2) Clock Register Setting, VADCLK[2:0]=000, EXAZ[3:0]=0001
           ADCLK/1, 1.0[us] (SCLK=160MHz)                          */
    /* (3) Mode Register 1 Setting,   MOD1[31:0]=0x00306122
           1.0us (SCLK=160MHz)                                     */
    /* (4) Mode Register 2 Setting,   MOD2[31:0]=0x00000000        */
    TSB_ADA->MOD0 = ADxMOD0_DACON_ON;   /* (1) */
    wait(3);
    TSB_ADA->CLK  = ADC_CLK_160MHz;     /* (2) */
    TSB_ADA->MOD1 = ADC_MOD1_160MHz;    /* (3) */
    TSB_ADA->MOD2 = ADC_MOD2_value;     /* (4) */
}

/*--------------------------------------------------*/
/** 
  * @fn     void ADC_A_SGL_Start(void)
  * @brief  ADC SGL start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ADC_A_SGL_Start(void)
{
    /* [ADxCR1] =0x00000000 */
    TSB_ADA->CR1 = ADC_CR1_INIT;
    /* [ADxCR0] =0x00000082 */
    TSB_ADA->CR0 = ADC_CR0_SGL_START;
}

/*--------------------------------------------------*/
/** 
  * @fn  void ADC_A_Stop(void)
  * @brief  ADC stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ADC_A_Stop(void)
{
    /* [ADxCR1] =0x00000000 */
    TSB_ADA->CR1 = ADC_CR1_INIT;
    /* [ADxCR0] =0x00000000 */
    TSB_ADA->CR0 = ADC_CR0_STOP;
}

/*--------------------------------------------------*/
/*!
  * @fn     void Set_AIN_TSET20_value(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void Set_AIN_TSET20_value(void)
{
    /* Convert Program Setting */
    TSB_ADA->TSET20 = AIN_A_TSET20_VAL;  /*  ADxTSET20 Setting,    */
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_AIN_REG20_result_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_AIN_REG20_result_value(void)
{

    uint32_t tmp;

    /* ADxREG20 [AIN10] AD Result Value Get */
    do
    {
        tmp = TSB_ADA->REG20;
    } while((tmp & ADC_ADRF0_EXIST) != ADC_ADRF0_EXIST);

    return (tmp);

}

/*--------------------------------------------------*/
/*!
  * @fn     void Set_AIN_TSET19_value(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void Set_AIN_TSET19_value(void)
{
    /* Convert Program Setting */
    TSB_ADA->TSET19 = AIN_A_TSET19_VAL;   /*  ADxTSET19 Setting,    */
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_AIN_REG19_result_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_AIN_REG19_result_value(void)
{
    uint32_t tmp;

    /* ADxREG19 [AIN19] AD Result Value Get */
    do
    {
        tmp = TSB_ADA->REG19;
    } while((tmp & ADC_ADRF0_EXIST) != ADC_ADRF0_EXIST);

    return (tmp);
}

/*--------------------------------------------------*/
/*!
  * @fn     void Set_AIN_TSET21_value(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void Set_AIN_TSET21_value(void)
{
    /* Convert Program Setting */
    TSB_ADA->TSET21 = AIN_A_TSET21_VAL; /*  ADxTSET21 Setting,    */
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_AIN_REG21_result_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_AIN_REG21_result_value(void)
{
    uint32_t tmp;

    /* ADxREG21 [AIN21] AD Result Value Get */
    do
    {
        tmp = TSB_ADA->REG21;
    } while((tmp & ADC_ADRF0_EXIST) != ADC_ADRF0_EXIST);

    return (tmp);
}

/*--------------------------------------------------*/
/*!
  * @fn     void Set_AIN_TSET0_value(void)
  * @brief  ADC initial setting
  * @param[in] -
  * @return    -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
void Set_AIN_TSET0_value(void)
{
    /* Convert Program Setting */
    TSB_ADC->TSET0 = AIN_C_TSET0_VAL;   /*  ADxTSET0 Setting,    */
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_AIN_REG0_result_value(void)
  * @brief  AD Result value Get 
  * @param  -
  * @return result
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_AIN_REG0_result_value(void)
{

    uint32_t tmp;

    /* ADxREG0 [AIN0] AD Result Value Get */
    do
    {
        tmp = TSB_ADC->REG0;
    } while((tmp & ADC_ADRF0_EXIST) != ADC_ADRF0_EXIST);

    return (tmp);

}


/**
 *  @}
 */ /* End of group RDA_ADC_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_ADC */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__ADC_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

