/** 
 *******************************************************************************
 * @file    rda_adc_i.h
 * @brief   This file provides rda_adc definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_ADC_I_H
#define __RDA_ADC_I_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "bsp.h"
#include "sys_timer.h"


/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_ADC RDA_ADC
 *  @brief    ADC Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_define RDA_ADC Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define ADC_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */

/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define ADC_PARAM_OK        ((int32_t)1)        /*!< Parameter is valid(specified).         */
#define ADC_PARAM_NG        ((int32_t)0)        /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result */

/** 
 *  @addtogroup ADxCR0 ADxCR0
 *  @brief    ADxCR0 Register.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-8  | -          |
 *  | 7     | ADEN       |
 *  | 6-2   | -          |
 *  | 1     | SGL        |
 *  | 0     | CNT        |
 *  @{
 */
/* ADEN  */
#define ADxCR0_ADEN_DISABLE     ((uint32_t)0x00000000)      /*!< ADEN   :Disable       */
#define ADxCR0_ADEN_ENABLE      ((uint32_t)0x00000080)      /*!< ADEN   :Enable        */
/* SGL   */
#define ADxCR0_SGL_ENABLE       ((uint32_t)0x00000002)      /*!< SGL    :Enable        */
/* CNT   */
#define ADxCR0_CNT_MASK         ((uint32_t)0x00000001)      /*!< CNT    :Mask          */
#define ADxCR0_CNT_DISABLE      ((uint32_t)0x00000000)      /*!< CNT    :Disable       */
#define ADxCR0_CNT_ENABLE       ((uint32_t)0x00000001)      /*!< CNT    :Enable        */
/**
 *  @}
 */ /* End of group ADxCR0 */

/** 
 *  @addtogroup ADxCR1 ADxCR1
 *  @brief    ADxCR1 Register.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-7  | -          |
 *  | 6     | CNTDMEN    |
 *  | 5     | SGLDMEN    |
 *  | 4     | TRGDMEN    |
 *  | 3:1   | -          |
 *  | 0     | TRGEN      |
 *  @{
 */
/* CNTDMEN  */
#define ADxCR1_CNTDMEN_DISABLE      ((uint32_t)0x00000000)      /*!< CNTDMEN :Disable      */
#define ADxCR1_CNTDMEN_ENABLE       ((uint32_t)0x00000040)      /*!< CNTDMEN :Enable       */
/* SGLDMEN  */
#define ADxCR1_SGLDMEN_DISABLE      ((uint32_t)0x00000000)      /*!< SGLDMEN :Disable      */
#define ADxCR1_SGLDMEN_ENABLE       ((uint32_t)0x00000020)      /*!< SGLDMEN :Enable       */
/* TRGDMEN  */
#define ADxCR1_TRGDMEN_DISABLE      ((uint32_t)0x00000000)      /*!< TRGDMEN :Disable      */
#define ADxCR1_TRGDMEN_ENABLE       ((uint32_t)0x00000010)      /*!< TRGDMEN :Enable       */
/* TRGEN    */
#define ADxCR1_TRGEN_DISABLE        ((uint32_t)0x00000000)      /*!< TRGEN   :Disable      */
#define ADxCR1_TRGEN_ENABLE         ((uint32_t)0x00000001)      /*!< TRGEN   :Enable       */
/**
 *  @}
 */ /* End of group ADxCR1 */

/** 
 *  @addtogroup ADxST ADxST
 *  @brief    ADxST Register.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-8  | -          |
 *  | 7     | ADBF       |
 *  | 6-4   | -          |
 *  | 3     | CNTF       |
 *  | 2     | SNGF       |
 *  | 1     | TRGF       |
 *  | 0     | PMDF       |
 *  @{
 */
/* ADBF  */
#define ADxST_ADBF_MASK             ((uint32_t)0x00000080)      /*!< ADBF   :Mask.       */
#define ADxST_ADBF_IDLE             ((uint32_t)0x00000000)      /*!< ADBF   :Idle.      Can stop ADCLK. */
#define ADxST_ADBF_RUN              ((uint32_t)0x00000080)      /*!< ADBF   :Running. Can't stop ADCLK. */
/* CNTF  */
#define ADxST_CNTF_MASK             ((uint32_t)0x00000008)      /*!< CNTF   :Mask.       */
#define ADxST_CNTF_IDLE             ((uint32_t)0x00000000)      /*!< CNTF   :Idle.       */
#define ADxST_CNTF_RUN              ((uint32_t)0x00000008)      /*!< CNTF   :Running.    */
/* SNGF  */
#define ADxST_SNGF_MASK             ((uint32_t)0x00000004)      /*!< SNGF   :Mask.       */
#define ADxST_SNGF_IDLE             ((uint32_t)0x00000000)      /*!< SNGF   :Idle.       */
#define ADxST_SNGF_RUN              ((uint32_t)0x00000004)      /*!< SNGF   :Running.    */
/* TRGF  */
#define ADxST_TRGF_MASK             ((uint32_t)0x00000002)      /*!< TRGF   :Mask.       */
#define ADxST_TRGF_IDLE             ((uint32_t)0x00000000)      /*!< TRGF   :Idle.       */
#define ADxST_TRGF_RUN              ((uint32_t)0x00000002)      /*!< TRGF   :Running.    */
/* PMDF  */
#define ADxST_PMDF_MASK             ((uint32_t)0x00000001)      /*!< PMDF   :Mask.       */
#define ADxST_PMDF_IDLE             ((uint32_t)0x00000000)      /*!< PMDF   :Idle.       */
#define ADxST_PMDF_RUN              ((uint32_t)0x00000001)      /*!< PMDF   :Running.    */
/**
 *  @}
 */ /* End of group ADxST */

/** 
 *  @addtogroup ADxMOD0 ADxMOD0.
 *  @brief    ADxMOD0 Register.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-2  | -          |
 *  | 1     | RCUT       |
 *  | 0     | DACON      |
 *  @{
 */
/* RCUT  */
#define ADxMOD0_RCUT_NORMAL         ((uint32_t)0x00000000)      /*!< RCUT   :Normal        */
#define ADxMOD0_RCUT_IREF_CUT       ((uint32_t)0x00000002)      /*!< RCUT   :Iref cut      */
/* DACON */
#define ADxMOD0_DACON_OFF           ((uint32_t)0x00000000)      /*!< DACON  :DAC off       */
#define ADxMOD0_DACON_ON            ((uint32_t)0x00000001)      /*!< DACON  :DAC on        */
/**
 *  @}
 */ /* End of group ADxMOD0 */

/** 
 *  @name  ADxCMPEN Macro Definition.
 *  @brief ADxCMPEN Register Macro Definition.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-2  | -          |
 *  | 1     | CMP1EN     |
 *  | 0     | CMP0EN     |
 *  @{
 */
/* CMP1EN  */
#define ADxCMPEN_CMP1EN_DISABLE     0      /*!< CMP1EN : Disable       */
#define ADxCMPEN_CMP1EN_ENABLE      1      /*!< CMP1EN : Enable        */
/* CMP0EN  */
#define ADxCMPEN_CMP0EN_DISABLE     0      /*!< CMP0EN : Disable       */
#define ADxCMPEN_CMP0EN_ENABLE      1      /*!< CMP0EN : Enable        */
/**
 *  @}
 */ /* End of name ADxCMPEN Macro Definition */

/** 
 *  @name  ADxCMPCR0 Macro Definition.
 *  @brief ADxCMPCR0 Register Macro Definition.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-12 | -          |
 *  | 11-8  | CMPCNT0    |
 *  | 7     | -          |
 *  | 6     | CMPCND0    |
 *  | 5     | ADBIG0     |
 *  | 4-0   | REGS0      |
 *  @{
 */
/* CMPCNT0  */
#define ADxCMPCR0_CMPCNT0_1                 (0x00000000U)       /*!< CMPCNT0 : single  */
#define ADxCMPCR0_CMPCNT0_5                 (0x00000000U)       /*!< CMPCNT0 : 5 times  */
/* CMPCND0  */
#define ADxCMPCR0_CMPCND0_ACC               (0x00000040U)       /*!< CMPCND0 : accumulation  */
#define ADxCMPCR0_CMPCND0_CNT               (0x00000000U)       /*!< CMPCND0 : counter  */
/* ADBIG0  */
#define ADxCMPCR0_ADBIG0_SMALL              (0x00000020U)       /*!< ADBIG0 : ADxREGn > ADxCMP0  */
/* REGS0  */
#define ADxCMPCR0_REGS0_REG0                (0x00000000U)       /*!< REGS0 : ADxREG0       */
/**
 *  @}
 */ /* End of name ADxCMPCR0 Macro Definition */

/** 
 *  @name  ADxCMPCR1 Macro Definition.
 *  @brief ADxCMPCR1 Register Macro Definition.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-12 | -          |
 *  | 11-8  | CMPCNT1    |
 *  | 7     | -          |
 *  | 6     | CMPCND1    |
 *  | 5     | ADBIG1     |
 *  | 4-0   | REGS1      |
 *  @{
 */
/* CMPCNT1  */
#define ADxCMPCR1_CMPCNT1_1                 (0x00000000U)      /*!< CMPCNT1 : single  */
#define ADxCMPCR1_CMPCNT1_5                 (0x00000000U)      /*!< CMPCNT1 : 5 times  */
/* CMPCND1  */
#define ADxCMPCR1_CMPCND1_ACC               (0x00000040U)      /*!< CMPCND1 : accumulation  */
#define ADxCMPCR1_CMPCND1_CNT               (0x00000000U)      /*!< CMPCND1 : counter  */
/* ADBIG1  */
#define ADxCMPCR1_ADBIG1_BIG                (0x00000000U)      /*!< ADBIG1 : ADxREGn < ADxCMP1  */
/* REGS1  */
#define ADxCMPCR1_REGS1_REG0                (0x00000000U)      /*!< REGS1 : ADxREG0       */
/**
 *  @}
 */ /* End of name ADxCMPCR1 Macro Definition */


/** 
 *  @name  ADxTSETn Macro Definition.
 *  @brief ADxTSETn Register Macro Definition.
 *  @details  Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31-8  | -          |
 *  | 7     | ENINT0     |
 *  | 6-5   | TRGS0[1:0] |
 *  | 4-0   | AINST0[4:0]|
 *  @{
 */
/* ENINT0  */
#define ADxTSETn_ENINT_MASK         ((uint32_t)0x00000080)      /*!< ENINT :Mask              */
#define ADxTSETn_ENINT_DISABLE      ((uint32_t)0x00000000)      /*!< ENINT :Disable           */
#define ADxTSETn_ENINT_ENABLE       ((uint32_t)0x00000080)      /*!< ENINT :Enable            */
/* TRGS0[1:0]  */
#define ADxTSETn_TRGS_DISABLE       ((uint32_t)0x00000000)      /*!< TRGS  :Disable           */
#define ADxTSETn_TRGS_CNT           ((uint32_t)0x00000020)      /*!< TRGS  :Continuation      */
#define ADxTSETn_TRGS_SGL           ((uint32_t)0x00000040)      /*!< TRGS  :Single            */
#define ADxTSETn_TRGS_TRG           ((uint32_t)0x00000060)      /*!< TRGS  :Universal Trigger */
/**
 *  @}
 */ /* End of name ADxTSETn Macro Definition */

/** 
 *  @name  ADxREGn Macro Definition.
 *  @brief ADxREGn Register Macro Definition.
 *  @details  Detail.
 *  | Bit   | Bit Symbol   |
 *  | :---  | :---         |
 *  | 31-30 | -            |
 *  | 29    | ADOVR_Mn    |
 *  | 28    | ADRF_Mn      |
 *  | 27-16 | ADR_Mn[11:0] |
 *  | 15-4  | ADRn[11:0]   |
 *  | 3-2   | -            |
 *  | 1     | ADOVRFn      |
 *  | 0     | ADRFn        |
 *  @{
 */
/* ADOVRF_Mn */
#define ADxREGn_ADOVR_Mn_MASK       ((uint32_t)0x20000000)      /*!< ADOVR_Mn :Mask          */
#define ADxREGn_ADOVR_Mn_OFF        ((uint32_t)0x00000000)      /*!< ADOVR_Mn :Flag off.     */
#define ADxREGn_ADOVR_Mn_ON         ((uint32_t)0x20000000)      /*!< ADOVR_Mn :Flag on       */
/* ADRF_Mn   */
#define ADxREGn_ADRF_Mn_MASK        ((uint32_t)0x10000000)      /*!< ADRF_Mn   :Mask          */
#define ADxREGn_ADRF_Mn_OFF         ((uint32_t)0x00000000)      /*!< ADRF_Mn   :Flag off.     */
#define ADxREGn_ADRF_Mn_ON          ((uint32_t)0x10000000)      /*!< ADRF_Mn   :Flag on       */
/* ADR_Mn    */
#define ADxREGn_ADR_Mn_MASK         ((uint32_t)0x0FFF0000)      /*!< ADR_Mn    :Mask          */
/* ADRn      */
#define ADxREGn_ADRn_MASK           ((uint32_t)0x0000FFF0)      /*!< ADRn      :Mask          */
/* ADOVRFn   */
#define ADxREGn_ADOVRFn_MASK        ((uint32_t)0x00000002)      /*!< ADOVRF_Mn :Mask          */
#define ADxREGn_ADOVRFn_OFF         ((uint32_t)0x00000000)      /*!< ADOVRF_Mn :Flag off.     */
#define ADxREGn_ADOVRFn_ON          ((uint32_t)0x00000002)      /*!< ADOVRF_Mn :Flag on       */
/* ADRFn     */
#define ADxREGn_ADRFn_MASK          ((uint32_t)0x00000001)      /*!< ADRFn     :Mask          */
#define ADxREGn_ADRFn_OFF           ((uint32_t)0x00000000)      /*!< ADRFn     :Flag off.     */
#define ADxREGn_ADRFn_ON            ((uint32_t)0x00000001)      /*!< ADRFn     :Flag on       */
/**
 *  @}
 */ /* End of name ADxREGn Macro Definition */

/** 
 *  @addtogroup ADC_CLK Clock Setting
 *  @brief    Clock Setting.
 *  @{
 */
#define ADC_CLK_160MHz                  ((uint32_t)0x00000008)    /*!< convert time:  ADCLK/1  1.0[us] (SCLK=160MHz).  */
#define ADC_CLK_80MHz                   ((uint32_t)0x00000001)    /*!< convert time:  ADCLK/2  1.1[us] (SCLK=80MHz).   */
/**
 *  @}
 */ /* End of group ADC_CLK */
 
/** 
 *  @addtogroup ADC_MOD1 MODE Setting
 *  @brief    MODE Setting.
 *  @{
 */
#define ADC_MOD1_160MHz                 ((uint32_t)0x00306122)      /*!< convert time:  1.0[us] (SCLK=160MHz).  */
#define ADC_MOD1_80MHz                  ((uint32_t)0x00104011)      /*!< convert time:  1.1[us] (SCLK=80MHz).   */
/**
 *  @}
 */ /* End of group ADC_MOD1 */

/** 
 *  @addtogroup ADC_MOD2 MODE Setting
 *  @brief    MODE Setting.
 *  @{
 */
#define ADC_MOD2_value                  ((uint32_t)0x00000000)      /*!< ADxMOD2 set value.  */
/**
 *  @}
 */ /* End of group ADC_MOD2 */

/** 
 *  @addtogroup ADC_TSET0 Setting
 *  @brief    MODE Setting.
 *  @{
 */
#define ADC_TSET0_VAL                   ((uint32_t)0x00000040)      /*!< ADxTSET0 Setting, ENINT0=0,TRGS0[1:0]=10,AINST0[4:0]=00000:AINx00  */
/**
 *  @}
 */ /* End of group ADC_MOD2 */

/** 
 *  @addtogroup ADC_CR1 DMA Request Init
 *  @brief    DMA Request Init.
 *  @{
 */
#define ADC_CR1_INIT                    ((uint32_t)0x00000000)      /*!< Not DMA Request.  */
/**
 *  @}
 */ /* End of group ADC_CR1 */
 
/** 
 *  @addtogroup ADC_CR0 ADC Convert Start
 *  @brief    ADC Convert Start.
 *  @{
 */
#define ADC_CR0_ADEN_ENABLE             ((uint32_t)0x00000080)      /*!< ADC Enable.                      */
#define ADC_CR0_SGL_START               ((uint32_t)0x00000082)      /*!< ADC Single Convert Start.        */
#define ADC_CR0_CNT_START               ((uint32_t)0x00000081)      /*!< ADC Continuation Convert Start.  */
#define ADC_CR0_STOP                    ((uint32_t)0x00000000)      /*!< ADC Convert Stop.        */
/**
 *  @}
 */ /* End of group ADC_CR0 */

/** 
 *  @addtogroup ADC_ADxREGx ADC Convert Result Store Register
 *  @brief    ADC Convert Result Store Register.
 *  @{
 */
#define ADC_ADRF0_MASK                  ((uint32_t)0x00000001)  /*!< ADC Convert Result Exist.      */
#define ADC_ADRF0_EXIST                 ((uint32_t)0x00000001)  /*!< ADC Convert Result Exist.      */
#define ADC_ADR0_MASK                   ((uint32_t)0x0000FFF0)  /*!< ADC Convert Result Exist.      */
/**
 *  @}
 */ /* End of group ADC_ADxREGx */

/** 
 *  @addtogroup ADC_SingleStatus  Single Conversion Running Status.
 *  @brief    Single Conversion Running Status.
 *  @{
 */
#define ADC_SGL_STATUS_MASK             ((uint32_t)0x00000004)    /*!< for Mask.  */
#define ADC_SGL_STATUS_SLEEP            ((uint32_t)0x00000000)    /*!< Sleep.     */
#define ADC_SGL_STATUS_RUNNING          ((uint32_t)0x00000004)    /*!< Running.   */
/**
 *  @}
 */ /* End of group ADC_SingleStatus */

/** 
 *  @addtogroup ADC_TSETx ADC TSET Register
 *  @brief    ADC TSET Register.
 *  @{
 */
/* ADC AIN_Sample */
#define AIN_A_TSET20_VAL                ((uint32_t)0x00000054)    /*!< ADxTSET20 Setting, ENINT0=0y0,TRGS0[1:0]=0y10,AINST0[4:0]=0y10100:AINx20 */
#define AIN_A_TSET19_VAL                ((uint32_t)0x00000053)    /*!< ADxTSET19 Setting, ENINT0=0y0,TRGS0[1:0]=0y10,AINST0[4:0]=0y10011:AINx19 */

#define AIN_A_TSET21_VAL                ((uint32_t)0x00000055)    /*!< ADxTSET21 Setting, ENINT0=0y0,TRGS0[1:0]=0y10,AINST0[4:0]=0y10101:AINx21 */

#define AIN_C_TSET0_VAL                 ((uint32_t)0x000000C0)    /*!< ADxTSET0  Setting, ENINT0=0y1,TRGS0[1:0]=0y10,AINST0[4:0]=0y00000:AINx00 */

/**
 *  @}
 */ /* End of group ADC_TSETx */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_enum RDA_ADC Private Enum
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_typedef RDA_ADC Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_ADC_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Inline Functions                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_ADC_Private_fuctions RDA_ADC Private Functions
 *  @{
 */

/* Sample ADC_Monitor/ADC_SoftwareTrigger */
void ADC_C_Config(void);
void ADC_C_CP_Config(uint32_t , uint32_t);
void Set_ADC_C_TSET0_value(void);
void ADC_C_SGL_Start(void);
void ADC_C_Stop(void);
uint32_t Get_ADC_C_REG0_result_value(void);
uint32_t Get_ADC_C_REG0_CP_value(void);


/* Self Diagnosis AIN_Sample */
void AIN_VREF_Config(void);

void ADC_A_SGL_Start(void);
void ADC_A_Stop(void);

void Set_AIN_TSET20_value(void);            /* VREFL */
uint32_t Get_AIN_REG20_result_value(void);

void Set_AIN_TSET19_value(void);             /* VREFH */
uint32_t Get_AIN_REG19_result_value(void);

void Set_AIN_TSET21_value(void);            /* VREF */
uint32_t Get_AIN_REG21_result_value(void);

void Set_AIN_TSET0_value(void);
uint32_t Get_AIN_REG0_result_value(void);

/**
 *  @}
 */ /* End of group RDA_ADC_Private_functions */

/**
 *  @}
 */ /* End of group RDA_ADC */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_ADC_I_H */


