/**
 *******************************************************************************
 * @file    rda_aenc32_a.c
 * @brief   This file provides API functions for A-ENC32 rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "aenc32.h"

#if defined(__AENC32_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_AENC32 RDA_AENC32
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_config RDA_AENC32 Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group RDA_AENC32_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_define RDA_AENC32 Private Define
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_AENC32_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_define RDA_AENC32 Private Define
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_AENC32_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_typedef RDA_AENC32 Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_AENC32_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_variable RDA_AENC32 Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group AENC32_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Exported_fuctions RDA_AENC32 Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  ENC0_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ENC0_Config(void)
{
    /* (1) Setting ENC Control, decoder mode
           CMPSEL=0,UDMD[1:0]=00,TOVMD=0,MCMPMD=0,DECMD[1:0]=00,SDTEN=0,MODE[2:0]=000,P3EN=0,
           TRGCAPMD=0,SFTCAP=0,ENCLR=0,ZESEL[1:0]=00,ZEN=0,ENRUN=0,ZEACT=0;ENDEV[2:0]=0        */
    /* (2) Setting Noise Cancell, Filters out pulses narrower than 31/fsys as noise
           NCT[6:0]=0011111,PDSTP=0,PDSTT=0,SYNCNCZEN=0,SYNCSPLMD=0,SYNCSPLEN=0    */
    /* (3) Interrupt Enable Contorl
           MCMPIE=0,RLDIE=0,CMPIE=0,ERRIE=0,CAPIE=0,TPLSIE=0       */
    /* (4) Setting sample clock fsys                               */
    /* (5) Setting Reload Register                                 */
    TSB_EN0->TNCR   = ENxTNCR_INIT;            /* (1) */
    TSB_EN0->INPCR  = ENxINPCR_INIT;           /* (2) */
    TSB_EN0->INTCR  = ENxINTCR_INIT;           /* (3) */
    TSB_EN0->CLKCR  = ENxCLKCR_FSYS;           /* (4) */
    TSB_EN0->RELOAD = 0xFFFFFFFF;              /* (5) */
    TSB_EN0->INT    = 0x00000000;              /* (6) */
}

/*--------------------------------------------------*/
/** 
  * @brief  ENC0_Start
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void ENC0_Start(void)
{
    TSB_EN0_TNCR_ENRUN = ENRUN_ENABLE;
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_param_ENC0_UD
  * @param[in] -
  * @return 0:CCW , 1:CW
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_ENC0_UD(void)
{
    return (TSB_EN0_STS_UD);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_ENC0_CNT_value
  * @param[in] -
  * @return count
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_ENC0_CNT_value(void)
{
    return (TSB_EN0->CNT);
}

/**
 *  @}
 */ /* End of group RDA_AENC32_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_AENC32 */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__AENC32_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

