/** 
 *******************************************************************************
 * @file    rda_aenc32_a.h
 * @brief   This file provides rda_aenc32 definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_AENC32_A_H
#define __RDA_AENC32_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_AENC32 RDA_AENC32
 *  @brief    AENC32 Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_define RDA_AENC32 Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define AENC32_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */



/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define AENC32_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define AENC32_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result Parameter Result */

/** 
 *  @addtogroup  AENC32 disable
 *  @brief    AENC32 Disable code setting.
 *  @{
 */
#define SIWDEN_Val              (0x00000000UL)            /* SIWD Disable */
#define SIWDCR_Val              (0x000000B1UL)            /* SIWD Disable code */
/** 
 *  @}
 */ /* End of group AENC32 disable */


/** 
 *  @name  ENxTNCR Macro Definition.
 *  @brief ENxTNCR Register Macro Definition.
 *  @{
 */
#define ENxTNCR_INIT       ((uint32_t)0x00000000)     /*!< CMPSEL=0,UDMD[1:0]=00,TOVMD=0,MCMPMD=0,DECMD[1:0]=00,SDTEN=0,MODE[2:0]=000,P3EN=0,TRGCAPMD=0,SFTCAP=0,ENCLR=0,
                                                           ZESEL[1:0]=00,ZEN=0,ENRUN=0,ZEACT=0;ENDEV[2:0]=0                                                                */
/**
 *  @}
 */ /* End of name ENxTNCR Macro Definition */

/** 
 *  @name  ENxINPCR Macro Definition.
 *  @brief ENxINPCR Register Macro Definition.
 *  @{
 */
#define ENxINPCR_INIT       ((uint32_t)0x00001F00)     /*!< NCT[6:0]=0011111,PDSTP=0,PDSTT=0,SYNCNCZEN=0,SYNCSPLMD=0,SYNCSPLEN=0 */
/**
 *  @}
 */ /* End of name ENxINPCR Macro Definition */

/** 
 *  @name  ENxINTCR Macro Definition.
 *  @brief ENxINTCR Register Macro Definition.
 *  @{
 */
#define ENxINTCR_INIT       ((uint32_t)0x00000000)     /*!< MCMPIE=0,RLDIE=0,CMPIE=0,ERRIE=0,CAPIE=0,TPLSIE=0  */
/**
 *  @}
 */ /* End of name ENxINTCR Macro Definition */
/** 
 *  @name  ENxCLKCR Macro Definition.
 *  @brief ENxCLKCR Register Macro Definition.
 *  @{
 */
#define ENxCLKCR_FSYS       ((uint32_t)0x00000000)     /*!< sampling clock:fsys    */
#define ENxCLKCR_FSYS_DIV2  ((uint32_t)0x00000001)     /*!< sampling clock:fsys/2  */
#define ENxCLKCR_FSYS_DIV4  ((uint32_t)0x00000002)     /*!< sampling clock:fsys/4  */
#define ENxCLKCR_FSYS_DIV8  ((uint32_t)0x00000003)     /*!< sampling clock:fsys/8  */
/**
 *  @}
 */ /* End of name ENxCLKCR Macro Definition */
 
/** 
 *  @name  ENRUN Macro Definition.
 *  @brief ENRUN Enable/Disable Macro Definition.
 *  @{
 */
#define ENRUN_DISABLE       0     /*!< Enc input circuit disable */
#define ENRUN_ENABLE        1     /*!< Enc input circuit enable  */
/**
 *  @}
 */ /* End of name ENRUN Macro Definition */
 
/** 
 *  @name  ENxSTS_UD Macro Definition.
 *  @brief ENxSTS UD Macro Definition.
 *  @{
 */
#define ENxSTS_UD_CCW       ((uint32_t)0x00000000)     /*!< CounterClockWise direction */
#define ENxSTS_UD_CC        ((uint32_t)0x00002000)     /*!< ClockWise direction        */
/**
 *  @}
 */ /* End of name ENxSTS_UD Macro Definition */
 




/**
 *  @}
 */ /* End of group RDA_AENC32_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_enum RDA_AENC32 Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_AENC32_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Private_typedef RDA_AENC32 Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_AENC32_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_AENC32_Exported_fuctions RDA_AENC32 Exported Fuctions
 *  @{
 */

void ENC0_Config(void);
void ENC0_Start(void);
bool Get_param_ENC0_UD(void);
uint32_t Get_ENC0_CNT_value(void);

/**
 *  @}
 */ /* End of group RDA_AENC32_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_AENC32 */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_AENC32_A_H */


