/**
 *******************************************************************************
 * @file    rda_cg_m4k2_e.c
 * @brief   This file provides API functions for CG rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "cg.h"

#if defined(__CG_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_CG_M4K2 RDA_CG_M4K2
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_config RDA_CG_M4K2 Private Config
 *  @{
 */
#if ((PLL0SEL_Val & (1U<<1U)) && (PLL0SEL_Val & (1U<<0U)))  /* If PLL selected and enabled */
    #if   (CORE_TALH == EOSC_6M)        /* If input is 6MHz */
        #if ((PLL0SEL_Val & PLL0SEL_MASK) == (CG_6M_MUL_26_656_FPLL))
            #define __CORE_CLK   EOSC_6M_DIV2_PLLON                               /* output clock is 159.938MHz */
        #else                                      /* fc -> reserved */
            #define __CORE_CLK   (0U)
        #endif                          /* End input is 6MHz */
    #elif (CORE_TALH == EOSC_8M)        /* If input is 8MHz */
        #if ((PLL0SEL_Val & PLL0SEL_MASK) == (CG_8M_MUL_20_FPLL))
            #define __CORE_CLK   EOSC_8M_DIV2_PLLON                               /* output clock is 160MHz */
        #else                                     /* fc -> reserved */
            #define __CORE_CLK   (0U)
        #endif                          /* End input is 8MHz */
    #elif (CORE_TALH == EOSC_10M)       /* If input is 10MHz */
        #if ((PLL0SEL_Val & PLL0SEL_MASK) == CG_10M_MUL_16_FPLL)
            #define __CORE_CLK   EOSC_10M_DIV2_PLLON                              /* output clock is 160MHz */
        #else                                     /* fc -> reserved */
            #define __CORE_CLK   (0U)
        #endif                          /* End input is 10MHz */
    #elif (CORE_TALH == EOSC_12M)       /* If input is 12MHz */
        #if ((PLL0SEL_Val & PLL0SEL_MASK) == CG_12M_MUL_13_312_FPLL)
            #define __CORE_CLK   EOSC_12M_DIV2_PLLON                              /* output clock is 159.75MHz */
        #else                                    /* fc -> reserved */
            #define __CORE_CLK   (0U)
        #endif                          /* End input is 12MHz    */
    #elif (CORE_TALH == IOSC_10M)       /* If input is 10MHz */
        #if ((PLL0SEL_Val & PLL0SEL_MASK) == CG_10M_MUL_16_FPLL)
            #define __CORE_CLK   IOSC_10M_DIV2_PLLON                              /* output clock is 160MHz */
        #else                                    /* fc -> reserved */
            #define __CORE_CLK   (0U)
        #endif                          /* End input is 12MHz    */
    #else                                                   /* input clock not known */
        #define __CORE_CLK   (0U)
        #error "Core Oscillator Frequency invalid!"
    #endif                                                  /* End switch input clock */
#else                                                       /* If PLL not used */
    #define __CORE_CLK   (CORE_TALH)
#endif

#if   ((SYSCR_GEAR_Val & 7U) == 0U)     /* Gear -> fc                         */
    #define __CORE_SYS   (__CORE_CLK)
#elif ((SYSCR_GEAR_Val & 7U) == 1U)     /* Gear -> fc/2                       */
    #define __CORE_SYS   (__CORE_CLK / 2U)
#elif ((SYSCR_GEAR_Val & 7U) == 2U)     /* Gear -> fc/4                       */
    #define __CORE_SYS   (__CORE_CLK / 4U )
#elif ((SYSCR_GEAR_Val & 7U) == 3U)     /* Gear -> fc/8                       */
    #define __CORE_SYS   (__CORE_CLK / 8U)
#elif ((SYSCR_GEAR_Val & 7U) == 4U)     /* Gear -> fc/16                      */
    #define __CORE_SYS   (__CORE_CLK / 16U)
#else                                   /* Gear -> reserved                   */
    #define __CORE_SYS   (0U)
#endif

/** 
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_define RDA_CG_M4K2 Private Define
 *  @{
 */


/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_enum RDA_CG_M4K2 Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_typedef RDA_CG_M4K2 Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_variable RDA_CG_M4K2 Private Variable
 *  @{
 */

/* Clock Variable definitions */
uint32_t SystemCoreClock = __CORE_SYS;  /*!< System Clock Frequency (Core Clock) */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Exported_fuctions RDA_CG_M4K2 Exported Functions
 *  @{
 */

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for LED port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_LED_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA01 = FSYS_ENABLE;
    TSB_CG_FSYSMENA_IPMENA17 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for SW port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_SW_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA03 = FSYS_ENABLE;
    TSB_CG_FSYSMENA_IPMENA06 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for DNF unit B,C
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void DNF_enable_fsys(void)
{
    TSB_CG_FCEN_FCIPEN27 = FSYS_ENABLE;
    TSB_CG_FCEN_FCIPEN28 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for DNF unit C
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void DNF_C_enable_fsys(void)
{
    TSB_CG_FCEN_FCIPEN28 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for UART ch.0 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_UART_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA02 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for UART ch.0
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void UART_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA21 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for T32A ch.0
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void T32A_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA28 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for ADC unit C port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_ADC_C_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA08 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for ADC unit C
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void ADC_C_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB04 = FSYS_ENABLE;
    TSB_CG_SPCLKEN_ADCKEN2   = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for A-ENC32 ch.0 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_ENC_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA12 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for A-ENC32 ch.0
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void ENC_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB06 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for CRC
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void CRC_enable_fsys(void)
{
    TSB_CG_FSYSENA_IPENA00 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for EI2C ch.1 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_EI2C_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA03 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for EI2C ch.1
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void EI2C_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB26 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for I2C ch.1 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_I2C_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA03 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for I2C ch.1
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void I2C_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA26 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for OFD
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void OFD_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB14 = FSYS_ENABLE;
    TSB_CG_FCEN_FCIPEN23 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for RAMP ch.0
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void RAMP_CH0_enable_fsys(void)
{
    TSB_CG_FSYSENA_IPENA00 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for SIWDT
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void SIWDT_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB31 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for T32A ch.1 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_T32A_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA05 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for T32A ch.1
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void T32A_CH1_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA29 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for T32A ch.3 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_T32A_CH3_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA04 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for T32A ch.3
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void T32A_CH3_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA31 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for TRM
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void TRM_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB15 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for TSPI ch.0 port
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void GPIO_TSPI_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA00 = FSYS_ENABLE;
    TSB_CG_FSYSMENA_IPMENA02 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for TSPI ch.0
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void TSPI_CH0_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA19 = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for DMAC unit A
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void DMAC_A_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB17 = FSYS_ENABLE;
}


/* Self-Diagnosis start */
/*--------------------------------------------------*/
/**
  * @brief     Clock suply for ADC unit A
  * @param     -
  * @note      Self-Diagnosis AIN_Sample
  */
/*--------------------------------------------------*/
void ADC_A_enable_fsys(void)
{
    TSB_CG_FSYSMENB_IPMENB02 = FSYS_ENABLE;
    TSB_CG_SPCLKEN_ADCKEN0   = FSYS_ENABLE;
}

/*--------------------------------------------------*/
/**
  * @brief     Clock suply for BSP_DIAGNOSIS_DIGIALIO
  * @param     -
  * @note      Self-Diagnosis DIO_Sample
  */
/*--------------------------------------------------*/
void DIO_DigitalIO_enable_fsys(void)
{
    TSB_CG_FSYSMENA_IPMENA08 = FSYS_ENABLE;
}
/* Self-Diagnosis end */


/*--------------------------------------------------*/
/**
  * @brief     Get CG system core clock.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void cg_get_system_core_clock(void)
{
    uint32_t CoreClock = 0U;
    uint32_t CoreClockInput = 0U;
    uint32_t regval = 0U;
    uint32_t oscsel = 0U;
    uint32_t pll0sel = 0U;
    uint32_t pll0on = 0U;
    /* Determine clock frequency according to clock register values */
    /* System clock is high-speed clock */
    regval = TSB_CG->OSCCR;
    oscsel = regval & CG_OSCCR_OSCSEL_SET;
    if( oscsel )    /* If system clock is External high-speed oscillator freq */
    {
        CoreClock = EXTALH;
    }
    else            /* If system clock is Internal high-speed oscillator freq */
    {
        CoreClock = IXTALH;
    }
    regval = TSB_CG->PLL0SEL;
    pll0sel = regval & CG_PLL0SEL_PLL0SEL_SET;
    pll0on = regval & CG_PLL0SEL_PLL0ON_SET;
    if( pll0sel && pll0on ) /* If PLL enabled  */
    {
        if( CoreClock == EOSC_6M )      /* If input is 6MHz */
        {
            if( (TSB_CG->PLL0SEL & PLL0SEL_MASK) == CG_6M_MUL_26_656_FPLL )
            {
                CoreClockInput = EOSC_6M_DIV2_PLLON;    /* output clock is 159.938MHz */
            }
            else
            {
                CoreClockInput = 0U;    /* fc -> reserved */
            }
        }
        else if( CoreClock == EOSC_8M )      /* If input is 8MHz */
        {
            if( (TSB_CG->PLL0SEL & PLL0SEL_MASK) == CG_8M_MUL_20_FPLL )
            {
                CoreClockInput = EOSC_8M_DIV2_PLLON;    /* output clock is 160MHz */
            }
            else
            {
                CoreClockInput = 0U;    /* fc -> reserved */
            }
        }
        else if( CoreClock == EOSC_10M )    /* If input is 10MHz */
        {
            if( (TSB_CG->PLL0SEL & PLL0SEL_MASK) == CG_10M_MUL_16_FPLL )
            {
                CoreClockInput = EOSC_10M_DIV2_PLLON;   /* output clock is 160MHz */
            }
            else
            {
                CoreClockInput = 0U;    /* fc -> reserved */
            }
        }
        else if( CoreClock == EOSC_12M )    /* If input is 12MHz */
        {
            if( (TSB_CG->PLL0SEL & PLL0SEL_MASK) == CG_12M_MUL_13_312_FPLL )
            {
                CoreClockInput = EOSC_12M_DIV2_PLLON;   /* output clock is 159.75MHz */
            }
            else
            {
                CoreClockInput = 0U;    /* fc -> reserved */
            }
        }
        else
        {
            CoreClockInput = 0U;
        }
    }
    else    /* If PLL not used */
    {
        CoreClockInput = CoreClock;
    }
    
    switch ( TSB_CG->SYSCR & 7U ) {
    case 0U:                                 /* Gear -> fc */
        SystemCoreClock = CoreClockInput;
        break;
    case 1U:                                 /* Gear -> fc/2 */
        SystemCoreClock = CoreClockInput / 2U;
        break;
    case 2U:                                 /* Gear -> fc/4 */
        SystemCoreClock = CoreClockInput / 4U;
        break;
    case 3U:                                 /* Gear -> fc/8 */
        if( CoreClockInput >= EOSC_8M )
        {
            SystemCoreClock = CoreClockInput / 8U;
        }
        else
        {
            SystemCoreClock = 0U;
        }
        break;
    case 4U:                                 /* Gear -> fc/16 */
        if( CoreClockInput >= EOSC_12M )
        {
            SystemCoreClock = CoreClockInput / 16U;
        }
        else
        {
            SystemCoreClock = 0U;
        }
        break;
    case 5U:
    case 6U:
    case 7U:
        SystemCoreClock = 0U;
        break;
    default:
        SystemCoreClock = 0U;
        break;
    }
}

/*--------------------------------------------------*/
/**
  * @brief     External High-speed Oscillation Setup.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void cg_setup_external_hosc(void)
{
    TSB_CG->SYSCR = (SYSCR_GEAR_Val | (SYSCR_PRCK_Val << 8)); /* set <GEAR> <PRCK> */

    TSB_CG->WUPHCR = (WUPHCR_WUPT_EXT | CG_WUPHCR_WUCLK_SET);
    TSB_CG->OSCCR |= CG_OSCCR_EOSCEN_SET;
    TSB_CG->WUPHCR = (WUPHCR_WUPT_EXT | CG_WUPHCR_WUCLK_SET | CG_WUPHCR_WUON_START_SET);
    while( TSB_CG_WUPHCR_WUEF ){;}                          /* Warm-up */

    TSB_CG->OSCCR |= CG_OSCCR_OSCSEL_SET;
    while( !TSB_CG_OSCCR_OSCF ){;}                          /* Confirm CGOSCCR<OSCF>="1" */
    TSB_CG->OSCCR &= CG_OSCCR_IHOSC1EN_CLEAR;
}

/*--------------------------------------------------*/
/**
  * @brief     PLL Setup.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void cg_setup_pll(void)
{
    TSB_CG->SYSCR = (SYSCR_GEAR_Val | CG_SYSCR_MCKSEL_SET);   /* set <MCKSEL> */
    while((TSB_CG->SYSCR & (CG_SYSCR_MCKSELGST_Val | CG_SYSCR_MCKSELPST_Val))
           != ((CG_SYSCR_MCKSELGST_Val | CG_SYSCR_MCKSELPST_Val))){;}

    TSB_CG->WUPHCR = (WUPHCR_INIT_PLL | CG_WUPHCR_WUCLK_SET);
    TSB_CG->PLL0SEL &= CG_PLL0SEL_PLL0SEL_CLEAR;    /* PLL-->fOsc */
    TSB_CG->PLL0SEL &= CG_PLL0SEL_PLL0ON_CLEAR;
    TSB_CG->PLL0SEL = PLL0SEL_Ready;
    TSB_CG->WUPHCR = (WUPHCR_INIT_PLL | CG_WUPHCR_WUCLK_SET | CG_WUPHCR_WUON_START_SET);
    while( TSB_CG_WUPHCR_WUEF ){;}                           /* Warm-up */

    TSB_CG->WUPHCR = (WUPHCR_LUPT_PLL | CG_WUPHCR_WUCLK_SET);
    TSB_CG->PLL0SEL |= CG_PLL0SEL_PLL0ON_SET;    /* PLL enabled */
    TSB_CG->STBYCR = STBYCR_Val;
    TSB_CG->WUPHCR = (WUPHCR_LUPT_PLL | CG_WUPHCR_WUCLK_SET | CG_WUPHCR_WUON_START_SET);
    while( TSB_CG_WUPHCR_WUEF ){;}                          /* Lockup */
    TSB_CG->PLL0SEL |= CG_PLL0SEL_PLL0SEL_SET;
    while( !TSB_CG_PLL0SEL_PLL0ST ){;}                      /*Confirm CGPLL0SEL<PLL0ST> = "1" */
}

/*--------------------------------------------------*/
/**
  * @brief     Set Internal high-speed oscillator1 disable.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void cg_ihosc1_disable(void)
{
    /* Internal high-speed oscillator1 is disable. */
    TSB_CG_OSCCR_IHOSC1EN = 0U;
}

/*--------------------------------------------------*/
/**
  * @brief     Set CG_STBY ( value )
  * @param     00 : IDLE , 01 : STOP1
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Set_CG_STBY_value(uint32_t mode)
{

    /*----------------------*/
    /* Set STBY             */
    /*----------------------*/
    /* [CGSTBYCR]<STBY>    :IDLE            */
    TSB_CG->STBYCR = mode;
    /*----------------------*/
    /* STBY Wait            */
    /*----------------------*/
    /* [CGSTBYCR]<STBY>   : Read(wait for done) */
    while( (TSB_CG->STBYCR & CGSTBYCR_STBY_MASK) != mode )
    {
        /* no processing */
    }

}

/*--------------------------------------------------*/
/**
  * @brief     Get_param_CG_WUEF
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Get_param_CG_WUEF(void)
{
    /*----------------------*/
    /* HOSC Warm-up Wait    */
    /*----------------------*/
    /* [CGWUPHCR]<WUEF>  : Read(wait for done) */
    while( (TSB_CG->WUPHCR & CGWUPHCR_WUEF_MASK) != CGWUPHCR_WUEF_R_DONE )
    {
        /* no processing */
    }
}

/*--------------------------------------------------*/
/**
  * @brief     Set_param_CG_WUCLK
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Set_param_CG_WUCLK(void)
{
    uint32_t work;

    /*----------------------*/
    /* Internal HOSC Select */
    /*----------------------*/
    /* [CGWUPHCR]<WUCLK> : IHOSC */
    work = (uint32_t)(TSB_CG->WUPHCR & ~CGWUPHCR_WUCLK_MASK);
    TSB_CG->WUPHCR = (uint32_t)(work | CGWUPHCR_WUCLK_RW_IHOSC);
}

/*--------------------------------------------------*/
/**
  * @brief     Set_CG_EOSC_WUPT_value
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Set_CG_EOSC_WUPT_value(void)
{
    uint32_t work;

    work = (uint32_t)(TSB_CG->WUPHCR & ~CGWUPHCR_WUPT_HIGH_MASK);
    work = work | WUPHCR_WUPT_EXT;
    TSB_CG->WUPHCR = work;

}

/*--------------------------------------------------*/
/**
  * @brief     Set_CG_IOSC_WUPT_value
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Set_CG_IOSC_WUPT_value(void)
{
    uint32_t work;

    work = (uint32_t)(TSB_CG->WUPHCR & ~CGWUPHCR_WUPT_HIGH_MASK);

    if (WUPHCR_WUPT_INT < WU_TIME_INT_MIN)
    {
        work = work | WU_TIME_INT_MIN;
    }
    else
    {
        work = work | WUPHCR_WUPT_INT;
    }

    TSB_CG->WUPHCR = work;

}

/*--------------------------------------------------*/
/**
  * @brief     Set_param_CG_WUON
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void Set_param_CG_WUON(void)
{
    uint32_t work;

    work = TSB_CG->WUPHCR;
    work = work | CG_WUPHCR_WUON_START_SET;
    TSB_CG->WUPHCR = work;

}

/*--------------------------------------------------*/
/** 
  * @brief  Disable PLL
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void disable_PLL (void)
{
    uint32_t work;

    /* [CGPLL0SEL]<PLL0SEL>: fosc           */
    work = (uint32_t)(TSB_CG->PLL0SEL & ~CGPLL0SEL_PLL0SEL_MASK);
    TSB_CG->PLL0SEL = (uint32_t)(work | CGPLL0SEL_PLL0SEL_RW_FOSC);
    /* [CGPLL0SEL]<PLL0ST> : wait for fosc  */
    while( (TSB_CG->PLL0SEL & CGPLL0SEL_PLL0ST_MASK) != CGPLL0SEL_PLL0ST_R_FOSC )
    {
        /* no processing */
    }
    /* [CGPLL0SEL]<PLL0ON> : PLL Disable    */
    work = (uint32_t)(TSB_CG->PLL0SEL & ~CGPLL0SEL_PLL0ON_MASK);
    TSB_CG->PLL0SEL = (uint32_t)(work | CGPLL0SEL_PLL0ON_RW_DISABLE);
}

/*--------------------------------------------------*/
/** 
  * @brief  Internal HOSC Enable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void enable_IHOSC1(void)
{
    uint32_t work;

    /* [CGOSCCR]<IHOSC1EN> : HOSC Enable    */
    work = (uint32_t)(TSB_CG->OSCCR & ~CGOSCCR_IHOSC1EN_MASK);
    TSB_CG->OSCCR = (uint32_t)(work | CGOSCCR_IHOSC1EN_RW_ENABLE);
    /* [CGOSCCR]<OSCSEL>   : IHOSC          */
    work = (uint32_t)(TSB_CG->OSCCR & ~CGOSCCR_OSCSEL_MASK);
    TSB_CG->OSCCR = (uint32_t)(work | CGOSCCR_OSCSEL_RW_IHOSC);
    /* [CGOSCCR]<OSCF>     : Read(wait for IHOSC) */
    while( (TSB_CG->OSCCR & CGOSCCR_OSCF_MASK) != CGOSCCR_OSCF_R_IHOSC )
    {
        /* no processing */
    }
}

/*--------------------------------------------------*/
/** 
  * @brief  External HOSC Disable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void disable_EHOSC(void)
{
    uint32_t work;

    /*----------------------*/
    /* External HOSC Disable*/
    /*----------------------*/
    /* [CGOSCCR]<EOSCEN>   : EHOSC Disable  */
    work = (uint32_t)(TSB_CG->OSCCR & ~CGOSCCR_EOSCEN_MASK);
    TSB_CG->OSCCR = (uint32_t)(work | CGOSCCR_EOSCEN_RW_UNUSE);
}

/*--------------------------------------------------*/
/** 
  * @brief  Enable OFD Internal HOSC
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void enable_IHOSC2(void)
{
    TSB_CG->OSCCR |= 0x00000008;
}
/*--------------------------------------------------*/
/** 
  * @brief  OFD Internal HOSC Disable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void disable_IHOSC2(void)
{
    uint32_t work;

    /*----------------------*/
    /* OFD Internal HOSC Disable*/
    /*----------------------*/
    /* [CGOSCCR]<IHOSC2EN> : OFD IHOSC Disable  */
    work = (uint32_t)(TSB_CG->OSCCR & ~CGOSCCR_IHOSC2EN_MASK);
    TSB_CG->OSCCR = (uint32_t)(work | CGOSCCR_IHOSC2EN_RW_DISABLE);
}

/*--------------------------------------------------*/
/** 
  * @brief  External HOSC Disable Check
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_CG_EOSCEN_value(void)
{
    uint32_t retval;

    retval = TSB_CG->OSCCR & CGOSCCR_EOSCEN_MASK ;
    return retval ;
}

/*--------------------------------------------------*/
/** 
  * @brief  OFD Internal HOSC Disable Check
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_CG_IHOSC2F(void)
{
    return (TSB_CG_OSCCR_IHOSC2F);
}
/*--------------------------------------------------*/
/** 
  * @brief  OFD Internal HOSC Check
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_CG_IHOSC2EN(void)
{
    return ((TSB_CG->OSCCR & 0x00000008) >> 3);
}
/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_CG_M4K2 */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__CG_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

