/** 
 *******************************************************************************
 * @file    rda_cg_m4k2_e.h
 * @brief   This file provides rda_cg definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_CG_M4K2_E_H
#define __RDA_CG_M4K2_E_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "bsp.h"
#include "system.h"
#include "configration.h"
#include "driver_com.h"

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_CG_M4K2 RDA_CG_M4K2
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_define RDA_CG_M4K2 Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define CG_NULL     ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */

#define CG_SYSCR_MCKSEL_SET         (SYSCR_MCKSEL_Val << 6U)
#define CG_SYSCR_MCKSELGST_Val      (SYSCR_MCKSEL_Val << 22U)
#define CG_SYSCR_MCKSELPST_Val      (SYSCR_MCKSEL_Val << 30U)

#define CG_6M_MUL_26_656_FPLL       (0x001C1535UL<<8U)      /* fPLL = 6MHz * 26.656   */
#define CG_8M_MUL_20_FPLL           (0x00245028UL<<8U)      /* fPLL = 8MHz * 20       */
#define CG_10M_MUL_16_FPLL          (0x002E9020UL<<8U)      /* fPLL = 10MHz * 16       */
#define CG_12M_MUL_13_312_FPLL      (0x0036DA1AUL<<8U)      /* fPLL = 12MHz * 13.312   */

#define CG_PLL0SEL_PLL0ON_SET       (0x00000001UL)
#define CG_PLL0SEL_PLL0ON_CLEAR     (0xFFFFFFFEUL)
#define CG_PLL0SEL_PLL0SEL_SET      (0x00000002UL)
#define CG_PLL0SEL_PLL0SEL_CLEAR    (0xFFFFFFFDUL)

#define CG_OSCCR_IHOSC1EN_CLEAR     (0xFFFFFFFEUL)
#define CG_OSCCR_EOSCEN_SET         (0x00000002UL)
#define CG_OSCCR_OSCSEL_SET         (0x00000100UL)

#define SYSCR_GEAR_Val              (0x00000000UL)            /* GEAR = fc */
#define SYSCR_PRCK_Val              (0x00000000UL)            /* phiT0 = fc */
#define SYSCR_MCKSEL_Val            (0x00000001UL)            /* fsysm(phiT0m) = fsysh(phiT0h) / 2 */

#define STBYCR_Val                  (0x00000000UL)

#define CG_WUPHCR_WUON_START_SET    (0x00000001UL)
#define EXT_CG_WUPHCR_WUCLK_SET     (0x00000000UL)      /* WUCLK for External HOSC select the IHOSC1 */

#if (CLOCK_SETUP)
    #define CG_WUPHCR_WUCLK_SET     (0x00000100UL)      /* WUCLK for Inital/Lockup time */
    #define PLL0SEL_Ready           CG_10M_MUL_16_FPLL
#else
    #define CG_WUPHCR_WUCLK_SET     (0x00000000UL)      /* WUCLK for Inital/Lockup time */
    #define PLL0SEL_Ready           CG_10M_MUL_16_FPLL
#endif

#define PLL0SEL_Val                 (PLL0SEL_Ready|0x00000003UL)
#define PLL0SEL_MASK                (0xFFFFFF00UL)

/* Configure Warm-up time */
#define HZ_1M                       (1000000UL)
#define WU_TIME_EXT                 (5000UL)            /* warm-up time for EXT is 5ms   */
#define WU_TIME_INT                 (1634UL)            /* warm-up time for INT is 163.4us  */
#define WU_TIME_INT_MIN             (0x03C << 20U)      /* minimum warm-up time for INT */
#define INIT_TIME_PLL               (100UL)             /* Initial time for PLL is 100us */
#define LOCKUP_TIME_PLL             (400UL)             /* Lockup time for PLL is 400us  */

/* Warm-up setting value */
/* EOSC OSCCR<WUPT11:0> = (warm-up time(us) * EXTALH - 16) / 16 */
#define WUPHCR_WUPT_EXT         ((uint32_t)(((((uint64_t)WU_TIME_EXT * EXTALH / HZ_1M) - 16UL) /16UL) << 20U))
/* IOSC OSCCR<WUPT11:0> = ((warm-up time(us) - 63.3us) * IXTALH - 41) / 16 */
#define WUPHCR_WUPT_INT         ((uint32_t)(((((uint64_t)(WU_TIME_INT - 633UL) * (IXTALH / 10) / HZ_1M) - 41UL) / 16UL) << 20U))

#if (CLOCK_SETUP)
    #define WUPHCR_INIT_PLL     ((uint32_t)(((((uint64_t)INIT_TIME_PLL * EXTALH / HZ_1M) - 16UL) /16UL) << 20U))
    #define WUPHCR_LUPT_PLL     ((uint32_t)(((((uint64_t)LOCKUP_TIME_PLL * EXTALH / HZ_1M) - 16UL) /16UL) << 20U))
#else
    #define WUPHCR_INIT_PLL     ((uint32_t)(((((uint64_t)((INIT_TIME_PLL * 10) - 633UL) * (IXTALH / 10) / HZ_1M) - 41UL) /16UL) << 20U))
    #define WUPHCR_LUPT_PLL     ((uint32_t)(((((uint64_t)((LOCKUP_TIME_PLL * 10) - 633UL) * (IXTALH /10) / HZ_1M) - 41UL) /16UL) << 20U))
#endif

#define IOSC_10M_DIV4_PLLON     (80000000UL)    /* 10.00MHz * 32.0000 / 4 */
#define IOSC_10M_DIV8_PLLON     (40000000UL)    /* 10.00MHz * 32.0000 / 8 */
#define IOSC_10M_DIV2_PLLON     (160000000UL)   /* 10.00MHz * 32.0000 / 2 */

#define EOSC_6M_DIV4_PLLON      (79970000UL)    /* 6.00MHz  * 53.3125 / 4 */
#define EOSC_8M_DIV4_PLLON      (80000000UL)    /* 8.00MHz  * 40.0000 / 4 */
#define EOSC_10M_DIV4_PLLON     (80000000UL)    /* 10.00MHz * 32.0000 / 4 */
#define EOSC_12M_DIV4_PLLON     (79880000UL)    /* 12.00MHz * 26.6250 / 4 */
#define EOSC_6M_DIV8_PLLON      (39980000UL)    /* 6.00MHz  * 53.3125 / 8 */
#define EOSC_8M_DIV8_PLLON      (40000000UL)    /* 8.00MHz  * 40.0000 / 8 */
#define EOSC_10M_DIV8_PLLON     (40000000UL)    /* 10.00MHz * 32.0000 / 8 */
#define EOSC_12M_DIV8_PLLON     (39940000UL)    /* 12.00MHz * 26.6250 / 8 */
#define EOSC_6M_DIV2_PLLON      (159900000UL)   /* 6.00MHz  * 53.3125 / 2 */
#define EOSC_8M_DIV2_PLLON      (160000000UL)   /* 8.00MHz  * 40.0000 / 2 */
#define EOSC_10M_DIV2_PLLON     (160000000UL)   /* 10.00MHz * 32.0000 / 2 */
#define EOSC_12M_DIV2_PLLON     (159800000UL)   /* 12.00MHz * 26.6250 / 2 */

/** 
 *  @addtogroup  FSYS_EN FSYS Enable/Disable
 *  @brief     FSYS Enable/Disable
 *  @{
 */
#define FSYS_DISABLE            ((uint32_t)0x00000000)    /*!< Disable                 */
#define FSYS_ENABLE             ((uint32_t)0x00000001)    /*!< Enable                  */
/** 
 *  @}
 */ /* End of group FSYS_EN */

/**
 *  @addtogroup IHOSCConfiguration IHOSC Configuration
 *  @brief    IHOSC Configuration.
 *  @{
 */
#define CFG_IHOSC_WARM_UP_TIME  ((uint32_t)(5000))      /*!< Warm up time(us).  Minimam warm-up time is 100(us). */
#define CFG_IHOSC_CLOCK         ((uint32_t)(10000000))  /*!< Clock(hz).        */
/**
 *  @}
 */ /* End of group IHOSCConfiguration */

/**
 *  @addtogroup  CGSTBYCR  CGSTBYCR Register
 *  @brief     Standby Control Register.
 *  @details   Detail.
 *  | Bit   | Bit Symbol |
 *  | :---  | :---       |
 *  | 31:2  | -          |
 *  | 1:0   | STBY       |
 *  @{
 */
 /* STBY */
#define CGSTBYCR_STBY_MASK              ((uint32_t)0x00000003)    /*!< STBY :[R/W] :Mask   */
#define CGSTBYCR_STBY_RW_IDLE           ((uint32_t)0x00000000)    /*!< STBY :[R/W] :IDLE   */
#define CGSTBYCR_STBY_RW_STOP1          ((uint32_t)0x00000001)    /*!< STBY :[R/W] :STOP1  */

 /**
  *  @}
  */ /* End of group CGSTBYCR */

/**
 *  @addtogroup  CGWUPHCR  CGWUPHCR Register
 *  @brief     HOSC warming up Register.
 *  @{
 */
/* WUPT  */
#define CGWUPHCR_WUPT_HIGH_MASK         ((uint32_t)0xFFF00000)    /*!< WUPT    :High Bit Mask.  */
/* WUCLK */
#define CGWUPHCR_WUCLK_MASK             ((uint32_t)0x00000100)    /*!< WUCLK   :Mask.           */
#define CGWUPHCR_WUCLK_RW_IHOSC         ((uint32_t)0x00000000)    /*!< WUCLK   :[R/W]  :IHOSC   */
#define CGWUPHCR_WUCLK_RW_EHOSC         ((uint32_t)0x00000100)    /*!< WUCLK   :[R/W]  :EHOSC   */
/* WUEF  */
#define CGWUPHCR_WUEF_MASK              ((uint32_t)0x00000002)    /*!< WUEF    :Mask.           */
#define CGWUPHCR_WUEF_R_DONE            ((uint32_t)0x00000000)    /*!< WUEF    :[R]    :Done    */
#define CGWUPHCR_WUEF_R_RUNNING         ((uint32_t)0x00000002)    /*!< WUEF    :[R]    :Running */
/**
 *  @}
 */ /* End of group CGWUPHCR */

/** 
 *  @addtogroup  CGPLL0SEL  CGPLL0SEL Register
 *  @brief     fsys PLL Select Register.
 *  @{
 */
/* PLL0ST  */
#define CGPLL0SEL_PLL0ST_MASK           ((uint32_t)0x00000004)    /*!< PLL0ST  :Mask.           */
#define CGPLL0SEL_PLL0ST_R_FOSC         ((uint32_t)0x00000000)    /*!< PLL0ST  :[R]     :fosc   */
#define CGPLL0SEL_PLL0ST_R_FPLL         ((uint32_t)0x00000004)    /*!< PLL0ST  :[R]     :fpll   */
/* PLL0SEL */
#define CGPLL0SEL_PLL0SEL_MASK          ((uint32_t)0x00000002)    /*!< PLL0SEL :Mask.           */
#define CGPLL0SEL_PLL0SEL_RW_FOSC       ((uint32_t)0x00000000)    /*!< PLL0SEL :[R/W]   :fosc   */
#define CGPLL0SEL_PLL0SEL_RW_FPLL       ((uint32_t)0x00000002)    /*!< PLL0SEL :[R/W]   :fpll   */
/* PLL0ON  */
#define CGPLL0SEL_PLL0ON_MASK           ((uint32_t)0x00000001)    /*!< PLL0ON  :Mask.           */
#define CGPLL0SEL_PLL0ON_RW_DISABLE     ((uint32_t)0x00000000)    /*!< PLL0ON  :[R/W]   :Disable*/
#define CGPLL0SEL_PLL0ON_RW_ENABLE      ((uint32_t)0x00000001)    /*!< PLL0ON  :[R/W]   :Enable */
/** 
 *  @}
 */ /* End of group CGPLL0SEL */

 /** 
 *  @addtogroup  CGOSCCR  CGOSCCR Register
 *  @brief     CG Control Register.
 *  @{
 */
/* IHOSC2F  */
#define CGOSCCR_IHOSC2F_MASK            ((uint32_t)0x00080000)    /*!< IHOSC2F   :Mask                  */
#define CGOSCCR_IHOSC2F_R_STOP          ((uint32_t)0x00000000)    /*!< IHOSC2F   :[R]   :Stop           */
#define CGOSCCR_IHOSC2F_R_RUNNING       ((uint32_t)0x00080000)    /*!< IHOSC2F   :[R]   :Running        */
/* OSCF     */
#define CGOSCCR_OSCF_MASK               ((uint32_t)0x00000200)    /*!< OSCF      :Mask                  */
#define CGOSCCR_OSCF_R_IHOSC            ((uint32_t)0x00000000)    /*!< OSCF      :[R]   :Internal HOSC  */
#define CGOSCCR_OSCF_R_EHOSC            ((uint32_t)0x00000200)    /*!< OSCF      :[R]   :External HOSC  */
/* OSCSEL   */
#define CGOSCCR_OSCSEL_MASK             ((uint32_t)0x00000100)    /*!< OSCSEL    :Mask                  */
#define CGOSCCR_OSCSEL_RW_IHOSC         ((uint32_t)0x00000000)    /*!< OSCSEL    :[R/W] :Internal HOSC  */
#define CGOSCCR_OSCSEL_RW_EHOSC         ((uint32_t)0x00000100)    /*!< OSCSEL    :[R/W] :External HOSC  */
/* IHOSC2EN */
#define CGOSCCR_IHOSC2EN_MASK           ((uint32_t)0x00000008)    /*!< IHOSC2EN  :Mask                  */
#define CGOSCCR_IHOSC2EN_RW_DISABLE     ((uint32_t)0x00000000)    /*!< IHOSC2EN  :[R/W] :Disable        */
#define CGOSCCR_IHOSC2EN_RW_ENABLE      ((uint32_t)0x00000008)    /*!< IHOSC2EN  :[R/W] :Enable         */
/* EOSCEN   */
#define CGOSCCR_EOSCEN_MASK             ((uint32_t)0x00000006)    /*!< EOSCEN    :Mask                  */
#define CGOSCCR_EOSCEN_RW_UNUSE         ((uint32_t)0x00000000)    /*!< EOSCEN    :[R/W] :Unuse          */
#define CGOSCCR_EOSCEN_RW_EHOSC         ((uint32_t)0x00000002)    /*!< EOSCEN    :[R/W] :External HOSC  */
#define CGOSCCR_EOSCEN_RW_ECLK          ((uint32_t)0x00000004)    /*!< EOSCEN    :[R/W] :External Clock */
/* IHOSC1EN */
#define CGOSCCR_IHOSC1EN_MASK           ((uint32_t)0x00000001)    /*!< IHOSC1EN  :Mask                  */
#define CGOSCCR_IHOSC1EN_RW_DISABLE     ((uint32_t)0x00000000)    /*!< IHOSC1EN  :[R/W] :Disable        */
#define CGOSCCR_IHOSC1EN_RW_ENABLE      ((uint32_t)0x00000001)    /*!< IHOSC1EN  :[R/W] :Enable         */
/** 
 *  @}
 */ /* End of group CGOSCCR */


/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_enum RDA_CG_M4K2 Private Enum
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Private_typedef RDA_CG_M4K2 Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CG_M4K2_Exported_functions RDA_CG_M4K2 Exported Functions
 *  @{
 */
void GPIO_LED_enable_fsys(void);
void GPIO_SW_enable_fsys(void);
void DNF_enable_fsys(void);
void GPIO_UART_CH0_enable_fsys(void);
void UART_CH0_enable_fsys(void);
void T32A_CH0_enable_fsys(void);
void GPIO_ADC_C_enable_fsys(void);
void ADC_C_enable_fsys(void);
void GPIO_ENC_CH0_enable_fsys(void);
void ENC_CH0_enable_fsys(void);
void CRC_enable_fsys(void);
void GPIO_EI2C_CH1_enable_fsys(void);
void EI2C_CH1_enable_fsys(void);
void GPIO_I2C_CH1_enable_fsys(void);
void I2C_CH1_enable_fsys(void);
void OFD_enable_fsys(void);
void RAMP_CH0_enable_fsys(void);
void SIWDT_enable_fsys(void);
void GPIO_T32A_CH1_enable_fsys(void);
void T32A_CH1_enable_fsys(void);
void GPIO_T32A_CH3_enable_fsys(void);
void T32A_CH3_enable_fsys(void);
void TRM_enable_fsys(void);
void GPIO_TSPI_CH0_enable_fsys(void);
void TSPI_CH0_enable_fsys(void);
void DMAC_A_enable_fsys(void);

/* Self-Diagnosis */
void ADC_A_enable_fsys(void);
void DNF_C_enable_fsys(void);
void DIO_DigitalIO_enable_fsys(void);


void cg_get_system_core_clock(void);
void cg_setup_external_hosc(void);
void cg_setup_pll(void);
void cg_ihosc1_disable(void);
void Set_CG_STBY_value(uint32_t mode);
void Get_param_CG_WUEF(void);
void Set_param_CG_WUCLK(void);
void Set_CG_EOSC_WUPT_value(void);
void Set_CG_IOSC_WUPT_value(void);
void Set_param_CG_WUON(void);
void disable_PLL (void);
void enable_IHOSC1(void);
void disable_EHOSC(void);
void enable_IHOSC2(void);
void disable_IHOSC2(void);
uint32_t Get_CG_EOSCEN_value(void);
bool Get_param_CG_IHOSC2F(void);
bool Get_param_CG_IHOSC2EN(void);

/**
 *  @}
 */ /* End of group RDA_CG_M4K2_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_CG_M4K2 */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDA_CG_M4K2_E_H */


