/**
 *******************************************************************************
 * @file    rda_crc_a.c
 * @brief   This file provides API functions for CRC rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "crc.h"

#if defined(__CRC_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_CRC RDA_CRC
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_config RDA_CRC Private Config
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group RDA_CRC_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_define RDA_CRC Private Define
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_enum RDA_CRC Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_typedef RDA_CRC Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                         */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_variable RDA_CRC Private Variable
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_fuctions RDA_CRC Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/**
  * @brief     CRC_Config
  * @param     init_crctyp , init_crcclc
  * @note      -
  */
/*--------------------------------------------------*/
void CRC_Config(uint32_t init_crctyp , uint32_t init_crcclc)
{
    TSB_CRC->TYP = init_crctyp;
    TSB_CRC->CLC = init_crcclc;
}

/*--------------------------------------------------*/
/**
  * @brief     CRC_calculation
  * @param     top_memory , size_meomory
  * @note      -
  */
/*--------------------------------------------------*/
void CRC_calculation(uint32_t top_memory , uint32_t size_memory)
{
    uint32_t i;
    uint8_t *ptr;
    uint32_t length;
    uint32_t reg, work;
    
    ptr = (uint8_t *)top_memory;
    length = size_memory;
    work = 0x00;
    for( i=0; i < length; ++i )
    {
        work = ((work << 8U) | ((uint32_t)*ptr));
        ptr++;
        if( (i % 4) == 3 )
        {
            TSB_CRC->DIN = work;
             work = 0x00;
        }
    }
    if( (length % 4 ) == 0 )
    {
        /* no process */
    }
    else if( (length % 4 ) == 1 )
    {
        reg = (TSB_CRC->TYP & 0x0000000C);
        TSB_CRC->TYP = (reg | CRCTYP_DBIT_8BIT);
        TSB_CRC->DIN = work;
    }
    else if( (length % 4 ) == 2 )
    {
        reg = (TSB_CRC->TYP & 0x0000000C);
        TSB_CRC->TYP = (reg | CRCTYP_DBIT_16BIT);
        TSB_CRC->DIN = work;
    }
    else if( (length % 4 ) == 3 )
    {
        uint32_t work2 = work >> 8U;
        reg = (TSB_CRC->TYP & 0x0000000C);
        TSB_CRC->TYP = (reg | CRCTYP_DBIT_16BIT);
        TSB_CRC->DIN = work2;
        work2 = work & 0xFFU;
        reg = (TSB_CRC->TYP & 0x0000000C);
        TSB_CRC->TYP = (reg | CRCTYP_DBIT_8BIT);
        TSB_CRC->DIN = work2;
    }
}

/*--------------------------------------------------*/
/**
  * @brief     CRC_OneTime_calc
  * @param     top_memory , size_meomory
  * @note      -
  */
/*--------------------------------------------------*/
void CRC_OneTime_calc(uint32_t crctyp_dbit , uint32_t data)
{
    uint32_t    reg;
    
    reg = (TSB_CRC->TYP & 0x0000000C);
    TSB_CRC->TYP = (reg | crctyp_dbit);
    TSB_CRC->DIN = data;
}

/*--------------------------------------------------*/
/**
  * @brief     CRC_calculation
  * @param     -
  * @return    clc[1]
  * @note      -
  */
/*--------------------------------------------------*/
uint32_t Get_CRC_CLC_value(void)
{
    uint32_t clc[2];

    clc[0] = TSB_CRC->CLC;
    clc[1] = TSB_CRC->CLC;

    return (clc[1]);
}


/* Self-Diagnosis */
/*--------------------------------------------------*/
/**
  * @brief     MEMORY_CRC_calc
  * @param     -
  * @return    Get_CRC_CLC_value
  * @note      -
  */
/*--------------------------------------------------*/
uint32_t MEMORY_CRC_calc(uint32_t bg_addr, uint32_t mem_size, uint32_t typ_val, uint32_t clc_val)
{

    uint8_t     *p;
    uint32_t    clc_result = 0;

    TSB_CRC->TYP = typ_val;
    TSB_CRC->CLC = clc_val;
    
    for( p = (uint8_t *)bg_addr; mem_size > 0; p++, mem_size--)
    {
        TSB_CRC->DIN = (uint32_t)(*p & 0xff);
    }

    clc_result = TSB_CRC->CLC;
    clc_result = TSB_CRC->CLC;  /* read twice */

    return (clc_result);
}

/**
 *  @}
 */ /* End of group RDA_CRC_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_CRC */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__CRC_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

