/** 
 *******************************************************************************
 * @file    rda_crc_a.h
 * @brief   This file provides rda_crc definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_CRC_A_H
#define __RDA_CRC_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_CRC RDA_CRC
 *  @brief    CRC Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDC_CRC_Private_define RDA_CRC Private Define
 *  @{
 */

/** 
 *  @name  CRCTYP CRCTYP Macro Definition.
 *  @brief CRCTYP Register Macro Definition.
 *  @{
 */
#define CRCTYP_CFMT_CRC16       ((uint32_t)0x00000000)      /*!< CFMT=00 */
#define CRCTYP_CFMT_CRC32       ((uint32_t)0x0000000C)      /*!< CFMT=11 */

#define CRCTYP_DBIT_32BIT       ((uint32_t)0x00000000)      /*!< DBIT=00 */
#define CRCTYP_DBIT_8BIT        ((uint32_t)0x00000001)      /*!< DBIT=01 */
#define CRCTYP_DBIT_16BIT       ((uint32_t)0x00000002)      /*!< DBIT=10 */
#define CRCTYP_DBIT_11          ((uint32_t)0x00000003)      /*!< DBIT=11 */
/**
 *  @}
 */ /* End of name CRCTYP Macro Definition */
 
/** 
 *  @name  CRCCLC CRCCLC Macro Definition.
 *  @brief CRCCLC Register Macro Definition.
 *  @{
 */
#define CRCCLC_CRC16_INIT       ((uint32_t)0x0000FFFF)
#define CRCCLC_CRC32_INIT       ((uint32_t)0xFFFFFFFF)
/**
 *  @}
 */ /* End of name CRCCLC Macro Definition */

/** 
 *  @}
 */ /* End of group RDC_CRC_Private_define */

/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_enum RDA_CRC Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Private_typedef RDA_CRC Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_CRC_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_CRC_Exported_functions RDA_CRC Exported Functions
 *  @{
 */
void CRC_Config(uint32_t , uint32_t);
void CRC_calculation(uint32_t , uint32_t);
void CRC_OneTime_calc(uint32_t , uint32_t);
uint32_t Get_CRC_CLC_value(void);

/* Self-Diagnosis */
uint32_t MEMORY_CRC_calc(uint32_t , uint32_t , uint32_t , uint32_t);

/**
 *  @}
 */ /* End of group RDA_CRC_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_CRC */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_CRC_A_H */


