/** 
 *******************************************************************************
 * @file    rda_dnf_a.h
 * @brief   This file provides rda_dnf definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_DNF_A_H
#define __RDA_DNF_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_DNF RDA_DNF
 *  @brief    DNF Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_DNF_Private_define RDA_DNF Private Define
 *  @{
 */

/** 
 *  @addtogroup NFCKCR_NFCKS NFCKS
 *  @brief    [Bit2-0]: Noise Filter Clock Select.
 *  @{
 */
#define DNF_NFCKCR_NFCKS_STOP           ((uint32_t)0x00000000)        /*!< Clock Control circuit stop.                                       */
#define DNF_NFCKCR_NFCKS_CLOCK_2        ((uint32_t)0x00000001)        /*!< fc/2   fc=20MHz: 0.7us 40MHz: 0.35us 80MHz: 0.175us 100MHz:0.14us */
#define DNF_NFCKCR_NFCKS_CLOCK_4        ((uint32_t)0x00000002)        /*!< fc/4   fc=20MHz: 1.4us 40MHz: 0.7us  80MHz: 0.35us  100MHz:0.28us */
#define DNF_NFCKCR_NFCKS_CLOCK_8        ((uint32_t)0x00000003)        /*!< fc/8   fc=20MHz: 2.8us 40MHz: 1.4us  80MHz: 0.7us   100MHz:0.56us */
#define DNF_NFCKCR_NFCKS_CLOCK_16       ((uint32_t)0x00000004)        /*!< fc/16  fc=20MHz: 5.6us 40MHz: 2.8us  80MHz: 1.4us   100MHz:1.12us */
#define DNF_NFCKCR_NFCKS_CLOCK_32       ((uint32_t)0x00000005)        /*!< fc/32  fc=20MHz:11.2us 40MHz: 5.6us  80MHz: 2.8us   100MHz:2.24us */
#define DNF_NFCKCR_NFCKS_CLOCK_64       ((uint32_t)0x00000006)        /*!< fc/64  fc=20MHz:22.4us 40MHz:11.2us  80MHz: 5.6us   100MHz:4.48us */
#define DNF_NFCKCR_NFCKS_CLOCK_128      ((uint32_t)0x00000007)        /*!< fc/128 fc=20MHz:44.8us 40MHz:22.4us  80MHz:11.2us   100MHz:8.96us */
/**
 *  @}
 */ /* End of group NFCKCR_NFCKS */

/**
 *  @}
 */ /* End of group RDA_DNF_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_DNF_Private_enum RDA_DNF Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_DNF_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_DNF_Private_typedef RDA_DNF Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_DNF_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_DNF_Exported_functions RDA_DNF Exported Functions
 *  @{
 */
 
void DNF_B_Config(void);
void DNF_C_Config(uint32_t nfckcr);

/**
 *  @}
 */ /* End of group RDA_DNF_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_DNF */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_DNF_A_H */


