/**
 *******************************************************************************
 * @file    rda_ei2c_a.c
 * @brief   This file provides API functions for EI2C rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "ei2c.h"

#if defined(__EI2C_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/* no define */

/** 
 *  @addtogroup RDA_EI2C RDA_EI2C
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_config RDA_EI2C Private Config
 *  @{
 */

/** 
 *  @}
 */ /* End of group RDA_EI2C_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_define RDA_EI2C Private Define
 *  @{
 */
 
#define EI2CSCL_FRQ_STD       ((uint32_t)100000)  /*!< STD  100kHz             */
#define EI2CSCL_FRQ_FM        ((uint32_t)400000)  /*!< Fm   400kHz             */
#define EI2CSCL_FRQ_FMP       ((uint32_t)1000000) /*!< Fm+ 1000kHz             */
#define EI2CSCL_SCLH_STDMIN   ((uint32_t)4000)    /*!< SCLH  STD MIN           */
#define EI2CSCL_SCLH_FMMIN    ((uint32_t)600)     /*!< SCLH  FM  MIN           */
#define EI2CSCL_SCLH_FMPMIN   ((uint32_t)260)     /*!< SCLH  FMP MIN           */
#define EI2CSCL_SCLL_STDMIN   ((uint32_t)4700)    /*!< SCLL  STD MIN           */
#define EI2CSCL_SCLL_FMMIN    ((uint32_t)1300)    /*!< SCLL  FM  MIN           */
#define EI2CSCL_SCLL_FMPMIN   ((uint32_t)500)     /*!< SCLL  FMP MIN           */
#define EI2CSCL_TR_STD        ((uint32_t)1000)    /*!< TR  STD MAX(100000)     */
#define EI2CSCL_TF_STD        ((uint32_t)300)     /*!< TF  STD MAX(100000)     */
#define EI2CSCL_TR_FM         ((uint32_t)300)     /*!< TR  FM  MAX(400000)     */
#define EI2CSCL_TF_FM         ((uint32_t)300)     /*!< TF  FM  MAX(400000)     */
#define EI2CSCL_TR_FMP        ((uint32_t)120)     /*!< TR  FMP MAX(1000000)    */
#define EI2CSCL_TF_FMP        ((uint32_t)120)     /*!< TF  FMP MAX(1000000)    */

/** 
 *  @name  EI2CxARST Macro Definition.
 *  @brief EI2CxARST Register Macro Definition.
 *  @{
 */
#define EI2CxARST_SWRES_10       ((uint32_t)0x00000002)    /*!< SWRES=10                */
#define EI2CxARST_SWRES_01       ((uint32_t)0x00000001)    /*!< SWRES=01                */
/**
 *  @}
 */ /* End of name EI2CxARST Macro Definition */
 
 
/** 
 *  @name  EI2CxCR0_DNF Macro Definition.
 *  @brief EI2CxCR0_DNF Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_DNF_1PRSCK      ((uint32_t)0x00000000)     /*!< 1PRSCK                */
#define EI2CxCR0_DNF_2PRSCK      ((uint32_t)0x00001000)     /*!< 2PRSCK                */
#define EI2CxCR0_DNF_3PRSCK      ((uint32_t)0x00002000)     /*!< 3PRSCK                */
#define EI2CxCR0_DNF_4PRSCK      ((uint32_t)0x00003000)     /*!< 4PRSCK                */
#define EI2CxCR0_DNF_5PRSCK      ((uint32_t)0x00004000)     /*!< 5PRSCK                */
#define EI2CxCR0_DNF_6PRSCK      ((uint32_t)0x00005000)     /*!< 6PRSCK                */
#define EI2CxCR0_DNF_NA7         ((uint32_t)0x00006000)     /*!< NA7(the same with 00) */
#define EI2CxCR0_DNF_NA8         ((uint32_t)0x00007000)     /*!< NA8(the same with 00) */
#define EI2CxCR0_DNF_MASK        ((uint32_t)0x0000F000)     /*!<                       */

/**
 *  @}
 */ /* End of name EI2CxCR0_DNF Macro Definition */
 
/** 
 *  @name  EI2CxCR0_NFSEL Macro Definition.
 *  @brief EI2CxCR0_NFSEL Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_NFSEL_DIG       ((uint32_t)0x00000000)     /*!< Digtal noise filter   */
#define EI2CxCR0_NFSEL_ANA       ((uint32_t)0x00000800)     /*!< Analog noise filter   */
/**
 *  @}
 */ /* End of name EI2CxCR0_NFSEL Macro Definition */
 
/** 
 *  @name  EI2CxCR0_TOPER Macro Definition.
 *  @brief EI2CxCR0_TOPER Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_TOPER_1PRSCK    ((uint32_t)0x00000000)     /*!< timeout 2*13 PRSCK   */
#define EI2CxCR0_TOPER_2PRSCK    ((uint32_t)0x00000200)     /*!< timeout 2*14 PRSCK   */
#define EI2CxCR0_TOPER_3PRSCK    ((uint32_t)0x00000400)     /*!< timeout 2*15 PRSCK   */
#define EI2CxCR0_TOPER_4PRSCK    ((uint32_t)0x00000600)     /*!< timeout 2*16 PRSCK   */
/**
 *  @}
 */ /* End of name EI2CxCR0_TOPER Macro Definition */
 
 /** 
 *  @name  EI2CxCR0_TOE Macro Definition.
 *  @brief EI2CxCR0_TOE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_TOE_ENABLE     ((uint32_t)0x00000100)     /*!< timeout Enable        */
#define EI2CxCR0_TOE_DISABLE    ((uint32_t)0x00000000)     /*!< timeout Disable       */
/**
 *  @}
 */ /* End of name EI2CxCR0_TOE Macro Definition */
 
/** 
 *  @name  EI2CxCR0_ESPE Macro Definition.
 *  @brief EI2CxCR0_ESPE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_ESPE_ENABLE    ((uint32_t)0x00000010)     /*!< error stop condition Enable  */
#define EI2CxCR0_ESPE_DISABLE   ((uint32_t)0x00000000)     /*!< error stop condition Disable */
/**
 *  @}
 */ /* End of name EI2CxCR0_ESPE Macro Definition */

/** 
 *  @name  EI2CxCR0_ESTE Macro Definition.
 *  @brief EI2CxCR0_ESTE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_ESTE_ENABLE    ((uint32_t)0x00000008)     /*!< error start condition Enable  */
#define EI2CxCR0_ESTE_DISABLE   ((uint32_t)0x00000000)     /*!< error start condition Disable */
/**
 *  @}
 */ /* End of name EI2CxCR0_ESTE Macro Definition */
 
/** 
 *  @name  EI2CxCR0_NACKE Macro Definition.
 *  @brief EI2CxCR0_NACKE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_NACKE_ENABLE    ((uint32_t)0x00000004)     /*!< NACK Check Enable           */
#define EI2CxCR0_NACKE_DISABLE   ((uint32_t)0x00000000)     /*!< NACK Check Disable          */
/**
 *  @}
 */ /* End of name EI2CxCR0_NACKE Macro Definition */
 
 
/** 
 *  @name  EI2CxCR0_GCE Macro Definition.
 *  @brief EI2CxCR0_GCE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_GCE_ENABLE      ((uint32_t)0x00000002)     /*!< General call Enable         */
#define EI2CxCR0_GCE_DISABLE     ((uint32_t)0x00000000)     /*!< General call Disable        */
/**
 *  @}
 */ /* End of name EI2CxCR0_GCE Macro Definition */
 
 
/** 
 *  @name  EI2CxCR0_ALE Macro Definition.
 *  @brief EI2CxCR0_ALE Register Macro Definition.
 *  @{
 */
#define EI2CxCR0_ALE_ENABLE      ((uint32_t)0x00000001)     /*!< Arbitration lost Enable     */
#define EI2CxCR0_ALE_DISABLE     ((uint32_t)0x00000000)     /*!< Arbitration lost Disable    */
/**
 *  @}
 */ /* End of name EI2CxCR0_ALE Macro Definition */

/** 
 *  @name  EI2C Macro Definition.
 *  @brief EI2C frequency Macro Definition.
 *  @{
 */
#define EI2C_UNUSE_VALUE        ((uint32_t)0xFFFFFFFF)       /*!< UNUSE Value             */
#define EI2C_UNIT_1US           ((uint32_t)1000000)          /*!< 1S=1000000us            */
/**
 *  @}
 */ /* End of name EI2C Definition */



/** 
 *  @name  EI2CxSR1 Macro Definition.
 *  @brief EI2CxSR1 Register Macro Definition.
 *  @{
 */
#define EI2CxSR1_TOERR          ((uint32_t)0x00002000)       /*!< Timeout error.               */
#define EI2CxSR1_ESP            ((uint32_t)0x00001000)       /*!< Error stop condition         */
#define EI2CxSR1_EST            ((uint32_t)0x00000800)       /*!< Error start condition        */
#define EI2CxSR1_AAS2           ((uint32_t)0x00000400)       /*!< The same NO2 address flag    */
#define EI2CxSR1_AAS1           ((uint32_t)0x00000200)       /*!< The same NO1 address flag    */
#define EI2CxSR1_GC             ((uint32_t)0x00000100)       /*!< General call check flag      */
#define EI2CxSR1_AL             ((uint32_t)0x00000080)       /*!< Arbitration lost flag        */
#define EI2CxSR1_NACK           ((uint32_t)0x00000040)       /*!< NACK check flag              */
#define EI2CxSR1_RBF            ((uint32_t)0x00000020)       /*!< Receive buffer full          */
#define EI2CxSR1_TBE            ((uint32_t)0x00000010)       /*!< Transmit buffer empty        */
#define EI2CxSR1_TEND           ((uint32_t)0x00000008)       /*!< Transmit over flag           */
#define EI2CxSR1_SPCF           ((uint32_t)0x00000004)       /*!< Stop Condition check flag    */
#define EI2CxSR1_RSCF           ((uint32_t)0x00000002)       /*!< ReStart Condition check flag */
#define EI2CxSR1_STCF           ((uint32_t)0x00000001)       /*!< Start Condition check flag   */
#define EI2CxSR1_CLEAR          ((uint32_t)0x00003FFF)       /*!< Clear INT status             */

/**
 *  @}
 */ /* End of name EI2CxSR1 Macro Definition */
 
 /** 
 *  @name  EI2CxPRS Macro Definition.
 *  @brief EI2CxPRS Register Macro Definition.
 *  @{
 */
#define EI2CxPRS_PRCK            ((uint32_t)0x0000001F)     /*!< PRCK                    */
#define EI2CxPRS_MAX             ((uint32_t)64)             /*!< PRCK MAX                */
/**
 *  @}
 */ /* End of name EI2CxPRS Macro Definition */

 /** 
 *  @name  EI2CxSCL Macro Definition.
 *  @brief EI2CxSCL Register Macro Definition.
 *  @{
 */
#define EI2CxSCL_SCL_MASK        ((uint32_t)0x000000FF)     /*!< SCLH SCLL MASK         */
#define EI2CxSCL_MAX             ((uint32_t)0xFF)           /*!< SCLH SCLL  Max size    */
/**
 *  @}
 */ /* End of name EI2CxSCL Macro Definition */
 
/** 
 *  @name  EI2CxAR1 Macro Definition.
 *  @brief EI2CxAR1 Register Macro Definition.
 *  @{
 */
#define EI2CxAR1_INT            ((uint32_t)0x00000000)      /*!< Initial Settings.     */
#define EI2CxAR1_SAFS1_7BIT     ((uint32_t)0x00000000)      /*!< 7Bit Address Format.  */
#define EI2CxAR1_SAFS1_10BIT    ((uint32_t)0x00008000)      /*!< 10Bit Address Format. */
#define EI2CxAR1_SAFS1_MASK     ((uint32_t)0x00008000)      /*!< Get Address Format    */
#define EI2CxAR1_SA1_7BITMASK   ((uint32_t)0x000000FE)      /*!< 7Bit Address MASK.    */
#define EI2CxAR1_SA1_10BITMASK  ((uint32_t)0x000007FE)      /*!< 10Bit Address MASK.   */
#define EI2CxAR1_SA1E_ENABLE    ((uint32_t)0x00000001)      /*!< No1 Slave Add Enable. */
#define EI2CxAR1_SA1E_DISABLE   ((uint32_t)0x00000000)      /*!< No1 Slave Add Disable.*/
#define EI2CxAR1_SA1E_MASK      ((uint32_t)0x00000001)      /*!< Get Slave Add Status  */

/**
 *  @}
 */ /* End of name EI2CxAR1 Macro Definition */

/** 
 *  @name  EI2CxAR2 Macro Definition.
 *  @brief EI2CxAR2 Register Macro Definition.
 *  @{
 */
#define EI2CxAR2_INT            ((uint32_t)0x00000000)      /*!< Initial Settings.     */
#define EI2CxAR2_SAFS2_7BIT     ((uint32_t)0x00000000)      /*!< 7Bit Address Format.  */
#define EI2CxAR2_SAFS2_10BIT    ((uint32_t)0x00008000)      /*!< 10Bit Address Format. */
#define EI2CxAR2_SAFS2_MASK     ((uint32_t)0x00008000)      /*!< Get Address Format    */
#define EI2CxAR2_SA2_7BITMASK   ((uint32_t)0x000000FE)      /*!< 7Bit Address MASK.    */
#define EI2CxAR2_SA2_10BITMASK  ((uint32_t)0x000007FE)      /*!< 10Bit Address MASK.   */
#define EI2CxAR2_SA2E_ENABLE    ((uint32_t)0x00000001)      /*!< No2 Slave Add Enable. */
#define EI2CxAR2_SA2E_DISABLE   ((uint32_t)0x00000000)      /*!< No2 Slave Add Disable.*/
#define EI2CxAR2_SA2E_MASK      ((uint32_t)0x00000001)      /*!< Get Slave Add Status  */

/**
 *  @}
 */ /* End of name EI2CxAR2 Macro Definition */
 
/**
 *  @}
 */ /* End of group RDA_EI2C_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_enum RDA_EI2C Private Enum
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_EI2C_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_typedef RDA_EI2C Private Typedef
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_EI2C_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C__Private_variables RDA_EI2C_ Private Variables
 *  @{
 */


/**
 *  @}
 */ /* End of group EI2C_MasterSlave_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_variable RDA_EI2C Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_EI2C_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Exported_fuctions RDA_EI2C Exported Fuctions
 *  @{
 */



/*--------------------------------------------------*/
/** 
  * @brief  EI2C1_Master_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void EI2C1_Master_Config(void)
{
    EI2C1_Config(MODE_MASTER);
}

/*--------------------------------------------------*/
/** 
  * @brief  EI2C1_Slave_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void EI2C1_Slave_Config(void)
{
    EI2C1_Config(MODE_SLAVE);
}

/*--------------------------------------------------*/
/** 
  * @brief  EI2C1_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void EI2C1_Config(Mode mode)
{    
    /* EI2C I2CM Disable      */
    TSB_EI2C1_AEN_I2CM = 0;
    
    /* EI2C ASR1 All Clear    */
    TSB_EI2C1->ASR1 = EI2CxSR1_TOERR |
                      EI2CxSR1_ESP   |
                      EI2CxSR1_EST   |
                      EI2CxSR1_AAS2  |
                      EI2CxSR1_AAS1  |
                      EI2CxSR1_GC    |
                      EI2CxSR1_AL    |
                      EI2CxSR1_NACK  |
                      EI2CxSR1_RBF   |
                      EI2CxSR1_TBE   |
                      EI2CxSR1_TEND  |
                      EI2CxSR1_SPCF  |
                      EI2CxSR1_RSCF  |
                      EI2CxSR1_STCF  ;

    if ( NOISE_FILTER_SEL == EI2CxCR0_NFSEL_DIG )
    {
      TSB_EI2C1->ACR0 = EI2CxCR0_DNF_3PRSCK    |
                        EI2CxCR0_NFSEL_DIG     |
                        EI2CxCR0_TOPER_4PRSCK  |
                        EI2CxCR0_TOE_DISABLE   |
                        EI2CxCR0_ESPE_ENABLE   |
                        EI2CxCR0_ESTE_ENABLE   |
                        EI2CxCR0_NACKE_ENABLE  |
                        EI2CxCR0_GCE_ENABLE    |
                        EI2CxCR0_ALE_ENABLE    ;
    }
    else
    {
      TSB_EI2C1->ACR0 = EI2CxCR0_DNF_3PRSCK    |
                        EI2CxCR0_NFSEL_ANA     |
                        EI2CxCR0_TOPER_4PRSCK  |
                        EI2CxCR0_TOE_DISABLE   |
                        EI2CxCR0_ESPE_ENABLE   |
                        EI2CxCR0_ESTE_ENABLE   |
                        EI2CxCR0_NACKE_DISABLE |
                        EI2CxCR0_GCE_ENABLE    |
                        EI2CxCR0_ALE_ENABLE    ;
    }

    if ( NOISE_FILTER_SEL == EI2CxCR0_NFSEL_DIG ){
        ei2c_set_prs_scl_dig(FREQUENCY);
    }else{
        ei2c_set_prs_scl_ana(FREQUENCY);
    }
    
    if( mode == MODE_SLAVE )
    {
        if(SLAVE_ADDRESS_FMT == EI2CxAR1_SAFS1_7BIT)
        {
            TSB_EI2C1->AAR1 = EI2CxAR1_SAFS1_7BIT |
                            (( SLAVE_ADDRESS & EI2CxAR1_SA1_7BITMASK ) << 1) |
                            EI2CxAR1_SA1E_ENABLE;
        }
        else
        {
            TSB_EI2C1->AAR1 = EI2CxAR1_SAFS1_10BIT |
                            (( SLAVE_ADDRESS & EI2CxAR1_SA1_10BITMASK) << 1) |
                            EI2CxAR1_SA1E_ENABLE;
        }
    }
    else
    {
    }
    
    /* EI2C APM Enable      */
    while(  ( TSB_EI2C1_APM_SDA != 1 )
          ||( TSB_EI2C1_APM_SCL != 1 )){;}
    
    /* EI2C I2CM Enable      */
    TSB_EI2C1_AEN_I2CM = 1;
}


/*--------------------------------------------------*/
/**
  * @brief     Return the EI2c clock setting
  * @param     frequency   :Maximum frequency.
  * @param     fsys        :SystemCoreClock.
  * @param     p_setting   :Clock data pointer.
  * @retval    Non-zero    :Scl frequency.
  * @retval    0           :Error.
  * @note      -
  */
/*--------------------------------------------------*/
TXZ_Result ei2c_set_prs_scl_dig(uint32_t frequency)
{
    TXZ_Result result;
    
    int32_t  sclh_tmp,scll_tmp,prs_tmp;
    uint32_t t_total,t_high,t_low;
    uint32_t high_width_min,scl_tf;
    uint32_t low__width_min,scl_tr;
    
    uint32_t fsys = SystemCoreClock;
    uint8_t  dnf  = ei2c_get_dnf_num(TSB_EI2C1->ACR0 & EI2CxCR0_DNF_MASK);
    
    /* unuse value init */
    uint32_t prs  = EI2C_UNUSE_VALUE;
    uint32_t sclh = EI2C_UNUSE_VALUE;
    uint32_t scll = EI2C_UNUSE_VALUE;
    
    if(frequency <= EI2CSCL_FRQ_FMP)
    {
        /* STD */
        if(frequency <= EI2CSCL_FRQ_STD)
        {
            high_width_min = EI2CSCL_SCLH_STDMIN;
            low__width_min = EI2CSCL_SCLL_STDMIN;
            scl_tf         = EI2CSCL_TF_STD;
            scl_tr         = EI2CSCL_TR_STD;
        }
        /* FM */
        else if(frequency <= EI2CSCL_FRQ_FM)
        {
            high_width_min = EI2CSCL_SCLH_FMMIN;
            low__width_min = EI2CSCL_SCLL_FMMIN;
            scl_tf         = EI2CSCL_TF_FM;
            scl_tr         = EI2CSCL_TR_FM;
        }
        /* FMP */
        else
        {
            high_width_min = EI2CSCL_SCLH_FMPMIN;
            low__width_min = EI2CSCL_SCLL_FMPMIN;
            scl_tf         = EI2CSCL_TF_FMP;
            scl_tr         = EI2CSCL_TR_FMP;
        }

        /*---------------------------------------------------------*/
        /* freq(hz)=(1/(tHIGH(ns)+tLOW(ns)+tr(ns)+tf(ns)))*(10^9)  */
        /* tHIGH(ns)+tLOW(ns)=(10^9/freq(hz))-tr(ns)-tf(ns)        */
        /*---------------------------------------------------------*/
        t_total = (EI2C_UNIT_1US*1000/frequency) - scl_tf - scl_tr;

        /* if small than min return */
        if( t_total < (high_width_min + low__width_min) )
        {
            result = TXZ_ERROR;
            return result;
        }

        for( prs_tmp = 0; prs_tmp < EI2CxPRS_MAX; prs_tmp++ )
        {
            /*-----------------------------------------------*/
            /* clock width (s) = 1 / PCLK                    */
            /* clock width (s) = 1 / (fsys / PRS)            */
            /* clock width(ns) = (10^9) / (fsys / PRS)       */
            /*-----------------------------------------------*/
            /* NFSEL=0: (50ns/(<DNF>+1))<=clock width(ns)    */
            /*            <=(tHIGH(Min)/(<DNF>+2)            */
            /* ((10^9)*(<DNF>+2))/(tHIGH(Min) <= (fsys/PRS)  */
            /*            <=((10^9)*(<DNF>+1))/(50ns)        */
            /*-----------------------------------------------*/
            /* PRS: 1~64   DNF:1~6                           */
            /* (tHIGH(Min): Use @ref EI2CSCL_MAX             */
            /*-----------------------------------------------*/
            uint32_t prsck = ((uint32_t)fsys /((prs_tmp+1)*1000));

            if(   (prsck < ((EI2C_UNIT_1US/high_width_min)*(dnf+2)))
                ||(prsck > ((EI2C_UNIT_1US/50            )*(dnf+1))))
            {
                continue;
            }

            if(t_total == (high_width_min + low__width_min))
            {
                sclh_tmp = ((high_width_min*prsck)/EI2C_UNIT_1US) - 3 - dnf;
                scll_tmp = ((low__width_min*prsck)/EI2C_UNIT_1US) - 3 - dnf;

                /* paramater check */
                if(   ( sclh_tmp <= EI2CxSCL_MAX )
                    &&( scll_tmp <= EI2CxSCL_MAX ))
                {
                    prs  = prs_tmp;
                    sclh = sclh_tmp;
                    scll = scll_tmp;
                    break;
                }
            }
            else
            {
                /*-----------------------------------------------*/
                /* t_high(ns)=((SCLH+3+DNF)/prsck(Hz))*(10^9)    */
                /* t_low(ns) =((SCLL+3+DNF)/prsck(Hz))*(10^9)    */
                /* t_high(ns) + t_low(ns) = t_total              */
                /* t_high(ns)>= high_width_min                   */
                /* t_low(ns) >= low_width_min                    */
                /*-----------------------------------------------*/
                for( sclh_tmp = 0; sclh_tmp <= EI2CxSCL_MAX; sclh_tmp++ )
                {
                    t_high = ((sclh_tmp + dnf + 3)*EI2C_UNIT_1US)/prsck;
                    t_low  = t_total - t_high;

                    /*  paramater check */
                    if(   (t_high < high_width_min)
                        ||(t_low  < low__width_min))
                    {
                        continue;
                    }

                    scll_tmp = ((t_low*prsck)/EI2C_UNIT_1US) - 3 - dnf;

                    /* paramater check */
                    if(    ( scll_tmp >= 0            )
                        && ( scll_tmp <= EI2CxSCL_MAX ))
                    {
                        prs  = prs_tmp;
                        sclh = sclh_tmp;
                        scll = scll_tmp;
                        break;
                    }
                }
            }

            /*  when set over break the loop  */
            if(   (prs  != EI2C_UNUSE_VALUE)
                &&(sclh != EI2C_UNUSE_VALUE)
                &&(scll != EI2C_UNUSE_VALUE))
            {
                break;
            }
        }

        /* set the paramater value */
        TSB_EI2C1->APRS = prs;
        TSB_EI2C1->ASCL = (scll << 8 )|sclh;
        result = TXZ_SUCCESS;
    }
    else
    {
      result = TXZ_ERROR;
    }

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     Return the EI2c clock setting
  * @param     p_obj       :EI2C object.
  * @param     frequency   :Maximum frequency.
  * @param     fsys        :SystemCoreClock.
  * @param     p_setting   :Clock data pointer.
  * @retval    Non-zero    :Scl frequency.
  * @retval    0           :Error.
  * @note      -
  */
/*--------------------------------------------------*/
TXZ_Result ei2c_set_prs_scl_ana(uint32_t frequency)
{
    TXZ_Result result;
    
    int32_t  sclh_tmp,scll_tmp,prs_tmp;
    uint32_t t_total,t_high,t_low;
    uint32_t high_width_min,scl_tf;
    uint32_t low__width_min,scl_tr;
    
    uint32_t fsys = SystemCoreClock;
    
    /* unuse value init */
    uint32_t prs  = EI2C_UNUSE_VALUE;
    uint32_t sclh = EI2C_UNUSE_VALUE;
    uint32_t scll = EI2C_UNUSE_VALUE;
    
    if(frequency <= EI2CSCL_FRQ_FMP)
    {
        /* STD */
        if(frequency <= EI2CSCL_FRQ_STD)
        {
            high_width_min = EI2CSCL_SCLH_STDMIN;
            low__width_min = EI2CSCL_SCLL_STDMIN;
            scl_tf          = EI2CSCL_TF_STD;
            scl_tr         = EI2CSCL_TR_STD;
        }
        /* FM */
        else if(frequency <= EI2CSCL_FRQ_FM)
        {
            high_width_min = EI2CSCL_SCLH_FMMIN;
            low__width_min = EI2CSCL_SCLL_FMMIN;
            scl_tf         = EI2CSCL_TF_FM;
            scl_tr         = EI2CSCL_TR_FM;
        }
        /* FMP */
        else
        {
            high_width_min = EI2CSCL_SCLH_FMPMIN;
            low__width_min = EI2CSCL_SCLL_FMPMIN;
            scl_tf         = EI2CSCL_TF_FMP;
            scl_tr         = EI2CSCL_TR_FMP;
        }

        /*---------------------------------------------------------*/
        /* freq(hz)=(1/(tHIGH(ns)+tLOW(ns)+tr(ns)+tf(ns)))*(10^9)  */
        /* tHIGH(ns)+tLOW(ns)=(10^9/freq(hz))-tr(ns)-tf(ns)        */
        /*---------------------------------------------------------*/
        t_total = (EI2C_UNIT_1US*1000/frequency) - scl_tf - scl_tr;

        /* if small than min return */
        if(t_total < (high_width_min + low__width_min))
        {
            result = TXZ_ERROR;
            return result;
        }

        for( prs_tmp = 0; prs_tmp < EI2CxPRS_MAX; prs_tmp++ )
        {
            /*-----------------------------------------------*/
            /* clock width (s) = 1 / PRSCK                   */
            /* clock width (s) = 1 / (fsys /(PRS+1))         */
            /* clock width(ns) = (10^9) / (fsys/(PRS+1))     */
            /*-----------------------------------------------*/
            /* NFSEL=1: clock width(ns)<= (tHIGH(Min)/2)     */
            /* ((10^9)*2)/(tHIGH(Min)) <= (fsys/(PRS+1))     */
            /*-----------------------------------------------*/
            /* PRS: 0~63                                     */
            /* (tHIGH(Min): Use @ref EI2CSCL_MAX             */
            /*-----------------------------------------------*/
            uint32_t prsck = ((uint32_t)fsys /((prs_tmp+1)*1000));

            if(prsck < ((EI2C_UNIT_1US*2)/high_width_min))
            {
                continue;
            }

            for( sclh_tmp = 0; sclh_tmp <= EI2CxSCL_MAX; sclh_tmp++ )
            {
                t_high = ((sclh_tmp + 2)*EI2C_UNIT_1US)/prsck;
                t_low  = t_total - t_high;

                /*  paramater chec */
                if(   (t_high < high_width_min )
                    ||(t_low  < low__width_min ))
                {
                    continue;
                }

                scll_tmp = (t_low*prsck)/EI2C_UNIT_1US - 2;

                /*  paramater chec */
                if(   ( scll_tmp >= 0            )
                    &&( scll_tmp <= EI2CxSCL_MAX ))
                {
                    prs  = prs_tmp;
                    sclh = sclh_tmp;
                    scll = scll_tmp;
                    break;
                }
            }

            /* when set over break the loop */
            if(   (prs  != EI2C_UNUSE_VALUE)
                &&(sclh != EI2C_UNUSE_VALUE)
                &&(scll != EI2C_UNUSE_VALUE))
            {
                break;
            }
        }

        /* set the paramater value */
        TSB_EI2C1->APRS = prs;
        TSB_EI2C1->ASCL = (scll << 8 )|sclh;
        result = TXZ_SUCCESS;
    }
    else
    {
        result = TXZ_ERROR;
    }

    return (result);
}

/*--------------------------------------------------*/
/**
  * @brief     Return the EI2c clock setting
  * @param     p_obj       :EI2C object.
  * @param     frequency   :Maximum frequency.
  * @param     fsys        :SystemCoreClock.
  * @param     p_setting   :Clock data pointer.
  * @retval    Non-zero    :Scl frequency.
  * @retval    0           :Error.
  * @note      -
  */
/*--------------------------------------------------*/
uint8_t ei2c_get_dnf_num(uint32_t dnf)
{
    uint8_t dnf_num = 0;
    
    switch(dnf)
    {
        case EI2CxCR0_DNF_1PRSCK:
        case EI2CxCR0_DNF_NA7:
        case EI2CxCR0_DNF_NA8:
            dnf_num =1;
            break;
            
        case EI2CxCR0_DNF_2PRSCK:
            dnf_num =2;
            break;
            
        case EI2CxCR0_DNF_3PRSCK:
            dnf_num =3;
            break;
            
        case EI2CxCR0_DNF_4PRSCK:
            dnf_num =4;
            break;
            
        case EI2CxCR0_DNF_5PRSCK:
            dnf_num =5;
            break;
            
        case EI2CxCR0_DNF_6PRSCK:
            dnf_num =6;
            break;
            
        default:
            dnf_num =0;
            break;
    }
    return dnf_num;
}

/*--------------------------------------------------*/
/** 
  * @fn     EI2C1_start_condition(void)
  * @brief  EI2C ch.1 start Condition
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void EI2C1_start_condition(void)
{
    /* Check the BUS busy  */
    while(TSB_EI2C1_ASR0_BB == 1){;}
    
    /* Stop Condition Request Clear  */
    TSB_EI2C1_ACR1_SP = 0;
    /* Returnal Start Condition Request Clear*/
    TSB_EI2C1_ACR1_RS = 0;
    /* Start Condition Request Set  */
    TSB_EI2C1_ACR1_ST = 1;
}

/*--------------------------------------------------*/
/** 
  * @fn     EI2C1_stop_condition(void)
  * @brief  EI2C ch.1 stop Condition
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void EI2C1_stop_condition(void)
{
    /* Check Master / Slave Moniter  */
    if(TSB_EI2C1_ASR0_MST == 1)
    {
        /* Stop Condition Request Set  */
        TSB_EI2C1_ACR1_SP = 1;  
    }
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_EI2C1_DBRT_value(uint8_t data)
  * @brief  EI2C ch.1 DataBufferRT value
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_EI2C1_DBRT_value(uint8_t data)
{
    /* Send data Set*/
    TSB_EI2C1->ADBRT = data;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_EI2C1_DBRR_value(void)
  * @brief  EI2C ch.1 Recive Buffer Full Flag
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_EI2C1_DBRR_value(void)
{
    uint8_t data;
    
    /* Recive data Get  */
    data = (uint8_t)(TSB_EI2C1->ADBRR);
    
    return ( data );
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_param_EI2C1_ACKWAIT(void)
  * @brief  EI2C ch.1 Ack Wait Set
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_param_EI2C1_ACKWAIT(void)
{
    /* Ack Wait Set      */
    TSB_EI2C1_ACR1_ACKWAIT = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_param_EI2C1_ACKSEL(void)
  * @brief  EI2C ch.1 Ack Wait Set
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_param_EI2C1_ACKSEL(void)
{
    /* NACK Output Set  */
    TSB_EI2C1_ACR1_ACKSEL = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_ESP(void)
  * @brief  EI2C ch.1 ESP Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_ESP(void)
{
    bool ret;
    
    /* ESP Check  */
    ret = TSB_EI2C1_ASR1_ESP;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_NACK(void)
  * @brief  EI2C ch.1 NACK Ditect Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_NACK(void)
{
    bool ret;
    
    /* NACK Ditect Check  */
    ret = TSB_EI2C1_ASR1_NACK;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_TEND(void)
  * @brief  EI2C ch.1 Transfer End Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_TEND(void)
{
    return ((TSB_EI2C1->ASR1 & 0x00000008) >> 3);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_STCF(void)
  * @brief  EI2C ch.1 Start Condition Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_STCF(void)
{
    bool ret;
    
    /* Start Condition Check  */
    ret = TSB_EI2C1_ASR1_STCF;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_SPCF(void)
  * @brief  EI2C ch.1 Stop Condition Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_SPCF(void)
{
    return ((TSB_EI2C1->ASR1 & 0x00000004) >> 2);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_TBE(void)
  * @brief  EI2C ch.1 SendBuffer Status Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_TBE(void)
{
    
    /* SendBuffer Status Check  */
    return ((TSB_EI2C1->ASR1 & 0x00000010) >> 4);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_BC(void)
  * @brief  EI2C ch.1 Bit Count Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_param_EI2C1_BC(void)
{
    uint8_t ret;
    
    /* Bit Count Check  */
    ret = ((TSB_EI2C1->ASR0 & 0x000000F0) >> 4) ;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_BB(void)
  * @brief  EI2C ch.1 Bus Status Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_BB(void)
{
    bool ret;
    
    /* Bus Status Check  */
    ret = TSB_EI2C1_ASR0_BB;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_ACKF(void)
  * @brief  EI2C ch.1 ACK Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_ACKF(void)
{
    bool ret;
    
    /* Bus Status Check  */
    ret = TSB_EI2C1_ASR0_ACKF;

    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_AAS1(void)
  * @brief  EI2C ch.1 AddressCoincide Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_AAS1(void)
{
    bool ret;
    
    /* AddressCoincide Check  */
    ret = TSB_EI2C1_ASR1_AAS1;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_EI2C1_RBF(void)
  * @brief  Recive Buffer Flag Check
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_EI2C1_RBF(void)
{
    bool ret;
    
    /* Recive Buffer Flag Check  */
    ret = TSB_EI2C1_ASR1_RBF;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_NACK(void)
  * @brief  EI2C ch.1 NACK Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_NACK(void)
{
    /* NACK Flag Clear  */
    TSB_EI2C1->ASR1 = EI2CxSR1_NACK;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_RBF(void)
  * @brief  EI2C ch.1 Receive Buffer Full Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_RBF(void)
{
    /* Receive Buffer Full Flag Clear  */
    TSB_EI2C1->ASR1 = EI2CxSR1_RBF;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_TBE(void)
  * @brief  EI2C ch.1 Transfer Buffer Empty Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_TBE(void)
{
    /* Transfer Buffer Empty Flag Clear  */
    TSB_EI2C1->ASR1 = EI2CxSR1_TBE;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_TEND(void)
  * @brief  EI2C ch.1 Transfer End Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_TEND(void)
{
    /* Transfer End Flag Clear  */
    TSB_EI2C1->ASR1 = EI2CxSR1_TEND;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_STCF(void)
  * @brief  EI2C ch.1 Start Condition Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_STCF(void)
{
    /* Start Condition Flag Clear  */
    TSB_EI2C1->ASR1 = EI2CxSR1_STCF;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_allflag_EI2C1_ASR1(void)
  * @brief  EI2C ch.1 ASR1 All Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_allflag_EI2C1_ASR1(void)
{
    /* EI2C ASR1 All Flag Clear    */
    TSB_EI2C1->ASR1 = EI2CxSR1_TOERR |
                      EI2CxSR1_ESP   |
                      EI2CxSR1_EST   |
                      EI2CxSR1_AAS2  |
                      EI2CxSR1_AAS1  |
                      EI2CxSR1_GC    |
                      EI2CxSR1_AL    |
                      EI2CxSR1_NACK  |
                      EI2CxSR1_RBF   |
                      EI2CxSR1_TBE   |
                      EI2CxSR1_TEND  |
                      EI2CxSR1_SPCF  |
                      EI2CxSR1_RSCF  |
                      EI2CxSR1_STCF  ; 
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_EI2C1_AAS1(void)
  * @brief  EI2C ch.1 ASR1 All Flag Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_EI2C1_AAS1(void)
{
    /* AddressCoincide Check Flag Clear    */
    TSB_EI2C1->ASR1 = EI2CxSR1_AAS1;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_EI2C1_ACR1(void)
  * @brief  EI2C ch.1 ACR1 All Clear
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_EI2C1_ACR1(void)
{
    /* AddressCoincide Check Flag Clear    */
    TSB_EI2C1->ACR1 = 0x00000000;
}

/*--------------------------------------------------*/
/** 
  * @fn     Enable_EI2C1_AAR1_SA1E(void)
  * @brief  EI2C ch.1 AAR1 SA1E Enable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Enable_EI2C1_AAR1_SA1E(void)
{
    /* Slave Addres 1 Enable    */
    TSB_EI2C1_AAR1_SA1E = 0x00000001;
}

/*--------------------------------------------------*/
/** 
  * @fn     Disable_EI2C1_AAR1_SA1E(void)
  * @brief  EI2C ch.1 AAR1 SA1E Disable
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Disable_EI2C1_AAR1_SA1E(void)
{
    /* Slave Addres 1 Disable    */
    TSB_EI2C1_AAR1_SA1E = 0x00000000;
}


/**
 *  @}
 */ /* End of group RDA_EI2C_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_EI2C */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__EI2C_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

