/** 
 *******************************************************************************
 * @file    rda_ei2c_a.h
 * @brief   This file provides rda_ei2c definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_EI2C_A_H
#define __RDA_EI2C_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_EI2C RDA_EI2C
 *  @brief    EI2C Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_define RDA_EI2C Private Define
 *  @{
 */

#define FREQUENCY            ((uint32_t)800000)    /*!< Fm   800kHz               */
#define NOISE_FILTER_SEL     EI2CxCR0_NFSEL_DIG    /*!< Digtal noise filter       */
#define SLAVE_ADDRESS        0x60
#define SLAVE_ADDRESS_FMT    EI2CxAR2_SAFS2_7BIT   /*!< 7Bit Address Format.      */

/**
 *  @}
 */ /* End of group RDA_EI2C_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_enum RDA_EI2C Private Enum
 *  @{
 */

/*----------------------------------*/
/** 
 * @brief  ei2c mode.
*/
/*----------------------------------*/
typedef enum
{
    MODE_INIT,
    MODE_MASTER,
    MODE_SLAVE
} Mode;

/**
 *  @}
 */ /* End of group RDA_EI2C_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Private_typedef RDA_EI2C Private Typedef
 *  @{
 */
#define FLAG_NOT_DETECT 0
#define FLAG_DETECT     1

#define BUS_FREE 0
#define BUS_BUSY 1

/**
 *  @}
 */ /* End of group RDA_EI2C_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EI2C_Exported_functions RDA_EI2C Exported Functions
 *  @{
 */
 
void EI2C1_Master_Config(void);
void EI2C1_Slave_Config(void);
void EI2C1_Config(Mode mode);
TXZ_Result ei2c_set_prs_scl_dig(uint32_t frequency);
TXZ_Result ei2c_set_prs_scl_ana(uint32_t frequency);
uint8_t ei2c_get_dnf_num(uint32_t dnf);
void EI2C1_start_condition(void);
void EI2C1_stop_condition(void);
void Set_EI2C1_DBRT_value(uint8_t data);
void Set_param_EI2C1_ACKWAIT(void);
void Set_param_EI2C1_ACKSEL(void);
uint8_t Get_EI2C1_DBRR_value(void);
bool Get_param_EI2C1_ESP(void);
bool Get_param_EI2C1_NACK(void);
bool Get_param_EI2C1_TEND(void);
bool Get_param_EI2C1_STCF(void);
bool Get_param_EI2C1_SPCF(void);
bool Get_param_EI2C1_TBE(void);
uint8_t Get_param_EI2C1_BC(void);
bool Get_param_EI2C1_BB(void);
bool Get_param_EI2C1_ACKF(void);
bool Get_param_EI2C1_AAS1(void);
bool Get_param_EI2C1_RBF(void);
void Clear_flag_EI2C1_NACK(void);
void Clear_flag_EI2C1_RBF(void);
void Clear_flag_EI2C1_TBE(void);
void Clear_flag_EI2C1_TEND(void);
void Clear_flag_EI2C1_STCF(void);
void Clear_flag_EI2C1_AAS1(void);
void Clear_allflag_EI2C1_ASR1(void);
void Clear_EI2C1_ACR1(void);
void Enable_EI2C1_AAR1_SA1E(void);
void Disable_EI2C1_AAR1_SA1E(void);

/**
 *  @}
 */ /* End of group RDA_EI2C_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_EI2C */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_EI2C_A_H */


