/**
 *******************************************************************************
 * @file    rda_except_m4k2_0p5.c
 * @brief   This file provides API functions for EXCEPT rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "except.h"

#if defined(__EXCEPT_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_EXCEPT_M4K2 RDA_EXCEPT_M4K2
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_config RDA_EXCEPT_M4K2 Private Config
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_define RDA_EXCEPT_M4K2 Private Define
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_enum RDA_EXCEPT_M4K2 Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_typedef RDA_EXCEPT_M4K2 Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_variable RDA_EXCEPT_M4K2 Private Variable
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_EXCEPT_M4K2_Private_fuctions RDA_EXCEPT_M4K2 Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/**
  * @brief     INT17a enable
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void INT17a_enable_IMC061(void)
{
    TSB_IB->IMC061 = 0x05;
}

/*--------------------------------------------------*/
/**
  * @brief     INT17b enable
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void INT17b_enable_IMC062(void)
{
    TSB_IB->IMC062 = 0x05;
}

/*--------------------------------------------------*/
/**
  * @brief     INT21 enable
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void INT21_enable_IMC069(void)
{
    TSB_IB->IMC069 = 0x07;
}

/*--------------------------------------------------*/
/**
  * @brief     Get INT016FLG
  * @param     -
  * @return    INTWDT0 interrupt flag
  * @note      -
  */
/*--------------------------------------------------*/
bool Get_param_INT016FLG(void)
{

    return (TSB_IMN_FLGNMI_INT016FLG);

}

/*--------------------------------------------------*/
/**
  * @brief     Get INT157FLG
  * @param     -
  * @return    INT17a interrupt flag
  * @note      -
  */
/*--------------------------------------------------*/
bool Get_param_INT157FLG(void)
{
    return (TSB_IMN_FLG4_INT157FLG);
}

/*--------------------------------------------------*/
/**
  * @brief     Get INT158FLG
  * @param     -
  * @return    INT17b interrupt flag
  * @note      -
  */
/*--------------------------------------------------*/
bool Get_param_INT158FLG(void)
{
    return (TSB_IMN_FLG4_INT158FLG);
}

/*--------------------------------------------------*/
/**
  * @brief     Get INT165FLG
  * @param     -
  * @return    INT21 interrupt flag
  * @note      -
  */
/*--------------------------------------------------*/
bool Get_param_INT165FLG(void)
{
    return (TSB_IMN_FLG5_INT165FLG);
}

/*--------------------------------------------------*/
/**
  * @brief     INT17a Clear
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void Clear_flag_INTNCLR_IMC061(void)
{
    /* INTNFLG Clear INTNCLR=1 */
    TSB_IB->IMC061 |= 0x80;

    /* Dummy read is need. */
    {
        __IO uint8_t imc = TSB_IB->IMC061;
    }

}

/*--------------------------------------------------*/
/**
  * @brief     INT17b Clear
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void Clear_flag_INTNCLR_IMC062(void)
{
    /* INTNFLG Clear INTNCLR=1 */
    TSB_IB->IMC062 |= 0x80;

    /* Dummy read is need. */
    {
        __IO uint8_t imc = TSB_IB->IMC062;
    }

}

/*--------------------------------------------------*/
/**
  * @brief     INT21 Clear
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void Clear_flag_INTPCLR_IMC069(void)
{
    /* INTNFLG Clear INTPCLR=1 */
    TSB_IB->IMC069 |= 0x40;

    /* Dummy read is need. */
    {
        __IO uint8_t imc = TSB_IB->IMC069;
    }
    
}

/*--------------------------------------------------*/
/**
  * @brief     Get parameter of OFD Reset flag
  * @param     -
  * @return    OFD reset flag
  * @note      -
  */
/*--------------------------------------------------*/
bool Get_param_RLM1_OFDRSTF(void)
{
    return ((TSB_RLM->RSTFLG1 & 0x08) >> 3);
}
/*--------------------------------------------------*/
/**
  * @brief     Clear OFD Reset flag
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void Clear_flag_RLM1_OFDRSTF(void)
{
    TSB_RLM->RSTFLG1 &= 0x07;
}

/*--------------------------------------------------*/
/**
  * @brief     IBNIC00 Clear
  * @param     -
  * @note      -
  */
/*--------------------------------------------------*/
void Clear_flag_IBNIC00_INTPCLR(void)
{
    /*--- IBNIC00: INTPCLR ---*/
    TSB_IB->NIC00 = 0x40;
    /* Dummy read is need. */
    {
        __IO uint8_t nic = TSB_IB->NIC00;
    }
}

/**
 *  @}
 */ /* End of group RDA_EXCEPT_M4K2_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_EXCEPT_M4K2 */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__EXCEPT_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

