/**
 *******************************************************************************
 * @file    rda_i2c_b.c
 * @brief   This file provides API functions for I2C rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "i2c.h"

#if defined(__I2C_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/* no define */

/** 
 *  @addtogroup RDA_I2C RDA_I2C
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_config RDA_I2C Private Config
 *  @{
 */

/** 
 *  @}
 */ /* End of group RDA_I2C_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup I2C_MASTER_TRANS_Private_macro I2C_MASTER_TRANS Private Macro
 *  @{
*/

/** 
 *  @addtogroup LEDBlinkConfiguration LED Blink Time Configuration
 *  @brief    LED Blink Interval Time(Interrupt Cycle).
 *  @{
 */
#define CFG_LED_BLINK_TIME             ((uint32_t)(100))
/** 
 *  @}
 */ /* End of group LEDBlinkConfiguration */
/** 
 *  @addtogroup  I2CError I2C Error 
 *  @brief    Error  .
 *  @{
 */
#define ERROR_I2C       ((uint32_t)(1))
/** 
 *  @}
 */ /* End of group I2CError */
/** 
 *  @addtogroup  I2C_DataLength I2C Data Length
 *  @brief    I2C Data Length.
 *  @{
 */
#define CFG_I2C_DATA_LENGTH     (16)                /*!< Length of base data.          */
/** 
 *  @}
 */ /* End of group I2C_DataLength */
 
/** 
 *  @addtogroup   I2C Direction of Transfer
 *  @brief    I2C Direction of Transfer.
 *  @{
 */
#define CFG_I2C_WRITE_MODE      ((uint8_t)0x0)     /*!< Write Mode.        */
#define CFG_I2C_READ_MODE       ((uint8_t)0x1)     /*!< Read Mode.         */
/** 
 *  @}
 */ /* End of group I2C_Direction */
/** 
 *  @addtogroup  I2C_ADDRESS I2C Address
 *  @brief    I2C Frequency.
 *  @{
 */
#define CFG_I2C_SELF_ADDR       ((uint8_t)0x60)     /*!< Self address for test.        */
#define CFG_I2C_SLAVE_ADDR      ((uint8_t)0x60)     /*!< Slave address for test.       */
/** 
 *  @}
 */ /* End of group I2C_ADDRESS */
/** 
 *  @name  I2CxSR Macro Definition.
 *  @brief I2CxSR Register Macro Definition.
 *  @{
 */
#define I2CxSR_MST              ((uint32_t)0x00000080)     /*!< MST                     */
#define I2CxSR_TRX              ((uint32_t)0x00000040)     /*!< TRX                     */
#define I2CxSR_BB               ((uint32_t)0x00000020)     /*!< BB                      */
#define I2CxSR_PIN              ((uint32_t)0x00000010)     /*!< PIN                     */
#define I2CxSR_AL               ((uint32_t)0x00000008)     /*!< AL                      */
#define I2CxSR_AAS              ((uint32_t)0x00000004)     /*!< AAS                     */
#define I2CxSR_AD0              ((uint32_t)0x00000002)     /*!< AD0                     */
#define I2CxSR_LRB              ((uint32_t)0x00000001)     /*!< LRB                     */
/**
 *  @}
 */ /* End of name I2CxSR Macro Definition */
/** 
 *  @name  I2CxOP Macro Definition.
 *  @brief I2CxOP Register Macro Definition.
 *  @{
 */
#define I2CxOP_DISAL            ((uint32_t)0x00000080)     /*!< DISAL                   */
#define I2CxOP_SA2ST            ((uint32_t)0x00000040)     /*!< SA2ST                   */
#define I2CxOP_SAST             ((uint32_t)0x00000020)     /*!< SAST                    */
#define I2CxOP_NFSEL            ((uint32_t)0x00000010)     /*!< NFSEL                   */
#define I2CxOP_RSTA             ((uint32_t)0x00000008)     /*!< RSTA                    */
#define I2CxOP_GCDI             ((uint32_t)0x00000004)     /*!< GDDI                    */
#define I2CxOP_SREN             ((uint32_t)0x00000002)     /*!< SREN                    */
#define I2CxOP_MFACK            ((uint32_t)0x00000001)     /*!< MFACK                   */
#define I2CxOP_MASTER_INIT      ((uint32_t)0x00000000)     /*!< Master Initial Settings.*/
#define I2CxOP_SLAVE_INIT       ((uint32_t)0x00000084)     /*!< Slave  Initial Settings.*/
/**
 *  @}
 */ /* End of name I2CxOP Macro Definition */
 /** 
 *  @name  I2CxPRS Macro Definition.
 *  @brief I2CxPRS Register Macro Definition.
 *  @{
 */
#define I2CxPRS_PRCK5           ((uint32_t)0x00000005)     /*!< PRCK                    */
#define I2CxPRS_MAX             ((uint32_t)64)             /*!< PRCK MAX                */
/**
 *  @}
 */ /* End of name I2CxPRS Macro Definition */
/** 
 *  @name  I2CxCR1 Macro Definition.
 *  @brief I2CxCR1 Register Macro Definition.
 *  @{
 */
#define I2CxCR1_BC0             ((uint32_t)0x00000000)     /*!< BC 0        */
#define I2CxCR1_BC1             ((uint32_t)0x00000020)     /*!< BC 1        */
#define I2CxCR1_BC2             ((uint32_t)0x00000040)     /*!< BC 2        */
#define I2CxCR1_BC3             ((uint32_t)0x00000060)     /*!< BC 3        */
#define I2CxCR1_BC4             ((uint32_t)0x00000080)     /*!< BC 4        */
#define I2CxCR1_BC5             ((uint32_t)0x000000A0)     /*!< BC 5        */
#define I2CxCR1_BC6             ((uint32_t)0x000000D0)     /*!< BC 6        */
#define I2CxCR1_BC7             ((uint32_t)0x000000E0)     /*!< BC 7        */
#define I2CxCR1_ACK             ((uint32_t)0x00000010)     /*!< ACK         */
#define I2CxCR1_NOACK           ((uint32_t)0x00000008)     /*!< NOACK       */
#define I2CxCR1_SCK0            ((uint32_t)0x00000000)     /*!< SCK 0       */
#define I2CxCR1_SCK1            ((uint32_t)0x00000001)     /*!< SCK 1       */
#define I2CxCR1_SCK2            ((uint32_t)0x00000002)     /*!< SCK 2       */
#define I2CxCR1_SCK3            ((uint32_t)0x00000003)     /*!< SCK 3       */
#define I2CxCR1_SCK4            ((uint32_t)0x00000004)     /*!< SCK 4       */
#define I2CxCR1_SCK5            ((uint32_t)0x00000005)     /*!< SCK 5       */
#define I2CxCR1_SCK6            ((uint32_t)0x00000006)     /*!< SCK 6       */
#define I2CxCR1_SCK7            ((uint32_t)0x00000007)     /*!< SCK 7       */

/**
 *  @}
 */ /* End of name I2CxCR1 Macro Definition */
/** 
 *  @name  I2CxCR2 Macro Definition.
 *  @brief I2CxCR2 Register Macro Definition.
 *  @{
 */
#define I2CxCR2_MST_SLAVE       ((uint32_t)0x00000000)     /*!< MST=0                                  */
#define I2CxCR2_MST_MASTER      ((uint32_t)0x00000080)     /*!< MST=1                                  */
#define I2CxCR2_TRX_RECEIVER    ((uint32_t)0x00000000)     /*!< TRX=0                                  */
#define I2CxCR2_TRX_TRANSMITTER ((uint32_t)0x00000040)     /*!< TRX=1                                  */
#define I2CxCR2_BB_STOP         ((uint32_t)0x00000000)     /*!< BB=0                                   */
#define I2CxCR2_BB_START        ((uint32_t)0x00000020)     /*!< BB=1                                   */
#define I2CxCR2_PIN_CLEAR       ((uint32_t)0x00000010)     /*!< PIN=1                                  */
#define I2CxCR2_I2CM_DISABLE    ((uint32_t)0x00000000)     /*!< I2CM=0                                 */
#define I2CxCR2_I2CM_ENABLE     ((uint32_t)0x00000008)     /*!< I2CM=1                                 */
#define I2CxCR2_SWRES_10        ((uint32_t)0x00000002)     /*!< SWRES=10                               */
#define I2CxCR2_SWRES_01        ((uint32_t)0x00000001)     /*!< SWRES=01                               */
#define I2CxCR2_START_CONDITION ((uint32_t)0x000000F8)     /*!< MST=1,TRX=1,BB=1,PIN=1,I2CM=1          */
#define I2CxCR2_STOP_CONDITION  ((uint32_t)0x000000D8)     /*!< MST=1,TRX=1,BB=0,PIN=1,I2CM=1          */
#define I2CxCR2_INIT            ((uint32_t)0x00000008)     /*!< MST=0,TRX=0,BB=0,PIN=0,I2CM=1,SWRES=00 */

/**
 *  @}
 */ /* End of name I2CxCR2 Macro Definition */

/** 
 *  @name  I2CxAR Macro Definition.
 *  @brief I2CxAR Register Macro Definition.
 *  @{
 */
#define I2CxAR_ALS              ((uint32_t)0x00000001)      /*!< ALS.                   */
#define I2CxAR_INIT             ((uint32_t)0x00000000)      /*!< Initial Settings.      */
#define I2CxAR_MASTER_INIT      ((uint32_t)0x00000000)      /*!< Initial Settings.      */
#define I2CxAR_SLAVE_INIT       ( CFG_I2C_SLAVE_ADDR  & ~I2CxAR_ALS )

#define I2CxAR2_INIT            ((uint32_t)0x00000000)      /*!< Initial Settings.      */

/**
 *  @}
 */ /* End of name I2CxAR Macro Definition */
/** 
 *  @name  I2CxIE Macro Definition.
 *  @brief I2CxIE Register Macro Definition.
 *  @{
 */
#define I2CxIE_SELPINCD         ((uint32_t)0x00000040)     /*!< SELPINCD                */
#define I2CxIE_DMARI2CTX        ((uint32_t)0x00000020)     /*!< DMARI2CTX               */
#define I2CxIE_DMARI2CRX        ((uint32_t)0x00000010)     /*!< DMARI2CRX               */
#define I2CxIE_INTNACK          ((uint32_t)0x00000008)     /*!< NACK                    */
#define I2CxIE_I2C              ((uint32_t)0x00000001)     /*!< INTI2C                  */
#define I2CxIE_CLEAR            ((uint32_t)0x00000000)     /*!< All Clear Setting       */
#define I2CxIE_INIT             ((uint32_t)0x00000001)     /*!< Initial Settings.       */

/**
 *  @}
 */ /* End of name I2CxIE Macro Definition */
 
 /** 
 *  @name  I2CxDBR Macro Definition.
 *  @brief I2CxDBR Register Macro Definition.
 *  @{
 */
#define I2CxDBR_DB_MASK         ((uint32_t)0x000000FF)      /* !< DB 7-0 bits mask.     */
/**
 *  @}
 */ /* End of name I2CxDBR Macro Definition */
 /** 
 *  @name  I2CxST Macro Definition.
 *  @brief I2CxST Register Macro Definition.
 *  @{
 */
#define I2CxST_NACK             ((uint32_t)0x00000008)    /*!< NACK Interrupt Status.   */
#define I2CxST_I2CBF            ((uint32_t)0x00000004)    /*!< I2CBF Interrupt Status.  */
#define I2CxST_I2CAL            ((uint32_t)0x00000002)    /*!< I2CAL Interrupt Status.  */
#define I2CxST_I2C              ((uint32_t)0x00000001)    /*!< I2C Interrupt Status.    */
#define I2CxST_CLEAR            ((uint32_t)0x0000000F)    /*!< All Bits Clear.          */
/**
 *  @}
 */ /* End of name I2CxST Macro Definition */
 /** 
 *  @addtogroup  GPIO_EN GPIO Enable/Disable
 *  @brief     GPIO Enable/Disable
 *  @{
 */
#define GPIO_DISABLE            ((uint32_t)0x00000000)    /*!< Disable                 */
#define GPIO_ENABLE             ((uint32_t)0x00000001)    /*!< Enable                  */
/** 
 *  @}
 */ /* End of group GPIO_EN */
 /** 
 *  @addtogroup  FSYS_EN FSYS Enable/Disable
 *  @brief     FSYS Enable/Disable
 *  @{
 */
#define FSYS_DISABLE            ((uint32_t)0x00000000)    /*!< Disable                 */
#define FSYS_ENABLE             ((uint32_t)0x00000001)    /*!< Enable                  */
/** 
 *  @}
 */ /* End of group FSYS_EN */

/** 
 *  @}
 */ /* End of group I2C_MASTER_TRANS_Private_macro */

 
/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_enum RDA_I2C Private Enum
 *  @{
 */


/**
 *  @}
 */ /* End of group RDA_I2C_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_typedef RDA_I2C Private Typedef
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_I2C_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_member RDA_I2C Private Member
 *  @{
 */


/**
 *  @}
 */ /* End of group RDA_I2C_Private_member */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_variable RDA_I2C Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_I2C_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_fuctions RDA_I2C Exported Fuctions
 *  @{
 */


/*--------------------------------------------------*/
/** 
  * @brief  I2C1_Master_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void I2C1_Master_Config(void)
{
    
    /* I2C Priscaler Clock    */
    TSB_I2C1->PRS = I2CxPRS_PRCK5;
    
    /* I2C Control Register   */
    TSB_I2C1->CR1 = I2CxCR1_BC0   |
                    I2CxCR1_ACK   |
                    I2CxCR1_NOACK |
                    I2CxCR1_SCK0  ;
    
    /* I2C Bus Free Check    */
    while( TSB_I2C1_SR_BB != 0 ){;}
    
    /* I2C I2CM Enable       */
    TSB_I2C1->CR2 = I2CxCR2_I2CM_ENABLE;
    
    TSB_I2C1->OP  = I2CxOP_MASTER_INIT;
    
    TSB_I2C1->AR  = I2CxAR_MASTER_INIT;
    TSB_I2C1->AR2 = I2CxAR2_INIT;
    
    TSB_I2C1->CR2 = I2CxCR2_I2CM_ENABLE;
    
    TSB_I2C1->IE  = I2CxIE_I2C;
}

/*--------------------------------------------------*/
/** 
  * @brief  I2C1_Slave_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void I2C1_Slave_Config(void)
{
    
    /* I2C Priscaler Clock      */
    TSB_I2C1->PRS = I2CxPRS_PRCK5;
    
    /* I2C Control Register     */
    TSB_I2C1->CR1 = I2CxCR1_BC0 |
                    I2CxCR1_ACK |
                    I2CxCR1_SCK0;
    
    /* I2C Bus Free Check       */
    while( TSB_I2C1_SR_BB != 0 ){;}
    
    TSB_I2C1->OP  = I2CxOP_SLAVE_INIT;
    
    /* I2C I2CM Enable          */
    TSB_I2C1->CR2 = ( I2CxCR2_I2CM_ENABLE | I2CxCR2_PIN_CLEAR );
    TSB_I2C1->CR2 = ( I2CxCR2_I2CM_ENABLE                     );
    
    TSB_I2C1->AR  = I2CxAR_SLAVE_INIT;
    TSB_I2C1->AR2 = I2CxAR2_INIT;
    
    TSB_I2C1->IE  = I2CxIE_I2C;
}

/*--------------------------------------------------*/
/** 
  * @fn     I2C1_start_condition(bool write_mode)
  * @brief  I2C ch.1 start Condition
  * @param  write_mode: true: write mode false:read mode
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void I2C1_start_condition(bool write_mode)
{
    if( write_mode )
    {
        TSB_I2C1->DBR = ( CFG_I2C_SLAVE_ADDR | CFG_I2C_WRITE_MODE );
    }
    else
    {
        TSB_I2C1->DBR = ( CFG_I2C_SLAVE_ADDR | CFG_I2C_READ_MODE );
    }
    
    TSB_I2C1->CR2 = I2CxCR2_START_CONDITION;
}

/*--------------------------------------------------*/
/** 
  * @fn     I2C1_stop_condition(void)
  * @brief  I2C ch.1 stop Condition
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void I2C1_stop_condition(void)
{
    TSB_I2C1->CR2 = I2CxCR2_STOP_CONDITION;
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_I2C1_DBR_value(uint8_t data)
  * @brief  I2C ch.1 DataBufferR value
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_I2C1_DBR_value(uint8_t data)
{
    /* Send data Set*/
    TSB_I2C1->DBR = data;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_I2C1_DBR_value(void)
  * @brief  I2C ch.1 DataBufferR value
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_I2C1_DBR_value(void)
{
    uint8_t data;
    
    /* Recive data Get   */
    data = (uint8_t)(TSB_I2C1->DBR);
    
    return ( data );
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_I2C1_I2C(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_I2C1_I2C(void)
{
    /* Interrupt Status Clear  */
    TSB_I2C1_ST_I2C = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_I2C1_I2C(void)
  * @brief  
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_I2C1_I2C(void)
{
    bool ret;
    
    /* Interrupt Status */
    ret = TSB_I2C1_ST_I2C;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_I2C1_NACK(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_I2C1_NACK(void)
{
    /* NACK Interrupt Status Clear    */
    TSB_I2C1_ST_NACK =  1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_I2C1_NACK(void)
  * @brief  
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_I2C1_NACK(void)
{
    bool ret;
    
    /* NACK Interrupt Status  */
    ret = TSB_I2C1_ST_NACK;
  
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_I2C1_LRB(void)
  * @brief  
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_I2C1_LRB(void)
{
    bool ret;
    
    /* Last Recerve Bit Check  */
    ret = TSB_I2C1_SR_LRB;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_I2C1_BB(void)
  * @brief  
  * @param  -
  * @return -
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_I2C1_BB(void)
{
    bool ret;
    
    /* Bus Busy Check  */
    ret = TSB_I2C1_SR_BB;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_param_I2C1_MFACK(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_param_I2C1_MFACK(void)
{
    TSB_I2C1_OP_MFACK = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_I2C1_Slave_mode(bool type)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_I2C1_Slave_mode(void)
{
    TSB_I2C1->CR2 = I2CxCR2_INIT;
}

/**
 *  @}
 */ /* End of group RDA_I2C_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_I2C */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__I2C_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */
    
