/** 
 *******************************************************************************
 * @file    rda_i2c_b.h
 * @brief   This file provides rda_i2c definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_I2C_B_H
#define __RDA_I2C_B_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_I2C RDA_I2C
 *  @brief    I2C Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_define RDA_I2C Private Define
 *  @{
 */


/** 
 *  @name  FLAG Macro Definition.
 *  @brief FLAG detection Macro Definition.
 *  @{
 */

/**
 *  @}
 */ /* End of name FLAG detection Macro Definition */

/**
 *  @}
 */ /* End of group RDA_I2C_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_enum RDA_I2C Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_I2C_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Private_typedef RDA_I2C Private Typedef
 *  @{
 */
 
#define FLAG_NOT_DETECT 0
#define FLAG_DETECT     1

#define BUS_FREE 0
#define BUS_BUSY 1

#define LRB_0 0
#define LRB_1 1
/**
 *  @}
 */ /* End of group RDA_I2C_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_I2C_Exported_functions RDA_I2C Exported Functions
 *  @{
 */
 
void I2C1_Master_Config(void);
void I2C1_Slave_Config(void);
void I2C1_start_condition(bool write_mode);
void I2C1_stop_condition(void);
void Set_I2C1_DBR_value(uint8_t data);
uint8_t Get_I2C1_DBR_value(void);
void Clear_flag_I2C1_I2C(void);
bool Get_param_I2C1_I2C(void);
void Clear_flag_I2C1_NACK(void);
bool Get_param_I2C1_NACK(void);
bool Get_param_I2C1_LRB(void);
bool Get_param_I2C1_BB(void);
void Set_param_I2C1_MFACK(void);
void Set_I2C1_Slave_mode(void);

/**
 *  @}
 */ /* End of group RDA_I2C_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_I2C */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_I2C_B_H */


