/**
 *******************************************************************************
 * @file    rda_lvd_d.c
 * @brief   This file provides API functions for LVD rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "lvd.h"
#include "sys_timer.h"

#if defined(__LVD_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_LVD RDA_LVD
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_config RDA_LVD Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group RDA_LVD_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_define RDA_LVD Private Define
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_define RDA_LVD Private Define
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_typedef RDA_LVD Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_variable RDA_LVD Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_LVD_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Exported_fuctions RDA_LVD Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/**
  * @brief     Initialize the LVD object.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void LVD_Config(uint32_t voltage)
{
    TSB_LVD->CR &= (uint8_t)LVD_DISABLE;        /* LVD Disable */
    TSB_LVD->CR  = (uint8_t)( voltage | LVD_SEL_RESET | LVD_OUT_DISABLE);   /* 4.0V RESET  Output Disable*/
    wait(100);
}

/*--------------------------------------------------*/
/**
  * @brief     Start the LVD object.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void LVD_start(void)
{
    uint8_t tmp;

    tmp = TSB_LVD->CR;
    TSB_LVD->CR = (uint8_t)(tmp | LVD_ENABLE);  /* LVD Enable */
    wait(1000);
}

/*--------------------------------------------------*/
/**
  * @brief     Get LVD Status.
  * @param     -
  * @retval    -
  * @note      -
  */
/*--------------------------------------------------*/
uint32_t Get_param_LVD_ST(void)
{
    return (TSB_LVD->CR & LVD_ST_MASK);
}


/**
 *  @}
 */ /* End of group RDA_LVD_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_LVD */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__LVD_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

