/** 
 *******************************************************************************
 * @file    rda_lvd_d.h
 * @brief   This file provides rda_lvd definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_LVD_D_H
#define __RDA_LVD_D_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_LVD RDA_LVD
 *  @brief    LVD Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_define RDA_LVD Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define LVD_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */



/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define LVD_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define LVD_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result Parameter Result */

/** 
 *  @addtogroup  LVDCR  LVDCR Register
 *  @brief     LVD Control Register.
 *  @{
 */

#define LVD_SEL_INT         ((uint32_t)0x00000004)          /*!< LVD INTLVD               */
#define LVD_SEL_RESET       ((uint32_t)0x00000000)          /*!< LVD reset                */
#define LVD_OUT_ENABLE      ((uint32_t)0x00000002)          /*!< LVD output enable        */
#define LVD_OUT_DISABLE     ((uint32_t)0x00000000)          /*!< LVD output disable       */
#define LVD_ENABLE          ((uint32_t)0x00000001)          /*!< LVD enable               */
#define LVD_DISABLE         ((uint32_t)0x00000000)          /*!< LVD disable              */

#define LVD_ST_MASK         ((uint32_t)0x00000080)          /*!< LVD ST mask              */
#define LVD_UPPER           ((uint32_t)0x00000000)          /*!< LVD UPPER                */
#define LVD_LOWER           ((uint32_t)0x00000080)          /*!< LVD LOWER                */
#define LVD_UNKNOWN         ((uint32_t)0x000000FF)          /*!< LVD UNKNOWN              */

#define LVD_STATUS_CT       ((uint32_t)0x00000008)          /*!< LVD status count         */


#define LVD_SUCCESS         ((uint32_t)0x00000000)          /*!< LVD result Success       */
#define LVD_ERROR           ((uint32_t)0x00000001)          /*!< LVD result Error         */

/** 
 *  @}
 */ /* End of group LVDCR */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_enum RDA_LVD Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Private_typedef RDA_LVD Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_LVD_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_LVD_Exported_fuctions RDA_LVD Exported Fuctions
 *  @{
 */

void LVD_Config(uint32_t voltage);
void LVD_start(void);
uint32_t Get_param_LVD_ST(void);

/**
 *  @}
 */ /* End of group RDA_LVD_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_LVD */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_LVD_D_H */


