/**
 *******************************************************************************
 * @file    rda_ofd_a.c
 * @brief   This file provides API functions for OFD rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "ofd.h"

#if defined(__OFD_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_OFD RDA_OFD
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Private_config RDA_OFD Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group RDA_OFD_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Private_define RDA_OFD Private Define
 *  @{
 */
 /** ---------------------------------------
 *  @addtogroup OFDCR1 OFDCR1
 *  @brief    OFD Control Register 1.
 *  @{
 */

/**
 *  @addtogroup OFD_CFG OFD Configrations
 *  @brief    OFD Configrations.
 *  @{
 */
/*  fIHOSC2: Min   9.0MHz, TYP 10MHz, MAX  11.0MHz
    fEHOSC : Min   9.9MHz, TYP 10MHz, MAX  10.1MHz
    fc     : Min 158.4MHz, TYP160.0MHz, MAX 161.6MHz  */
#define OFD_LOWER_COUNT  ((uint32_t)0x1CCU)     /* (158.4/11)*32 = 460.8 : 460 = 0x1CC */
#define OFD_HIGHER_COUNT ((uint32_t)0x23EU)     /* (161.6/ 9)*32 = 574.5 : 574 = 0x23E */

#define OFD_LOWER_COUNT_EXTERNAL  ((uint32_t)0x01CU) /*  (9.9/11)*32 = 28.8 : 28 = 0x01C */
#define OFD_HIGHER_COUNT_EXTERNAL ((uint32_t)0x023U) /*  (10.1/9)*32 = 35.9 : 35 = 0x023 */

/**
 *  @}
 */ /* End of group OFD_CFG*/

/** 
 *  @addtogroup OFD_OFDCR1 OFDCR1 Register Setting
 *  @brief    OFDCR1 Register Macro Define.
 *  @{
 */
#define OFD_OFDCR1_OFDWEN_DISABLE      ((uint32_t)0x06U)     /* Regster Writing Disable */
#define OFD_OFDCR1_OFDWEN_ENABLE       ((uint32_t)0xF9U)     /* Regster Writing Enable  */
/**
 *  @}
 */ /* End of group OFD_OFDCR1*/
/** 
 *  @addtogroup OFD_OFDRST OFDRST Register Setting
 *  @brief    OFDRST Register Macro Define.
 *  @{
 */
#define OFD_OFDRST_OFDRSTEN_DISABLE    ((uint32_t)0x0U)      /* OFD Ditection Disable    */
#define OFD_OFDRST_OFDRSTEN_ENABLE     ((uint32_t)0x1U)      /* OFD Ditection Enable     */
/**
 *  @}
 */ /* End of group OFD_OFDRST*/
/** 
 *  @addtogroup OFD_OFDCR2 OFDCR2 Register Setting
 *  @brief    OFDCR2 Register Macro Define.
 *  @{
 */
#define OFD_OFDCR2_OFDEN_DISABLE       ((uint32_t)0x00U)     /* OFD Ditection Disable   */
#define OFD_OFDCR2_OFDEN_ENABLE        ((uint32_t)0xE4U)     /* OFD Ditection Enable    */
/**
 *  @}
 */ /* End of group OFD_OFDCR2*/
/** 
 *  @addtogroup OFD_OFDMON OFDMON Register Setting
 *  @brief    OFDMON Register Macro Define.
 *  @{
 */
#define OFD_OFDMON_EOHSC              ((uint32_t)0x0U)     /* OFD Ditection Moniter for EOHSC   */
#define OFD_OFDMON_FC                 ((uint32_t)0x1U)     /* OFD Ditection Moniter for fc      */
/**
 *  @}
 */ /* End of group OFD_OFDMON*/
/** 
 *  @addtogroup OFDSTAT_OFDBUSY OFDBUSY
 *  @brief    [Bit1]: OFD Running status.
 *  @{
 */
#define OFD_OFDSTAT_OFDBUSY_MASK         ((uint32_t)0x00000002)        /*!< For bit MASK.                 */
#define OFD_OFDSTAT_OFDBUSY_SUSPENDED    ((uint32_t)0x00000000)        /*!< OFD Susupended.               */
#define OFD_OFDSTAT_OFDBUSY_RUNNING      ((uint32_t)0x00000002)        /*!< OFD Running.                  */
/**
 *  @}
 */ /* End of group OFDSTAT_OFDBUSY */
/** 
 *  @addtogroup OFDSTAT_FRQERR FRQERR
 *  @brief    [Bit0]: OFD Error Detection Flag.
 *  @{
 */
#define OFD_OFDSTAT_FRQERR_MASK          ((uint32_t)0x00000001)        /*!< For bit MASK.                 */
#define OFD_OFDSTAT_FRQERR_NOERROR       ((uint32_t)0x00000000)        /*!< Not Error occurred.           */
#define OFD_OFDSTAT_FRQERR_ERROR         ((uint32_t)0x00000001)        /*!< Error occurred.               */
/**
 *  @}
 */ /* End of group OFDSTAT_FRQERR */


/* Self-Diagnosis */
/** 
 *  @addtogroup OFDCR1_OFDWEN OFDWEN
 *  @brief    [Bit7:0]: Register Write Enable/Disable Control.
 *  @{
 */
#define REG_OFD_OFDCR1_OFDWEN_DISABLE        ((uint32_t)0x00000006)        /*!< Register Write Disable.     */
#define REG_OFD_OFDCR1_OFDWEN_ENABLE         ((uint32_t)0x000000F9)        /*!< Register Write Enable.      */
/**
 *  @}
 */ /* End of group OFDCR1_OFDWEN */

/**
 *  @}
 */ /* End of group OFDCR1 */

/** ---------------------------------------
 *  @addtogroup OFDCR2 OFDCR2
 *  @brief    OFD Control Register 2.
 *  @{
 */

/** 
 *  @addtogroup OFDCR2_OFDEN OFDEN
 *  @brief    [Bit7:0]: Frequency Detection Enable/Disable Control.
 *  @{
 */
#define REG_OFD_OFDCR2_OFDEN_DISABLE         ((uint32_t)0x00000000)        /*!< Frequency Detection Disable.  */
#define REG_OFD_OFDCR2_OFDEN_ENABLE          ((uint32_t)0x000000E4)        /*!< Frequency Detection Enable.   */
/**
 *  @}
 */ /* End of group OFDCR2_OFDEN */
/**
 *  @}
 */ /* End of group OFDCR2 */

/** ---------------------------------------
 *  @addtogroup OFDRST OFDRST
 *  @brief    OFD RESET Control Register.
 *  @{
 */

/** 
 *  @addtogroup OFDRST_OFDRSTEN OFDRSTEN
 *  @brief    [Bit0]: RESET Enable/Disable Control.
 *  @{
 */
#define REG_OFD_OFDRST_OFDRSTEN_DISABLE      ((uint32_t)0x00000000)        /*!< RESET Disable.              */
#define REG_OFD_OFDRST_OFDRSTEN_ENABLE       ((uint32_t)0x00000001)        /*!< RESET Enable.               */
/**
 *  @}
 */ /* End of group OFDCR2_OFD2EN */
 /**
 *  @}
 */ /* End of group OFDRST */

/** ---------------------------------------
 *  @addtogroup OFDSTAT OFDSTAT
 *  @brief    OFD Status Register.
 *  @{
 */

/** 
 *  @addtogroup OFDSTAT_OFDBUSY OFDBUSY
 *  @brief    [Bit1]: ODD Running status.
 *  @{
 */
#define REG_OFD_OFDSTAT_OFDBUSY_MASK         ((uint32_t)0x00000002)        /*!< For bit MASK.                 */
#define REG_OFD_OFDSTAT_OFDBUSY_SUSPENDED    ((uint32_t)0x00000000)        /*!< OFD Susupended.               */
#define REG_OFD_OFDSTAT_OFDBUSY_RUNNING      ((uint32_t)0x00000002)        /*!< OFD Running.                  */
/**
 *  @}
 */ /* End of group OFDSTAT_OFDBUSY */
/** 
 *  @addtogroup OFDSTAT_FRQERR FRQERR
 *  @brief    [Bit0]: ODD Error Detection Flag.
 *  @{
 */
#define REG_OFD_OFDSTAT_FRQERR_MASK          ((uint32_t)0x00000001)        /*!< For bit MASK.                 */
#define REG_OFD_OFDSTAT_FRQERR_NOERROR       ((uint32_t)0x00000000)        /*!< Not Error occurred.           */
#define REG_OFD_OFDSTAT_FRQERR_ERROR         ((uint32_t)0x00000001)        /*!< Error occurred.               */
/**
 *  @}
 */ /* End of group OFDSTAT_OFDBUSY */
/** 
 *  @addtogroup OFDMON1_OFDMON1 OFDMON1
 *  @brief    [Bit0]: Frequency Detection Enable/Disable Control.
 *  @{
 */
#define REG_OFD_OFDMON1_OFDMON1_EHOSC           ((uint32_t)0x00000000)        /*!< Monitor Clock for EHOSC.      */
#define REG_OFD_OFDMON1_OFDMON1_FC              ((uint32_t)0x00000001)        /*!< Monitor Clock for fc.         */
/**
 *  @}
 */ /* End of group OFDMON1_OFDMON1 */

/**
 *  @}
 */ /* End of group RDA_OFD_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Private_enum RDA_OFD Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_OFD_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Private_typedef RDA_OFD Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_OFD_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Private_variable RDA_OFD Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group LVD_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_OFD_Exported_fuctions RDA_OFD Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/**
  * @brief     Initialize the OFD object.
  * @param     -
  * @retval    -
  * @note      -
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
bool OFD_Config(uint32_t mon, uint32_t mn0, uint32_t mx0, uint32_t mn1, uint32_t mx1 )
{
    bool err_flag = 0 ;

    /* Register Write Enable */
    TSB_OFD->CR1 = OFD_OFDCR1_OFDWEN_ENABLE;
    /* Reset Output Disable */
    TSB_OFD->RST = OFD_OFDRST_OFDRSTEN_DISABLE;
    /* EHOSC Monitor Enable */
    TSB_OFD->MON = mon ;
    /* Frequency Detection Set */
    TSB_OFD->MN0 = mn0 ;
    TSB_OFD->MX0 = mx0 ;
    TSB_OFD->MN1 = mn1 ;
    TSB_OFD->MX1 = mx1 ;
    /* Frequency Detection Enable */
    TSB_OFD->CR2 = OFD_OFDCR2_OFDEN_ENABLE;
    /* OFD Status Register Check */
    while( (TSB_OFD->STAT & OFD_OFDSTAT_OFDBUSY_MASK) != OFD_OFDSTAT_OFDBUSY_RUNNING )
    {

    }

    wait(1500);
    if(( TSB_OFD->STAT & OFD_OFDSTAT_FRQERR_MASK) == OFD_OFDSTAT_FRQERR_NOERROR )
    {
        err_flag = 0;
        /* Frequency Detection Disable */
        TSB_OFD->CR2 = OFD_OFDCR2_OFDEN_DISABLE;
        /* Reset Output Enable */
        TSB_OFD->RST = OFD_OFDRST_OFDRSTEN_ENABLE;
        /* Frequency Detection Enable */
        TSB_OFD->CR2 = OFD_OFDCR2_OFDEN_ENABLE;
        /* Register Write Disable */
        TSB_OFD->CR1 = OFD_OFDCR1_OFDWEN_DISABLE;             
    }
    else
    {
        err_flag = 1;
        /* Frequency Detection Disable */
        TSB_OFD->CR2 = OFD_OFDCR2_OFDEN_DISABLE;
        /* Reset Output Enable */
        TSB_OFD->RST = OFD_OFDRST_OFDRSTEN_ENABLE;
        /* Frequency Detection Enable */
        TSB_OFD->CR2 = OFD_OFDCR2_OFDEN_ENABLE;
         /* ----------------- */
         /* OFD Reset Occurre */
         /* ----------------- */
    }

    return err_flag ;

}


/* Self-Diagnosis */
/*--------------------------------------------------*/
/**
  * @brief     Initialize OFD object.
  * @param     -
  * @retval    -
  * @note      Self-Diagnosis CLOCKIRQ_Sample
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
void CLOCKIRQ_OFD_Config(uint32_t clock_id, uint32_t high_clock, uint32_t low_clock)
{
    /* OFD register write enable (0xf9) */
    TSB_OFD->CR1 = REG_OFD_OFDCR1_OFDWEN_ENABLE;
    
    /* OFD frequenct detect disable (0x00) */
    TSB_OFD->CR2 = REG_OFD_OFDCR2_OFDEN_DISABLE;
    
    /* OFD reset output disable */
    TSB_OFD->RST = REG_OFD_OFDRST_OFDRSTEN_DISABLE;
    
    /* OFD select monitor clock (fc or EHOSC) */
    TSB_OFD->MON = clock_id;
    
    /* OFD set frequency parameter */
    if (clock_id == REG_OFD_OFDMON1_OFDMON1_FC) {
        /* check fc */
        TSB_OFD->MN1 = low_clock;
        TSB_OFD->MX1 = high_clock;
    }
    else {
        /* check EHOSC */
        TSB_OFD->MN0 = low_clock;
        TSB_OFD->MX0 = high_clock;
    }
    
    /* OFD frequenct detect enable (0xe4) */
    TSB_OFD->CR2 = REG_OFD_OFDCR2_OFDEN_ENABLE;
    
    /* OFD register write disable (0x06) */
    TSB_OFD->CR1 = REG_OFD_OFDCR1_OFDWEN_DISABLE;

}

/*--------------------------------------------------*/
/**
  * @brief     OFD BUSY or not.
  * @param     -
  * @retval    TSB_OFD_STAT_OFDBUSY
  * @note      Self-Diagnosis CLOCKIRQ_Sample
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
bool Get_param_OFD_OFDBUSY(void)
{
    return (TSB_OFD_STAT_OFDBUSY);
}

/*--------------------------------------------------*/
/**
  * @brief     FRQ ERR or not.
  * @param     -
  * @retval    TSB_OFD_STAT_OFDBUSY
  * @note      Self-Diagnosis CLOCKIRQ_Sample
  * @attention This function is not available in interrupt.
  */
/*--------------------------------------------------*/
bool Get_param_OFD_FRQERR(void)
{
    return (TSB_OFD_STAT_FRQERR);
}

/**
 *  @}
 */ /* End of group RDA_OFD_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_OFD */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__OFD_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

