/** 
 *******************************************************************************
 * @file    rda_ramp_b.h
 * @brief   This file provides rda_ramp definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_RAMP_B_H
#define __RDA_RAMP_B_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_RAMP RDA_RAMP
 *  @brief    RAMP Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_RAMP_Private_define RDA_RAMP Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define RAMP_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */



/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define RAMP_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define RAMP_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result Parameter Result */

/** 
 *  @addtogroup RAMPCTL_RAMPF RAMPF
 *  @brief    [Bit:1]: PARITY Error Interrupt Control.
 *  @{
 */
#define RAMP_RAMPCTL_RAMPF_MASK          ((uint32_t)0x00000002)        /*!< for Bit Mask.  */
#define RAMP_RAMPCTL_RAMPF_DISABLE       ((uint32_t)0x00000000)        /*!< Error Interrupt Disable.       */
#define RAMP_RAMPCTL_RAMPF_ENABLE        ((uint32_t)0x00000002)        /*!< Error Interrupt Enable.        */
/**
 *  @}
 */ /* End of group RAMPCTL_RAMPF */

/** 
 *  @addtogroup RAMPCTL_RAMPEN RAMPEN
 *  @brief    [Bit:1]: PARITY Error Detection Control.
 *  @{
 */
#define RAMP_RAMPCTL_RAMPEN_MASK         ((uint32_t)0x00000001)        /*!< for Bit Mask.  */
#define RAMP_RAMPCTL_RAMPEN_DISABLE      ((uint32_t)0x00000000)        /*!< Error Detection Disable.       */
#define RAMP_RAMPCTL_RAMPEN_ENABLE       ((uint32_t)0x00000001)        /*!< Error Detection Enable.        */
/**
 *  @}
 */ /* End of group RAMPCTL_RAMPEN */
 

/**
 *  @}
 */ /* End of group RDA_RAMP_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_RAMP_Private_enum RDA_RAMP Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_RAMP_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_RAMP_Private_typedef RDA_RAMP Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_RAMP_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RAMP_Private_variables RAMP Private Variables
 *  @{
 */

extern uint32_t cfg_data_length ;
extern uint8_t ram1[] __attribute__((section(".ARM.__at_0x20001000")));

/**
 *  @}
 */ /* End of group RAMP_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_RAMP_Exported_fuctions RDA_RAMP Exported Fuctions
 *  @{
 */

void RAMP0_Config(void);
uint32_t Get_param_RPAR_ST(void) ;

/**
 *  @}
 */ /* End of group RDA_RAMP_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_RAMP */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_RAMP_B_H */


