/** 
 *******************************************************************************
 * @file    rda_siwdt_a.h
 * @brief   This file provides rda_siwdt definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_SIWDT_A_H
#define __RDA_SIWDT_A_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"


/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_SIWDT RDA_SIWDT
 *  @brief    SIWDT Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_SIWDT_Private_define RDA_SIWDT Private Define
 *  @{
 */

/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define SIWDT_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */



/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define SIWDT_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define SIWDT_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result Parameter Result */

/** 
 *  @addtogroup  SIWDT disable
 *  @brief    SIWDT Disable code setting.
 *  @{
 */
#define SIWDEN_Val              (0x00000000UL)            /* SIWD Disable */
#define SIWDCR_Val              (0x000000B1UL)            /* SIWD Disable code */
/** 
 *  @}
 */ /* End of group SIWDT disable */


/** 
 *  @addtogroup  SIWDxEN  SIWDxEN Register
 *  @brief     WD Enable Register.
 *  @{
 */
/* WDTE */
#define SIWDxEN_WDTE_RW_DISABLE         ((uint32_t)0x00000000)    /*!< WDTE  :[R/W] :Disable    */
#define SIWDxEN_WDTE_RW_ENABLE          ((uint32_t)0x00000001)    /*!< WDTE  :[R/W] :Enable     */
/* WDCR */
#define SIWDxCR_WDCR_W_DISABLE          ((uint32_t)0x000000B1)    /*!< WDCR  :[W] :Disable      */
#define SIWDxCR_WDCR_W_CLEAR            ((uint32_t)0x0000004E)    /*!< WDCR  :[W] :Clear        */
/** 
 *  @}
 */ /* End of group SIWDxEN */
 
/** 
 *  @addtogroup  SIWDxMOD  SIWDxMOD Register
 *  @brief     WD Mode Register.
 *  @{
 */
/* WDTE */
#define SIWDxMOD_INIT                   ((uint32_t)0x00000500)    /*!< WDCLS=00,WDTP=101,WDCWD=00,INTF=0,RESCR=0    */
/** 
 *  @}
 */ /* End of group SIWDxMOD */

/**
 *  @}
 */ /* End of group RDA_SIWDT_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_SIWDT_Private_enum RDA_SIWDT Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_SIWDT_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_SIWDT_Private_typedef RDA_SIWDT Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_SIWDT_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_SIWDT_Exported_fuctions RDA_SIWDT Exported Fuctions
 *  @{
 */

void disable_SIWDT(void);
void enable_SIWDT(void);
void Set_WDCR_clear_code(void);
void SIWDT_Config(void);

/**
 *  @}
 */ /* End of group RDA_SIWDT_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_SIWDT */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_SIWDT_A_H */


