/**
 *******************************************************************************
 * @file    rda_t32a_c.c
 * @brief   This file provides API functions for T32A rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "t32a.h"

#if defined(__T32A_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_T32A RDA_T32A
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_config RDA_T32A Private Config
 *  @{
 */


/** 
 *  @}
 */ /* End of group RDA_T32A_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_define RDA_T32A Private Define
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_enum RDA_T32A Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_typedef RDA_T32A Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_variable RDA_T32A Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_T32A_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_fuctions RDA_T32A Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  T32A0_A_IntervalTimer_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_A_IntervalTimer_Config(void)
{
    /* Setting 16bit Timer Mode,
       HALT=0,MODE32=0                                                    */
    /* Setting prescaler 1/2, counter relead  T32AxRGA0 compare match,
       PRSCLA=001,CLKA=000,WBFA=0,UPDNA=00,RELDA=111,STOPA=000,STARTA=000 */
    /* Clear Timer Register 0                                             */
    /* Set Timer Register 1                                               */
    /* Setting Reload Register,
       Clock fsys 160.00Hz, Clock pht0mem 80.000MHz, prescaler 1/2, period 1000us=1000Hz
       (80000000 / 2) / 1000   = 40000.0 => 40000 (0x9C40)
       0xFFFF - 0x9C40 = 0x63BF */
    /* T32AxRGA1 compare match detection interrupt is not MASK, 
       IMUFA=1,IMOFA=1, IMA1=0,IMA0=1                                     */
    TSB_T32A0->STA   = T32AxSTA_ALL_CLEAR;
    TSB_T32A0->MOD   = T32AxMOD_UPCOUNT_INIT;
    TSB_T32A0->CRA   = T32AxCRA_UPCOUNT_INIT;
    TSB_T32A0->RGA0  = 0;
    TSB_T32A0->RGA1  = 0x9C40;
    TSB_T32A0->RELDA = 0x0;
    TSB_T32A0->IMA   = T32AxIMA_UPCOUNT_INIT;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A1_A_CAP_TRM_Config(uint32_t TRM_Select_Type)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A1_A_CAP_TRM_Config(uint32_t TRM_Select_Type)
{
    TSB_T32A1->MOD     = 0;
    TSB_T32A1->MOD     = T32AxMOD_HALT_RUN |
                         T32AxMOD_MODE_16;
    
    TSB_T32A1->RUNA    = 0;
    
    TSB_T32A1->CRA     = 0;
    if( TRM_Select_Type == PPG_SELECT )
    {
      TSB_T32A1->CRA   = T32AxCRA_PRSCLx_2                   |
                         T32AxCRA_CLKx_PRSCLx                |
                         T32AxCRA_WBF_DISABLE                |
                         T32AxCRA_COUNT_UP                   |
                         T32AxCRA_RELOAD_NON                 |
                         T32AxCRA_STOP_EXTTRG_RISING_EDGE    |
                         T32AxCRA_START_EXTTRG_TRAILING_EDGE;
    }
    else
    {
      TSB_T32A1->CRA   = T32AxCRA_PRSCLx_2                   |
                         T32AxCRA_CLKx_PRSCLx                |
                         T32AxCRA_WBF_DISABLE                |
                         T32AxCRA_COUNT_UP                   |
                         T32AxCRA_RELOAD_NON                 |
                         T32AxCRA_STOP_NON                   |
                         T32AxCRA_START_EXTTRG_TRAILING_EDGE;
    }
    
    TSB_T32A1->OUTCRA0 = 0;
    TSB_T32A1->OUTCRA0 = T32AxOUTCRA0_OCR_DISABLE;
    
    TSB_T32A1->OUTCRA1 = 0;
    TSB_T32A1->OUTCRA1 = T32AxOUTCRA1_OCRCAPx1_DISABLE |
                         T32AxOUTCRA1_OCRCAPx0_DISABLE |
                         T32AxOUTCRA1_OCRCMPx1_DISABLE |
                         T32AxOUTCRA1_OCRCMPx0_DISABLE;
    
    TSB_T32A1->RGA0    = 0;
    TSB_T32A1->RGA1    = 0;
    
    TSB_T32A1->RELDA   = 0;
    
    if( TRM_Select_Type == PPG_SELECT )
    {
      TSB_T32A1->CAPCRA = T32AxCAPCRA_CAPMx1_INx0_RISING_EDGE   |
                          T32AxCAPCRA_CAPMx0_INx0_TRAILING_EDGE;
    }
    else
    {
      TSB_T32A1->CAPCRA = T32AxCAPCRA_CAPMx1_INx0_TRAILING_EDGE |
                          T32AxCAPCRA_CAPMx0_INx0_TRAILING_EDGE;
    }
    
    TSB_T32A1->IMA     = 0;
    TSB_T32A1->IMA     = T32AxIMA_IMUFx_MASK_REQ |
                         T32AxIMA_IMOFx_MASK_REQ |
                         T32AxIMA_IMx1_MASK_REQ  |
                         T32AxIMA_IMx0_MASK_REQ;
    
    TSB_T32A1->DMAA    = 0;
    TSB_T32A1->DMAA    = T32AxDMAA_DMAENx2_DISABLE |
                         T32AxDMAA_DMAENx1_DISABLE |
                         T32AxDMAA_DMAENx0_DISABLE;
    
    TSB_T32A1->RUNA    = T32AxRUNA_COUNT_STOP       |
                         T32AxRUNA_COUNT_DONT_START |
                         T32AxRUNA_RUN_ENABLE;
    
    TSB_T32A0_RUNA_SFTSTAA = 1;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A1_A_CAP_Config(void)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A1_A_CAP_Config(void)
{
    TSB_T32A1->STA     = T32AxSTA_ALL_CLEAR;
    TSB_T32A1->MOD     = T32AxMOD_CAP_INIT;
    TSB_T32A1->CRA     = T32AxCRA_CAP_INIT;/* 0x04000000 */
    TSB_T32A1->RGA0    = 0x0;
    TSB_T32A1->RGA1    = 0x0;
    TSB_T32A1->RELDA   = 0x0;
    TSB_T32A1->CAPCRA  = T32AxCAPCRA_INIT;/* 0x2 */
    TSB_T32A1->IMA     = T32AxIMA_CAP_INIT;/* 0xF */
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_A_PPG_Config(void)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_A_PPG_Config(void)
{

    TSB_T32A3->STA = T32AxSTA_ALL_CLEAR;
    TSB_T32A3->MOD = T32AxMOD_PPG_INIT;
    TSB_T32A3->CRA = T32AxCRA_PPG_INIT;
    TSB_T32A3->RGA0 = 0x0;
    TSB_T32A3->RGA1 = 0x4E20; /* 500us(0x4E20) */
    TSB_T32A3->RELDA = 0x0;
    TSB_T32A3->CAPCRA = 0;
    TSB_T32A3->OUTCRA0 = T32AxOUTCRA0_PPG_INIT;
    TSB_T32A3->OUTCRA1 = T32AxOUTCRA1_PPG1_INIT;

}
/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_A_PPG1_Config(void)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_A_PPG1_Config(void)
{

    TSB_T32A3->STA = T32AxSTA_ALL_CLEAR;
    TSB_T32A3->MOD = T32AxMOD_PPG_INIT;
    TSB_T32A3->CRA  = T32AxCRA_PPG_INIT;
    TSB_T32A3->RELDA = 0x0;
    TSB_T32A3->RGA1 = T32AxRGA1_PPG1_INIT;
    TSB_T32A3->IMA  = T32AxIMA_PPG_INIT;
    TSB_T32A3->OUTCRA0 = T32AxOUTCRA0_PPG_INIT;
    TSB_T32A3->OUTCRA1 = T32AxOUTCRA1_PPG1_INIT;

}

/*--------------------------------------------------*/
/** 
  * @fn     void_t T32A3_B_PPG2_TRM_Config(void)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_B_PPG2_TRM_Config(void)
{
    TSB_T32A3->MOD     = 0;
    TSB_T32A3->MOD     = T32AxMOD_HALT_RUN |
                         T32AxMOD_MODE_16;
    
    TSB_T32A3->RUNB    = 0;
    
    TSB_T32A3->CRB     = 0;
    TSB_T32A3->CRB     = T32AxCRA_PRSCLx_1     |
                         T32AxCRA_CLKx_PRSCLx  |
                         T32AxCRA_WBF_DISABLE  |
                         T32AxCRA_COUNT_UP     |
                         T32AxCRA_RELOAD_TREGx |
                         T32AxCRA_STOP_NON     |
                         T32AxCRA_START_NON;
    
    TSB_T32A3->OUTCRB0 = 0;
    TSB_T32A3->OUTCRB0 = T32AxOUTCRA0_OCR_DISABLE;
    
    TSB_T32A3->OUTCRB1 = 0;
    TSB_T32A3->OUTCRB1 = T32AxOUTCRA1_OCRCAPx1_DISABLE   |
                         T32AxOUTCRA1_OCRCAPx0_DISABLE   |
                         T32AxOUTCRA1_OCRCMPx1_INVERSION |
                         T32AxOUTCRA1_OCRCMPx0_INVERSION;
    
    TSB_T32A3->RGB0    = 0;
    TSB_T32A3->RGB1    = 1;
    
    TSB_T32A3->RELDB   = 0;
    
    TSB_T32A3->CAPCRB  = T32AxCAPCRA_CAPMx1_DISABLE |
                         T32AxCAPCRA_CAPMx0_DISABLE;
    
    TSB_T32A3->IMB     = 0;
    TSB_T32A3->IMB     = T32AxIMA_IMUFx_MASK_REQ |
                         T32AxIMA_IMOFx_MASK_REQ |
                         T32AxIMA_IMx1_MASK_REQ  |
                         T32AxIMA_IMx0_MASK_REQ;
    
    TSB_T32A3->DMAB    = 0;
    TSB_T32A3->DMAB    = T32AxDMAA_DMAENx2_DISABLE |
                         T32AxDMAA_DMAENx1_DISABLE |
                         T32AxDMAA_DMAENx0_DISABLE;
    
    TSB_T32A3->RUNB    = T32AxRUNA_COUNT_STOP       |
                         T32AxRUNA_COUNT_DONT_START |
                         T32AxRUNA_RUN_ENABLE;
    
    TSB_T32A0_RUNA_SFTSTAA = 1;
}

/*--------------------------------------------------*/
/** 
  * @fn     void_t T32A3_B_PPG2_Config(void)
  * @brief  -
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_B_PPG2_Config(void)
{

    TSB_T32A3->STB = T32AxSTA_ALL_CLEAR;
    TSB_T32A3->MOD = T32AxMOD_PPG_INIT;
    TSB_T32A3->CRB  = T32AxCRB_PPG_INIT;
    TSB_T32A3->RGB0 = 0x0;
    TSB_T32A3->RGB1 = 40000;
    TSB_T32A3->RELDB = 0x0;
    TSB_T32A3->CAPCRB = T32AxCAPCRB_INIT;
    TSB_T32A3->OUTCRB0 = T32AxOUTCRB0_PPG_INIT;
    TSB_T32A3->OUTCRB1 = T32AxOUTCRB1_PPG2_INIT;
    TSB_T32A3->IMB  = T32AxIMB_PPG_INIT;
}
/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_A_Start(void)
  * @brief  T32A ch.0 Timer-A start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_A_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A0->RUNA & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN ){;}
    
    /* TimerA Count Start SFTSTPA=0,SFTSTAA=1,RUNA=1 */
    TSB_T32A0->RUNA = T32AxRUNA_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_A_Stop(void)
  * @brief  T32A ch.0 Timer-A stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_A_Stop(void)
{
    /* TimerA Count Stop SFTSTPA=1,SFTSTAA=0,RUNA=0 */
    TSB_T32A0->RUNA = T32AxRUNA_UPCOUNT_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A1_A_Start(void)
  * @brief  T32A ch.1 Timer-A start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A1_A_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A1->RUNA & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN ){;}
    
    /* TimerA Count Start SFTSTPA=0,SFTSTAA=1,RUNA=1 */
    TSB_T32A1->RUNA = T32AxRUNA_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A1_A_Stop(void)
  * @brief  T32A ch.1 Timer-A stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A1_A_Stop(void)
{
    /* TimerA Count Stop SFTSTPA=1,SFTSTAA=0,RUNA=0 */
    TSB_T32A1->RUNA = T32AxRUNA_UPCOUNT_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_A_Start(void)
  * @brief  T32A ch.3 Timer-A start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_A_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A3->RUNA & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN ){;}
    
    /* TimerA Count Start SFTSTPA=0,SFTSTAA=1,RUNA=1 */
    TSB_T32A3->RUNA = T32AxRUNA_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_A_Stop(void)
  * @brief  T32A ch.3 Timer-A stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_A_Stop(void)
{
    /* TimerA Count Stop SFTSTPA=1,SFTSTAA=0,RUNA=0 */
    TSB_T32A3->RUNA = T32AxRUNA_UPCOUNT_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_B_Start(void)
  * @brief  T32A ch.3 Timer-B start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_B_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A3->RUNB & T32AxRUNB_RUNFLGB_MASK) == T32AxRUNB_RUNFLGB_RUN ){;}
    
    /* TimerA Count Start SFTSTPA=0,SFTSTAA=1,RUNA=1 */
    TSB_T32A3->RUNB = T32AxRUNB_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A3_B_Stop(void)
  * @brief  T32A ch.3 Timer-B stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A3_B_Stop(void)
{
    /* TimerB Count Stop SFTSTPB=1,SFTSTAB=0,RUNB=0 */
    TSB_T32A3->RUNB = T32AxRUNB_UPCOUNT_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_param_T32A0_INTA1(void)
  * @brief  return T32A0->STA<INTA1>
  * @param  -
  * @return uint32_t
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_param_T32A0_INTA1(void)
{
    /* Get the INTA1 flag */
    return(TSB_T32A0->STA & T32AxSTA_INTA1_MASK);
}

/*--------------------------------------------------*/
/** 
  * @fn     void Clear_flag_T32A0_INTA(void)
  * @brief  reset T32Ax->STA<INTA1>, T32Ax->STA<INTA0>
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_T32A0_INTA(void)
{
    /* Reset the INTA1,INTA0 flag */
    TSB_T32A0->STA = T32AxSTA_INT_RESET;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_param_T32A0_INTA1(void)
  * @brief  return T32A1->STA<INTA1>
  * @param  -
  * @return uint32_t
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_param_T32A1_INTA1(void)
{
    /* Get the INTA1 flag */
    return(TSB_T32A1->STA & T32AxSTA_INTA1_MASK);
}

/*--------------------------------------------------*/
/** 
  * @fn     void Clear_flag_T32A1_INTA(void)
  * @brief  reset T32Ax->STA<INTA1>, T32Ax->STA<INTA0>
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_T32A1_INTA(void)
{
    /* Reset the INTA1,INTA0 flag */
    TSB_T32A1->STA = T32AxSTA_INT_RESET;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_param_T32A3_INTA1(void)
  * @brief  return T32A3->STA<INTA1>
  * @param  -
  * @return uint32_t
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_param_T32A3_INTA1(void)
{
    /* Get the INTA1 flag */
    return(TSB_T32A3->STA & T32AxSTA_INTA1_MASK);
}

/*--------------------------------------------------*/
/** 
  * @fn     void Clear_flag_T32A3_INTA(void)
  * @brief  reset T32Ax->STA<INTA1>, T32Ax->STA<INTA0>
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_T32A3_INTA(void)
{
    /* Reset the INTA1,INTA0 flag */
    TSB_T32A3->STA = T32AxSTA_INT_RESET;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_param_T32A3_INTB1(void)
  * @brief  return T32A3->STB<INTB1>
  * @param  -
  * @return uint32_t
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_param_T32A3_INTB1(void)
{
    /* Get the INTB3 flag */
    return(TSB_T32A3->STB & T32AxSTB_INTB1_MASK);
}

/*--------------------------------------------------*/
/** 
  * @fn     void Clear_flag_T32A3_INTB(void)
  * @brief  reset T32Ax->STB<INTB1>, T32Ax->STB<INTB0>
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_T32A3_INTB(void)
{
    /* Reset the INTB1,INTB0 flag */
    TSB_T32A3->STB = T32AxSTB_INT_RESET;
}

/*--------------------------------------------------*/
/** 
  * @fn     void Set_T32A3_RGA0_value(uint32_t)
  * @brief  set T32A3->RGA0
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_T32A3_RGA0_value(uint32_t value)
{
    /* Set RGA0 value */
    TSB_T32A3->RGA0 = value;
}

/*--------------------------------------------------*/
/** 
  * @fn     void Set_T32A3_RGA1_value(uint32_t)
  * @brief  set T32A3->RGA1
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_T32A3_RGA1_value(uint32_t value)
{
    /* Set RGA1 value */
    TSB_T32A3->RGA1 = value;
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_T32A1_CAPA0_value(void)
  * @brief  get T32A1->CAPA0
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_T32A1_CAPA0_value(void)
{
    return TSB_T32A1->CAPA0;
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_T32A1_CAPA1_value(void)
  * @brief  get T32A1->CAPA1
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_T32A1_CAPA1_value(void)
{
    return TSB_T32A1->CAPA1;
}

/*--------------------------------------------------*/
/** 
  * @fn     bool Get_param_T32A_CH0_INTA1(void)
  * @brief  check T32A0->STA<INTA1>
  * @param  -
  * @return bool
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_T32A_CH0_INTA1(void)
{

    return (TSB_T32A0_STA_INTA1);

}

/*--------------------------------------------------*/
/** 
  * @fn     void Clear_flag_T32A_CH0_INTA(void)
  * @brief  reset T32Ax->STA<INTA1>, T32Ax->STA<INTA0>
  * @param  -
  * @return bool
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_T32A_CH0_INTA(void)
{
    /* Reset the INTA1,INTA0 flag */
    TSB_T32A0->STA = T32AxSTA_INT_RESET;
}

/*--------------------------------------------------*/
/** 
  * @fn     bool Get_param_T32A3_RUNFLGA(void)
  * @brief  Check the Timer is running
  * @param  -
  * @return bool
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_T32A3_RUNFLGA(void)
{
    return ( (TSB_T32A3->RUNA & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN );
}


/* Self-Diagnosis CLOCKIRQ_Sample */
/*--------------------------------------------------*/
/** 
  * @brief  T32A0_A_CLOCKIRQ_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_A_CLCOKIRQ_Config(void)
{
    TSB_T32A0->STA   = 0xF;                     /* Status Register all clear */
    TSB_T32A0->MOD   = T32AxMOD_MODE_16;        /* HALT=0, MODE32=0 */
    TSB_T32A0->CRA   = T32AxCRA_UPCOUNT_INIT;   /* PRSCLA=001, CLKA=000, WBFA=0, UPDNA=00, RELDA=111, STOPA=000, STARTA=000 */
    TSB_T32A0->RGA0  = 0x0000;                  /* Timer RegisterA0 clear */
    TSB_T32A0->RGA1  = 0x0FA0;                  /* Timer RegisterA1 clear */
    TSB_T32A0->RELDA = 0x0000;                  /* Setting Reload Register */
    TSB_T32A0->IMA   = T32AxIMA_UPCOUNT_INIT;   /* IMUFA=1, IMOFA=1, IMA1=0, IMA0=1 */
}
/*--------------------------------------------------*/
/** 
  * @brief  T32A0_B_CLOCKIRQ_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_B_CLCOKIRQ_Config(void)
{
    TSB_T32A0->STB   = 0xF;                     /* Status Register all clear */
    TSB_T32A0->MOD   = T32AxMOD_MODE_16;        /* HALT=0, MODE32=0 */
    TSB_T32A0->CRB   = T32AxCRA_UPCOUNT_INIT;   /* PRSCLA=001, CLKA=000, WBFA=0, UPDNA=00, RELDA=111, STOPA=000, STARTA=000 */
    TSB_T32A0->RGB0  = 0x0000;                  /* Timer RegisterA0 clear */
    TSB_T32A0->RGB1  = 0x0FA0;                  /* Timer RegisterA1 clear */
    TSB_T32A0->RELDB = 0x0000;                  /* Setting Reload Register */
    TSB_T32A0->IMB   = T32AxIMA_UPCOUNT_INIT;   /* IMUFA=1, IMOFA=1, IMA1=0, IMA0=1 */
}
/*--------------------------------------------------*/
/** 
  * @brief  T32A0_C_CLOCKIRQ_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_C_CLCOKIRQ_Config(void)
{
    TSB_T32A0->STC   = 0xF;                     /* Status Register all clear */
    TSB_T32A0->MOD   = T32AxMOD_MODE_32;        /* HALT=0, MODE32=0 */
    TSB_T32A0->CRC   = T32AxCRA_UPCOUNT_INIT;   /* PRSCLA=001, CLKA=000, WBFA=0, UPDNA=00, RELDA=111, STOPA=000, STARTA=000 */
    TSB_T32A0->RGC0  = 0x0000;                  /* Timer RegisterA0 clear */
    TSB_T32A0->RGC1  = 0x0FA0;                  /* Timer RegisterA1 clear */
    TSB_T32A0->RELDC = 0x0000;                  /* Setting Reload Register */
    TSB_T32A0->IMC   = T32AxIMA_UPCOUNT_INIT;   /* IMUFA=1, IMOFA=1, IMA1=0, IMA0=1 */
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_B_Start(void)
  * @brief  T32A ch.0 Timer-B start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_B_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A0->RUNB & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN ){;}
    
    /* Timer-B Count Start SFTSTPB=0,SFTSTAB=1,RUNB=1 */
    TSB_T32A0->RUNB = T32AxRUNA_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_B_Stop(void)
  * @brief  T32A ch.0 Timer-B stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_B_Stop(void)
{
    /* Timer-B Count Stop SFTSTPB=1,SFTSTAB=0,RUNB=0 */
    TSB_T32A0->RUNB = T32AxRUNA_UPCOUNT_STOP;
}
/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_C_Start(void)
  * @brief  T32A ch.0 Timer-C start
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_C_Start(void)
{
    /* Check the Timer is not running */
    while( (TSB_T32A0->RUNC & T32AxRUNA_RUNFLGA_MASK) == T32AxRUNA_RUNFLGA_RUN ){;}
    
    /* Timer-C Count Start SFTSTPC=0,SFTSTAC=1,RUNC=1 */
    TSB_T32A0->RUNC = T32AxRUNA_UPCOUNT_START;
}

/*--------------------------------------------------*/
/** 
  * @fn     void T32A0_C_Stop(void)
  * @brief  T32A ch.0 Timer-C stop
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void T32A0_C_Stop(void)
{
    /* Timer-C Count Stop SFTSTPC=1,SFTSTAC=0,RUNC=0 */
    TSB_T32A0->RUNC = T32AxRUNA_UPCOUNT_STOP;
}

/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_T32A0_A_STA_value(void)
  * @brief  Get T32A ch.0 Timer-A STA value
  * @param  -
  * @return TSB_T32A0->STA
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_T32A0_A_STA_value(void)
{
    return (TSB_T32A0->STA);
}
/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_T32A0_B_STA_value(void)
  * @brief  Get T32A ch.0 Timer-B STA value
  * @param  -
  * @return TSB_T32A0->STB
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_T32A0_B_STA_value(void)
{
    return (TSB_T32A0->STB);
}
/*--------------------------------------------------*/
/** 
  * @fn     uint32_t Get_T32A0_C_STC_value(void)
  * @brief  Get T32A ch.0 Timer-C STC value
  * @param  -
  * @return TSB_T32A0->STC
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t Get_T32A0_C_STA_value(void)
{
    return (TSB_T32A0->STC);
}


/**
 *  @}
 */ /* End of group RDA_T32A_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_T32A */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__T32A_C_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

