/** 
 *******************************************************************************
 * @file    rda_t32a_c.h
 * @brief   This file provides rda_t32a definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_T32A_C_H
#define __RDA_T32A_C_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_T32A RDA_T32A
 *  @brief    T32A Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_define RDA_T32A Private Define
 *  @{
 */
/** 
 *  @addtogroup Edge_Setting Edge Setting
 *  @{
 */

#define PPG_SELECT     1U
#define UART_SELECT    2U

/** 
 *  @}
 */ /* End of group Edge_Setting */
 
/** 
 *  @addtogroup NULL_Pointer NULL Pointer
 *  @brief    NULL Pointer.
 *  @{
 */
#define T32A_NULL        ((void *)0)
/**
 *  @}
 */ /* End of group NULL_Pointer */



/** 
 *  @addtogroup Parameter_Result Parameter Result
 *  @brief    Whether the parameter is specified or not.
 *  @{
 */
#define T32A_PARAM_OK             ((int32_t)1)              /*!< Parameter is valid(specified).         */
#define T32A_PARAM_NG             ((int32_t)0)              /*!< Parameter is invalid(not specified).   */
/**
 *  @}
 */ /* End of group Parameter_Result Parameter Result */

/** 
 *  @name  T32AxSTA Macro Definition.
 *  @brief T32AxSTA Register Macro Definition.
 *  @{
 */
#define T32AxSTA_ALL_CLEAR      ((uint32_t)0x0000000F)     /*!< Flag all clear       */
#define T32AxSTA_INTA1_MASK     ((uint32_t)0x00000002)     /*!< Mask for INTA1       */
#define T32AxSTA_INT_RESET      ((uint32_t)0x00000003)     /*!< INTA1 = 1, INTA0 = 1 */
/**
 *  @}
 */ /* End of name T32AxSTA Macro Definition */

/** 
 *  @name  T32AxSTB Macro Definition.
 *  @brief T32AxSTB Register Macro Definition.
 *  @{
 */
#define T32AxSTB_ALL_CLEAR      ((uint32_t)0x0000000F)     /*!< Flag all clear       */
#define T32AxSTB_INTB1_MASK     ((uint32_t)0x00000002)     /*!< Mask for INTA1       */
#define T32AxSTB_INT_RESET      ((uint32_t)0x00000003)     /*!< INTA1 = 1, INTA0 = 1 */
/**
 *  @}
 */ /* End of name T32AxSTB Macro Definition */

/** 
 *  @name  T32AxMOD Macro Definition.
 *  @brief T32AxMOD Register Macro Definition.
 *  @{
 */
#define T32AxMOD_UPCOUNT_INIT   ((uint32_t)0x00000000)     /*!< HALT=0,MODE32=0 */
#define T32AxMOD_PPG_INIT       ((uint32_t)0x00000000)     /*!< HALT=0,MODE32=0 */
#define T32AxMOD_CAP_INIT       ((uint32_t)0x00000000)     /*!< HALT=0,MODE32=0 */
/**
 *  @}
 */ /* End of name T32AxMOD Macro Definition */

 /** 
 *  @addtogroup T32AxHALT  T32A Debug HALT Control
 *  @brief    Debug HALT Control Run/Stop HALT Macro Definition.
 *  @{
 */
#define T32AxMOD_HALT_RUN               ((uint32_t)0x00000000)    /*!< Run   */
#define T32AxMOD_HALT_STOP              ((uint32_t)0x00000002)    /*!< Stop  */
/**
 *  @}
 */ /* End of group T32AxMOD_HALT */

 /** 
 *  @addtogroup T32AxMOD  T32A 16bit/32bit MODE 
 *  @brief    T32A 16bit/32bit MODE MODE32 Macro Definition.
 *  @{
 */ 
#define T32AxMOD_MODE_16                ((uint32_t)0x00000000)    /*!< 16bit Mode  */
#define T32AxMOD_MODE_32                ((uint32_t)0x00000001)    /*!< 32bit Mode  */
/**
 *  @}
 */ /* End of group T32AxMOD_MODE */

 /** 
 *  @addtogroup T32AxRUN_RUNFLGx  T32A RUNFLG Control
 *  @brief    Run/Stop RUNFLGx Macro Definition.
 *  @{
 */
#define T32AxRUN_RUNFLG_RUN                 ((uint32_t)0x00000010)    /*!< Run   */
#define T32AxRUN_RUNFLG_STOP                ((uint32_t)0x00000000)    /*!< Stop  */
/**
 *  @}
 */ /* End of group T32AxRUN_RUNFLGx */
 
/** 
 *  @addtogroup T32AxRUN_SFTSTPx  T32A SW STOP Control
 *  @brief    T32A SW STOPx SFTSTPx Macro Definition.
 *  @{
 */
#define T32AxRUN_SFTSTPxCOUNT_DONT_STOP     ((uint32_t)0x0000000)    /*!< No effect    */
#define T32AxRUN_SFTSTPxCOUNT_STOP          ((uint32_t)0x0000004)    /*!< Counter Stop */
/**
 *  @}
 */ /* End of group T32AxRUN_SFTSTPx */

/** 
 *  @addtogroup T32AxRUN_SFTSTAx  T32A SW START Control
 *  @brief    T32A SW STARTx SFTSTAx Macro Definition.
 *  @{
 */
#define T32AxRUN_SFTSTAxCOUNT_DONT_START    ((uint32_t)0x0000000)    /*!< No effect     */
#define T32AxRUN_SFTSTAxCOUNT_START         ((uint32_t)0x0000002)    /*!< Counter Start */
/**
 *  @}
 */ /* End of group T32AxRUN_SFTSTAx */

/** 
 *  @addtogroup T32AxRUN     T32A RUNA Disable/Enable Control
 *  @brief    RUN Disable/Enable RUNA Macro Definition.
 *  @{
 */
#define T32AxRUN_RUNA_DISABLE           ((uint32_t)0x00000000)    /*!< Disable */
#define T32AxRUN_RUNA_ENABLE            ((uint32_t)0x00000001)    /*!< Enable  */
/**
 *  @}
 */ /* End of group T32AxRUN_RUNA */

/** 
 *  @addtogroup T32AxCRA_PRSCLx  T32A PRESCALER Control
 *  @brief    PRESCALER Control PRSCLx Macro Definition.
 *  @{
 */
#define T32AxCRA_PRSCLx_1                  ((uint32_t)0x00000000)    /*!< 1/1    */
#define T32AxCRA_PRSCLx_2                  ((uint32_t)0x10000000)    /*!< 1/2    */
#define T32AxCRA_PRSCLx_8                  ((uint32_t)0x20000000)    /*!< 1/8    */
#define T32AxCRA_PRSCLx_32                 ((uint32_t)0x30000000)    /*!< 1/32   */
#define T32AxCRA_PRSCLx_128                ((uint32_t)0x40000000)    /*!< 1/128  */
#define T32AxCRA_PRSCLx_256                ((uint32_t)0x50000000)    /*!< 1/256  */
#define T32AxCRA_PRSCLx_512                ((uint32_t)0x60000000)    /*!< 1/512  */
#define T32AxCRA_PRSCLx_1024               ((uint32_t)0x70000000)    /*!< 1/1024 */
/**
 *  @}
 */ /* End of group T32AxCRA_PRSCLx */

/** 
 *  @addtogroup T32AxCRA_CLKx  T32A CLOCK Control
 *  @brief    CLOCK Control CLKA Macro Definition.
 *  @{
 */
#define T32AxCRA_CLKx_PRSCLx                ((uint32_t)0x00000000)    /*!< prescaler                     */
#define T32AxCRA_CLKx_INTRG                 ((uint32_t)0x01000000)    /*!< internal triger               */
#define T32AxCRA_CLKx_TIM_RISING_EDGE       ((uint32_t)0x02000000)    /*!< other timer rising edge       */
#define T32AxCRA_CLKx_TIM_TRAILING_EDGE     ((uint32_t)0x03000000)    /*!< other timer trailing edge     */
#define T32AxCRA_CLKx_EXTTRG_RISING_EDGE    ((uint32_t)0x04000000)    /*!< external triger rising edge   */
#define T32AxCRA_CLKx_EXTTRG_TRAILING_EDGE  ((uint32_t)0x05000000)    /*!< external triger trailing edge */
/**
 *  @}
 */ /* End of group T32AxCRA_CLKx */

/** 
 *  @addtogroup T32AxCRA_WBFx  T32A Double Buffer Disable/Enable Control
 *  @brief    Double Buffer Disable/Enable WBFx Macro Definition.
 *  @{
 */
#define T32AxCRA_WBF_DISABLE                ((uint32_t)0x00000000)    /*!< Disable */
#define T32AxCRA_WBF_ENABLE                 ((uint32_t)0x00100000)    /*!< Enable  */
/**
 *  @}
 */ /* End of group T32AxCRA_WBFx */
 
 /** 
 *  @addtogroup T32AxCRA_UPDNx  T32A Counter Up/Down Control
 *  @brief    Counter Up/Down Control UPDNx Macro Definition.
 *  @{
 */
#define T32AxCRA_COUNT_UP                   ((uint32_t)0x00000000)    /*!< count up      */
#define T32AxCRA_COUNT_DOWN                 ((uint32_t)0x00010000)    /*!< count down    */
#define T32AxCRA_COUNT_UPDOWN               ((uint32_t)0x00020000)    /*!< count updown  */
#define T32AxCRA_COUNT_PLS                  ((uint32_t)0x00030000)    /*!< count pulse   */
/**
 *  @}
 */ /* End of group T32AxCRA_UPDNx */

 /** 
 *  @addtogroup T32AxCRA_RELDx  T32A Counter Reload Control
 *  @brief    Counter Reload Control RELDx Macro Definition.
 *  @{
 */
#define T32AxCRA_RELOAD_NON                  ((uint32_t)0x00000000)    /*!< Nothing(Free run)               */
#define T32AxCRA_RELOAD_INTRG                ((uint32_t)0x00000100)    /*!< internal trigger                */
#define T32AxCRA_RELOAD_EXTTRG_RISING_EDGE   ((uint32_t)0x00000200)    /*!< external trigger rising edge    */
#define T32AxCRA_RELOAD_EXTTRG_TRAILING_EDGE ((uint32_t)0x00000300)    /*!< external trigger trailing edge  */
#define T32AxCRA_RELOAD_TIM_RISING_EDGE      ((uint32_t)0x00000400)    /*!< other timer rising edge         */
#define T32AxCRA_RELOAD_TIM_TRAILING_EDGE    ((uint32_t)0x00000500)    /*!< other timer trailing edge       */
#define T32AxCRA_RELOAD_SYNC                 ((uint32_t)0x00000600)    /*!< sync(slave channel)             */
#define T32AxCRA_RELOAD_TREGx                ((uint32_t)0x00000700)    /*!< match up Timer Register         */
/**
 *  @}
 */ /* End of group T32AxCRA_RELDx */

 /** 
 *  @addtogroup T32AxCRA_STOPx  T32A Counter Stop Control
 *  @brief    Counter Stop Control STOPx Macro Definition.
 *  @{
 */
#define T32AxCRA_STOP_NON                   ((uint32_t)0x00000000)    /*!< No use trigger                  */
#define T32AxCRA_STOP_INTRG                 ((uint32_t)0x00000010)    /*!< internal trigger                */
#define T32AxCRA_STOP_EXTTRG_RISING_EDGE    ((uint32_t)0x00000020)    /*!< external trigger rising edge    */
#define T32AxCRA_STOP_EXTTRG_TRAILING_EDGE  ((uint32_t)0x00000030)    /*!< external trigger trailing edge  */
#define T32AxCRA_STOP_TIM_RISING_EDGE       ((uint32_t)0x00000040)    /*!< other timer rising edge         */
#define T32AxCRA_STOP_TIM_TRAILING_EDGE     ((uint32_t)0x00000050)    /*!< other timer trailing edge       */
#define T32AxCRA_STOP_SYNC                  ((uint32_t)0x00000060)    /*!< sync(slave channel)             */
#define T32AxCRA_STOP_TREGx                 ((uint32_t)0x00000070)    /*!< match up Timer Register A       */
/**
 *  @}
 */ /* End of group T32AxCRA_STOPx */


 /** 
 *  @addtogroup T32AxCRA_STARTx  T32A Counter Start Control
 *  @brief    Counter Start Control STARTx Macro Definition.
 *  @{
 */
#define T32AxCRA_START_NON                  ((uint32_t)0x00000000)    /*!< No use trigger                  */
#define T32AxCRA_START_INTRG                ((uint32_t)0x00000001)    /*!< internal trigger                */
#define T32AxCRA_START_EXTTRG_RISING_EDGE   ((uint32_t)0x00000002)    /*!< external trigger rising edge    */
#define T32AxCRA_START_EXTTRG_TRAILING_EDGE ((uint32_t)0x00000003)    /*!< external trigger trailing edge  */
#define T32AxCRA_START_TIM_RISING_EDGE      ((uint32_t)0x00000004)    /*!< other timer rising edge         */
#define T32AxCRA_START_TIM_TRAILING_EDGE    ((uint32_t)0x00000005)    /*!< other timer trailing edge       */
#define T32AxCRA_START_SYNC                 ((uint32_t)0x00000006)    /*!< sync(slave channel)             */
#define T32AxCRA_START_Rsvd                 ((uint32_t)0x00000007)    /*!< Reserved                        */
/**
 *  @}
 */ /* End of group T32AxCRA_STARTx */
 
 /** 
 *  @name  T32AxCRA Macro Definition.
 *  @brief T32AxCRA Register Macro Definition.
 *  @{
 */
#define T32AxCRA_UPCOUNT_INIT    ((uint32_t)0x10000700)     /*!< PRSCLA=001,CLKA=000,WBFA=0,UPDNA=00,RELDA=111,STOPA=000,STARTA=000 */
#define T32AxCRA_PPG_INIT        ((uint32_t)0x10100700)     /*!< PRSCLA=001,CLKA=000,WBFA=1,UPDNA=00,RELDA=111,STOPA=000,STARTA=000 */
#define T32AxCRA_CAP_INIT        ((uint32_t)0x04000000)     /*!< PRSCLA=000,CLKA=100,WBFA=0,UPDNA=00,RELDA=000,STOPA=000,STARTA=000 */
#define T32AxCRB_PPG_INIT        ((uint32_t)0x60000700)     /*!< PRSCLB=110,CLKB=000,WBFB=0,UPDNB=00,RELDB=111,STOPB=000,STARTB=000 */

#define T32AxCAPCRB_INIT         ((uint32_t)0x00000000)     /*!< CAPMB1=000 CAPMB0=000 */
#define T32AxCAPCRA_INIT         ((uint32_t)0x00000002)     /*!< CAPMA1=000,CAPMA0=010 */
#define T32AxIMA_CAP_INIT        ((uint32_t)0x0000000F)
#define T32AxIMB_PPG_INIT        ((uint32_t)0x0000000D)
#define T32AxOUTCRA0_PPG_INIT    ((uint32_t)0x00000000)
#define T32AxOUTCRB0_PPG_INIT    ((uint32_t)0x00000000)
#define T32AxOUTCRA1_PPG1_INIT   ((uint32_t)0x00000009)     /*!< OCRCAPA1=00,OCRCAPA0=00,OCRCMPA1=10,OCRCMPA0=01 */
#define T32AxOUTCRB1_PPG2_INIT   ((uint32_t)0x0000000C)     /*!< OCRCAPB1=00,OCRCAPB0=00,OCRCMPB1=11,OCRCMPB0=00 */

#define T32AxRGA1_PPG1_INIT      ((uint32_t)0x00004E20)
    /* Setting Reload Register,
       Clock fsys 160.00Hz, Clock pht0mem 80.000MHz, prescaler 1/2, period 500us=2000Hz
       (80000000 / 2) / 2000   = 20000.0 => 20000 (0x4E20) */

/**
 *  @}
 */ /* End of name T32AxCRA Macro Definition */

/** 
 *  @addtogroup T32AxOUTCRA0_OCRx  T32AxOUTA Control
 *  @brief    T32AxOUTA Control OCRx Macro Definition.
 *  @{
 */
#define T32AxOUTCRA0_OCR_DISABLE           ((uint32_t)0x00000000)    /*!< Nothig    */
#define T32AxOUTCRA0_OCR_SET               ((uint32_t)0x00000001)    /*!< Hi        */
#define T32AxOUTCRA0_OCR_CLR               ((uint32_t)0x00000002)    /*!< Low       */
#define T32AxOUTCRA0_OCR_INVERSION         ((uint32_t)0x00000003)    /*!< inversion */
/**
 *  @}
 */ /* End of group T32AxOUTCRA0_OCRx */

/** 
 *  @addtogroup T32AxOUTCRA1_OCRCAPx1  T32AxOUTA Control of T32AxCAPx1 T32AxRGx1
 *  @brief    T32AxOUTA Control of T32AxCAPx1 T32AxRGx1 OCRCAPx1 Macro Definition.
 *  @{
 */
#define T32AxOUTCRA1_OCRCAPx1_DISABLE      ((uint32_t)0x00000000)    /*!< No effect */
#define T32AxOUTCRA1_OCRCAPx1_SET          ((uint32_t)0x00000040)    /*!< Hi        */
#define T32AxOUTCRA1_OCRCAPx1_CLR          ((uint32_t)0x00000080)    /*!< Low       */
#define T32AxOUTCRA1_OCRCAPx1_INVERSION    ((uint32_t)0x000000C0)    /*!< inversion */
/**
 *  @}
 */ /* End of group T32AxOUTCRA1_OCRCAPx1 */

/** 
 *  @addtogroup T32AxOUTCRA1_OCRCAPx0  T32AxOUTA Control of T32AxCAPx0 counter value
 *  @brief    T32AxOUTA Control of T32AxCAPx0 T32AxRGx1 OCRCAPx0 Macro Definition.
 *  @{
 */
#define T32AxOUTCRA1_OCRCAPx0_DISABLE      ((uint32_t)0x00000000)    /*!< No effect */
#define T32AxOUTCRA1_OCRCAPx0_SET          ((uint32_t)0x00000010)    /*!< Hi        */
#define T32AxOUTCRA1_OCRCAPx0_CLR          ((uint32_t)0x00000020)    /*!< Low       */
#define T32AxOUTCRA1_OCRCAPx0_INVERSION    ((uint32_t)0x00000030)    /*!< inversion */
/**
 *  @}
 */ /* End of group T32AxOUTCRA1_OCRCAPx0 */

/** 
 *  @addtogroup T32AxOUTCRA1_OCRCMPx1  T32AxOUTA Control of T32AxRGx1 Counter Value
 *  @brief    T32AxOUTA Control of T32AxRGx1 Counter Value OCRCMPx1 Macro Definition.
 *  @{
 */
#define T32AxOUTCRA1_OCRCMPx1_DISABLE      ((uint32_t)0x00000000)    /*!< No effect */
#define T32AxOUTCRA1_OCRCMPx1_SET          ((uint32_t)0x00000004)    /*!< Hi        */
#define T32AxOUTCRA1_OCRCMPx1_CLR          ((uint32_t)0x00000008)    /*!< Low       */
#define T32AxOUTCRA1_OCRCMPx1_INVERSION    ((uint32_t)0x0000000C)    /*!< inversion */
/**
 *  @}
 */ /* End of group T32AxOUTCRA1_OCRCMPx1 */

/** 
 *  @addtogroup T32AxOUTCRA1_OCRCMPx0  T32AxOUTA Control of T32AxRGx0 Counter Value
 *  @brief    T32AxOUTA Control of T32AxRGx0 Counter Value OCRCMPx0 Macro Definition.
 *  @{
 */
#define T32AxOUTCRA1_OCRCMPx0_DISABLE      ((uint32_t)0x00000000)    /*!< No effect */
#define T32AxOUTCRA1_OCRCMPx0_SET          ((uint32_t)0x00000001)    /*!< Hi        */
#define T32AxOUTCRA1_OCRCMPx0_CLR          ((uint32_t)0x00000002)    /*!< Low       */
#define T32AxOUTCRA1_OCRCMPx0_INVERSION    ((uint32_t)0x00000003)    /*!< inversion */
/**
 *  @}
 */ /* End of group T32AxOUTCRA1_OCRCMPx0 */
 
 /** 
 *  @addtogroup T32AxCAPCRA_CAPMx1  T32A Capture Control Register x1
 *  @brief    Capture Control Register A1 CAPMx1 Macro Definition.
 *  @{
 */
#define T32AxCAPCRA_CAPMx1_DISABLE             ((uint32_t)0x00000000)    /*!< No use trigger            */
#define T32AxCAPCRA_CAPMx1_INTRG               ((uint32_t)0x00000010)    /*!< internal trigger          */
#define T32AxCAPCRA_CAPMx1_INx0_RISING_EDGE    ((uint32_t)0x00000020)    /*!< INx0 rising edge          */
#define T32AxCAPCRA_CAPMx1_INx0_TRAILING_EDGE  ((uint32_t)0x00000030)    /*!< INx0 trailing edge        */
#define T32AxCAPCRA_CAPMx1_INx1_RISING_EDGE    ((uint32_t)0x00000040)    /*!< INx1 rising edge          */
#define T32AxCAPCRA_CAPMx1_INx1_TRAILING_EDGE  ((uint32_t)0x00000050)    /*!< INx1 trailing edge        */
#define T32AxCAPCRA_CAPMx1_TIM_RISING_EDGE     ((uint32_t)0x00000060)    /*!< other timer rising edge   */
#define T32AxCAPCRA_CAPMx1_TIM_TRAILING_EDGE   ((uint32_t)0x00000070)    /*!< other timer trailing edge */
/**
 *  @}
 */ /* End of group T32AxCAPCRA_CAPMx1 */

 /** 
 *  @addtogroup T32AxCAPCRA_CAPMx0  T32A Capture Control Register x0
 *  @brief    Capture Control Register x0 CAPMx0 Macro Definition.
 *  @{
 */
#define T32AxCAPCRA_CAPMx0_DISABLE             ((uint32_t)0x00000000)    /*!< No use trigger            */
#define T32AxCAPCRA_CAPMx0_INTRG               ((uint32_t)0x00000001)    /*!< internal trigger          */
#define T32AxCAPCRA_CAPMx0_INx0_RISING_EDGE    ((uint32_t)0x00000002)    /*!< INx0 rising edge          */
#define T32AxCAPCRA_CAPMx0_INx0_TRAILING_EDGE  ((uint32_t)0x00000003)    /*!< INx0 trailing edge        */
#define T32AxCAPCRA_CAPMx0_INx1_RISING_EDGE    ((uint32_t)0x00000004)    /*!< INx1 rising edge          */
#define T32AxCAPCRA_CAPMx0_INx1_TRAILING_EDGE  ((uint32_t)0x00000005)    /*!< INx1 trailing edge        */
#define T32AxCAPCRA_CAPMx0_TIM_RISING_EDGE     ((uint32_t)0x00000006)    /*!< other timer rising edge   */
#define T32AxCAPCRA_CAPMx0_TIM_TRAILING_EDGE   ((uint32_t)0x00000007)    /*!< other timer trailing edge */
/**
 *  @}
 */ /* End of group T32AxCAPCRA_CAPMx0 */

/** 
 *  @addtogroup T32AxIMA_IMUFx  T32A Underflow Interrupt Request MASK
 *  @brief    T32A Underflow Interrupt Request MASK IMUFx Macro Definition.
 *  @{
 */
#define T32AxIMA_IMUFx_MASK_NOREQ       ((uint32_t)0x00000000)    /*!< don't request */
#define T32AxIMA_IMUFx_MASK_REQ         ((uint32_t)0x00000008)    /*!< request       */
/**
 *  @}
 */ /* End of group T32AxIMA_IMUFx */

/** 
 *  @addtogroup T32AxIMA_IMOFx  T32A Overflow Interrupt Request MASK
 *  @brief    T32A Overflow Interrupt Request MASK IMOFx Macro Definition.
 *  @{
 */
#define T32AxIMA_IMOFx_MASK_NOREQ       ((uint32_t)0x00000000)    /*!< don't request */
#define T32AxIMA_IMOFx_MASK_REQ         ((uint32_t)0x00000004)    /*!< request       */
/**
 *  @}
 */ /* End of group T32AxIMA_IMOFx */

/** 
 *  @addtogroup T32AxIMA_IMx1  T32A Match Up T32AxRGx1 Interrupt Request MASK
 *  @brief    T32A Match Up T32AxRGx1 Interrupt Request MASK IMx1 Macro Definition.
 *  @{
 */
#define T32AxIMA_IMx1_MASK_NOREQ        ((uint32_t)0x00000000)    /*!< don't request */
#define T32AxIMA_IMx1_MASK_REQ          ((uint32_t)0x00000002)    /*!< request       */
/**
 *  @}
 */ /* End of group T32AxIMA_IMx1 */

/** 
 *  @addtogroup T32AxIMA_IMx0  T32A Match Up T32AxRGx0 Interrupt Request MASK
 *  @brief    T32A Match Up T32AxRGx0 Interrupt Request MASK IMx0 Macro Definition.
 *  @{
 */
#define T32AxIMA_IMx0_MASK_NOREQ        ((uint32_t)0x00000000)    /*!< don't request */
#define T32AxIMA_IMx0_MASK_REQ          ((uint32_t)0x00000001)    /*!< request       */
/**
 *  @}
 */ /* End of group T32AxIMA_IMx0 */

/** 
 *  @name  T32AxIMA Macro Definition.
 *  @brief T32AxIMA Register Macro Definition.
 *  @{
 */
#define T32AxIMA_UPCOUNT_INIT    ((uint32_t)0x0000000D)     /*!< IMUFA=1,IMOFA=1, IMA1=0,IMA0=1 */
#define T32AxIMA_PPG_INIT        ((uint32_t)0x00000000)
/**
 *  @}
 */ /* End of name T32AxIMA Macro Definition */

/** 
 *  @addtogroup T32AxDMAA_DMAENx2  T32A DMA Converter1 Request control
 *  @brief    T32A DMA Converter1 Disable/Enable DMAENx2 Macro Definition.
 *  @{
 */
#define T32AxDMAA_DMAENx2_DISABLE       ((uint32_t)0x00000000)    /*!< disable */
#define T32AxDMAA_DMAENx2_ENABLE        ((uint32_t)0x00000004)    /*!< enable  */
/**
 *  @}
 */ /* End of group T32AxDMAA_DMAENx2 */

/** 
 *  @addtogroup T32AxDMAA_DMAENx1  T32A DMA InputCapture1 Request control
 *  @brief    T32A DMA InputCapture1 Disable/Enable DMAENx1 Macro Definition.
 *  @{
 */
#define T32AxDMAA_DMAENx1_DISABLE       ((uint32_t)0x00000000)    /*!< disable */
#define T32AxDMAA_DMAENx1_ENABLE        ((uint32_t)0x00000002)    /*!< enable  */
/**
 *  @}
 */ /* End of group T32AxDMAA_DMAENx1 */

/** 
 *  @addtogroup T32AxDMAA_DMAENx0  T32A DMA InputCapture0 Request control
 *  @brief    T32A DMA InputCapture0 Disable/Enable DMAENx0 Macro Definition.
 *  @{
 */
#define T32AxDMAA_DMAENx0_DISABLE       ((uint32_t)0x00000000)    /*!< disable */
#define T32AxDMAA_DMAENx0_ENABLE        ((uint32_t)0x00000001)    /*!< enable  */
/**
 *  @}
 */ /* End of group T32AxDMAA_DMAENx0 */

/** 
 *  @addtogroup T32AxCAPx0  T32A Capture Register x0 MASK
 *  @brief    T32A Capture Register x0 MASK CAPx0 Macro Definition.
 *  @{
 */
#define T32AxCAPx0_MASK                 ((uint32_t)0x0000FFFF)    /*!< register value mask */
#define T32AxCAPC0_MASK                 ((uint32_t)0xFFFFFFFF)    /*!< register value mask */
/**
 *  @}
 */ /* End of group T32AxCAPx0 */

/** 
 *  @addtogroup T32AxRUNA_SFTSTPx  T32A SW STOP Control
 *  @brief    T32A SW STOPx SFTSTPx Macro Definition.
 *  @{
 */
#define T32AxRUNA_COUNT_DONT_STOP       ((uint32_t)0x0000000)    /*!< No effect    */
#define T32AxRUNA_COUNT_STOP            ((uint32_t)0x0000004)    /*!< Counter Stop */
/**
 *  @}
 */ /* End of group T32AxRUNA_SFTSTPx */

/** 
 *  @addtogroup T32AxRUNA_SFTSTAx  T32A SW START Control
 *  @brief    T32A SW STARTx SFTSTAx Macro Definition.
 *  @{
 */
#define T32AxRUNA_COUNT_DONT_START      ((uint32_t)0x0000000)    /*!< No effect     */
#define T32AxRUNA_COUNT_START           ((uint32_t)0x0000002)    /*!< Counter Start */
/**
 *  @}
 */ /* End of group T32AxRUNA_SFTSTAx */

/** 
 *  @addtogroup T32AxRUNA_RUNx     T32A RUN Disable/Enable Control
 *  @brief    RUN Disable/Enable RUNx Macro Definition.
 *  @{
 */
#define T32AxRUNA_RUN_DISABLE           ((uint32_t)0x00000000)    /*!< Disable */
#define T32AxRUNA_RUN_ENABLE            ((uint32_t)0x00000001)    /*!< Enable  */
/**
 *  @}
 */ /* End of group T32AxRUNA_RUNx */
 

/** 
 *  @addtogroup T32AxCAPx1  T32A Capture Register x1 MASK
 *  @brief    T32A Capture Register x1 MASK CAPx1 Macro Definition.
 *  @{
 */
#define T32AxCAPx1_MASK                 ((uint32_t)0x0000FFFF)    /*!< register value mask */
#define T32AxCAPC1_MASK                 ((uint32_t)0xFFFFFFFF)    /*!< register value mask */
/**
 *  @}
 */ /* End of group T32AxCAPx1 */


/** 
 *  @name  T32AxRUNA Macro Definition.
 *  @brief T32AxRUNA Register Macro Definition.
 *  @{
 */
#define T32AxRUNA_DISABLE           ((uint32_t)0x00000000)      /*!< SFTSTPA=0,SFTSTAA=0, RUNA=0 */
#define T32AxRUNA_ENABLE            ((uint32_t)0x00000001)      /*!< SFTSTPA=0,SFTSTAA=0, RUNA=1 */
#define T32AxRUNA_UPCOUNT_START     ((uint32_t)0x00000003)      /*!< SFTSTPA=0,SFTSTAA=1, RUNA=1 */
#define T32AxRUNA_UPCOUNT_STOP      ((uint32_t)0x00000004)      /*!< SFTSTPA=1,SFTSTAA=0, RUNA=0 */
#define T32AxRUNA_RUNFLGA_MASK      ((uint32_t)0x00000010)      /*!< Mask for RUNFLGA            */
#define T32AxRUNA_RUNFLGA_RUN       ((uint32_t)0x00000010)      /*!< RUNFLGA=1                   */
/**
 *  @}
 */ /* End of name T32AxRUNA Macro Definition */
/** 
 *  @name  T32AxRUNB Macro Definition.
 *  @brief T32AxRUNB Register Macro Definition.
 *  @{
 */
#define T32AxRUNB_DISABLE           ((uint32_t)0x00000000)      /*!< SFTSTPA=0,SFTSTAA=0, RUNB=0 */
#define T32AxRUNB_ENABLE            ((uint32_t)0x00000001)      /*!< SFTSTPA=0,SFTSTAA=0, RUNB=1 */
#define T32AxRUNB_UPCOUNT_START     ((uint32_t)0x00000003)      /*!< SFTSTPB=0,SFTSTAB=1, RUNB=1 */
#define T32AxRUNB_UPCOUNT_STOP      ((uint32_t)0x00000004)      /*!< SFTSTPB=1,SFTSTAB=0, RUNB=0 */
#define T32AxRUNB_RUNFLGB_MASK      ((uint32_t)0x00000010)      /*!< Mask for RUNFLGB            */
#define T32AxRUNB_RUNFLGB_RUN       ((uint32_t)0x00000010)      /*!< RUNFLGB=1                   */
/**
 *  @}
 */ /* End of name T32AxRUNA Macro Definition */
/** 
 *  @addtogroup  T32AStartError T32A Start Error 
 *  @brief    T32A Start Error  .
 *  @{
 */
#define ERROR_T32A_START      ((uint32_t)(1))
/** 
 *  @}
 */ /* End of group T32AStartError */
 /** 
 *  @addtogroup  T32ACounterError T32A Start Error 
 *  @brief    T32A Counter Error  .
 *  @{
 */
#define ERROR_T32A_COUNTER      ((uint32_t)(2))
/** 
 *  @}
 */ /* End of group T32ACounterError */


/** 
 *  @name  FLAG Macro Definition.
 *  @brief FLAG detection Macro Definition.
 *  @{
 */
#define FLAG_DETECT             1
#define NOT_DETECT              0
/**
 *  @}
 */ /* End of name FLAG detection Macro Definition */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_enum RDA_T32A Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Private_typedef RDA_T32A Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_T32A_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_T32A_Exported_functions RDA_T32A Exported Functions
 *  @{
 */

void T32A0_A_IntervalTimer_Config(void);
void T32A3_A_PPG_Config(void);
void T32A1_A_CAP_Config(void);
void T32A1_A_CAP_TRM_Config(uint32_t TRM_Select_Type);
void T32A3_A_PPG1_Config(void);
void T32A3_B_PPG2_Config(void);
void T32A3_B_PPG2_TRM_Config(void);
void T32A0_A_Start(void);
void T32A0_A_Stop(void);
void T32A1_A_Start(void);
void T32A1_A_Stop(void);
void T32A3_A_Start(void);
void T32A3_A_Stop(void);
void T32A3_B_Start(void);
void T32A3_B_Stop(void);
uint32_t Get_param_T32A0_INTA1(void);
void Clear_flag_T32A0_INTA(void);
uint32_t Get_param_T32A1_INTA1(void);
void Clear_flag_T32A1_INTA(void);
uint32_t Get_param_T32A3_INTA1(void);
void Clear_flag_T32A3_INTA(void);
uint32_t Get_param_T32A3_INTB1(void);
void Clear_flag_T32A3_INTB(void);
void Set_T32A3_RGA0_value(uint32_t);
void Set_T32A3_RGA1_value(uint32_t);
uint32_t Get_T32A1_CAPA0_value(void);
uint32_t Get_T32A1_CAPA1_value(void);
bool Get_param_T32A_CH0_INTA1(void);
void Clear_flag_T32A_CH0_INTA(void);
bool Get_param_T32A3_RUNFLGA(void);

/* Self-Diagnosis */
void T32A0_A_CLCOKIRQ_Config(void);
void T32A0_B_CLCOKIRQ_Config(void);
void T32A0_C_CLCOKIRQ_Config(void);
void T32A0_B_Start(void);
void T32A0_B_Stop(void);
void T32A0_C_Start(void);
void T32A0_C_Stop(void);
uint32_t Get_T32A0_A_STA_value(void);
uint32_t Get_T32A0_B_STA_value(void);
uint32_t Get_T32A0_C_STA_value(void);


/**
 *  @}
 */ /* End of group RDA_T32A_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_T32A */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_T32A_C_H */


