/**
 *******************************************************************************
 * @file    rda_trm_b.c
 * @brief   This file provides API functions for TRM rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include <stdio.h>
#include <stdlib.h>
#include "trm.h"
#include "t32a.h"
#include "cg.h"

#if defined(__TRM_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_TRM RDA_TRM
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_config RDA_TRM Private Config
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group RDA_TRM_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_define RDA_TRM Private Define
 *  @{
 */

#define TRMOSCPRO_ENABLE   (0x000000C1UL)  /* Writing register control enable.  */
#define TRMOSCPRO_DISABLE  (0x00000000UL)  /* Writing register control disable. */
#define TRMOSCEN_MASK      (0x00000001UL)  /* Trimming Control enable.          */
#define TRIM_MASK          (0x000001FEUL)  /* Trimming value mask.              */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_enum RDA_TRM Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_typedef RDA_TRM Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                         */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_variable RDA_TRM Private Variable
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_fuctions RDA_TRM Exported Fuctions
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TRMOSC_Private_variables TRMOSC Private Variables
 *  @{
 */
static IOSCADJ_TypeDef    IoscAdjust;
static TRM_ControlTypeDef AdjustData;
static int32_t            difference;

/**
 *  @}
 */ /* End of group TRMOSC_Private_variables */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
static void     SetTrmOsc(TRM_ControlTypeDef *ControlStruct);
static void     MeasureWave(IOSCADJ_TypeDef *Measure);
static void     StartCapture(uint32_t TRM_Select_Type);
static void     StopCapture(void);
static uint32_t GetCaptureData(void);
static int32_t  CalcDiff(IOSCADJ_TypeDef *Diff);
static int32_t  GetAdjustmentValue(void);
static uint32_t GetInitTrimValue(void);
static int32_t  CalcAdjVal(IOSCADJ_TypeDef *Adjust);

/*--------------------------------------------------*/
/** 
  * @brief  TRM_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void TRM_Config(void)
{
    TRM_ControlTypeDef InitData;
    
    InitData.TrimmingControl = TRMOSC_CONTROL_ENABLE;
    InitData.TrimmingValue   = 0x00000080;
    
    SetTrmOsc(&InitData);
}

/*--------------------------------------------------*/
/** 
  * @brief  Adjustment of internal OSC
  * @param  -
  * @retval TRMOSC_DONE, TRMOSC_ERROR, TRMOSC_RUN
  * @note   -
  */
/*--------------------------------------------------*/
int32_t IOSCAdjustment( uint32_t TRM_Select_Type )
{
    int32_t retval;
    IoscAdjust.TRM_Select_Type = TRM_Select_Type;
    
    MeasureWave(&IoscAdjust);               /* Measurement Waveform            */
    retval = CalcDiff(&IoscAdjust);         /* Calculation of difference       */
    if( retval == TRMOSC_RUN )
    {
        retval = CalcAdjVal(&IoscAdjust);   /* Calculation of adjustment value */
        if( retval == TRMOSC_RUN )
        {
            AdjustData.TrimmingControl = TRMOSC_CONTROL_ENABLE;
            AdjustData.TrimmingValue   = IoscAdjust.Trim;
            SetTrmOsc(&AdjustData);         /* Set TRMOSC register             */
        }
        else
        {                                   /* TRMOSC_ERROR */
            /* do nothing */
        }
    }
    else
    {                                      /* TRMOSC_DONE  */
        /* do nothing */
    }
    return (retval);
}

/*--------------------------------------------------*/
/** 
  * @brief  Set TRM register
  * @param  TRMOSC Control Structure
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void SetTrmOsc(TRM_ControlTypeDef *ControlStruct)
{
    uint32_t tmp = 0;
    
    TSB_TRM->OSCPRO = TRMOSCPRO_ENABLE;
    /* OSCEN disable change to enable set OSCET1,OSCET2 */
    
    if(  (TSB_TRM->OSCEN                 == TRMOSC_CONTROL_DISABLE)
       &&(ControlStruct->TrimmingControl == TRMOSC_CONTROL_ENABLE ))
    {
        TSB_TRM->OSCSET0 = TSB_TRM->OSCINIT0;
        TSB_TRM->OSCSET1 = TSB_TRM->OSCINIT1;
        TSB_TRM->OSCSET2 = TSB_TRM->OSCINIT2;
    }
    TSB_TRM->OSCEN  = ControlStruct->TrimmingControl;
    
    tmp = (ControlStruct->TrimmingValue << 1) & TRIM_MASK;
    TSB_TRM->OSCSET0 = tmp;
    
    TSB_TRM->OSCPRO = TRMOSCPRO_DISABLE;

    /* Internal HOSC Warm-up Time Set*/
    Set_CG_IOSC_WUPT_value();
    /* Warm-up Timer Start  */
    Set_param_CG_WUON();
    /* Check Warm-up Timer status */
    /* [CGWUPHCR]<WUEF>  : Read(wait for done) */
    Get_param_CG_WUEF();

}

/*--------------------------------------------------*/
/** 
  * @brief  Measurement Waveform
  * @param  Measure  :TRMOSC adjustment Structure
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void MeasureWave(IOSCADJ_TypeDef *Measure )
{
    StartCapture( Measure->TRM_Select_Type );
    
    Measure->MeasureVal = GetCaptureData();
    
    StopCapture();
}

/*--------------------------------------------------*/
/** 
  * @brief  Start Capture
  * @param  -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void StartCapture(uint32_t TRM_Select_Type)
{
#ifdef TRMOSC_LOSC
    BSP_T32A_REFIN_RUNB_SFTSTPB = 1;
    if( t32a_deinit(&timer_refin, T32A_TIMERB) != TXZ_SUCCESS )
    {
        /* no processing */
    }
    NVIC_ClearPendingIRQ( BSP_INTT32A_REFIN_BCAP1_IRQn );
    if( t32a_timer_init(&timer_refin, T32A_TIMERB) != TXZ_SUCCESS )
    {
        /* no processing */
    }
#else
    BSP_T32A_REFIN_RUNA_SFTSTPA = 1;
    
    T32A1_A_Stop();
    
    NVIC_ClearPendingIRQ( INTT32A01ACCAP0_IRQn );
    NVIC_ClearPendingIRQ( INTT32A01ACCAP1_IRQn );
    
    T32A1_A_CAP_TRM_Config( TRM_Select_Type );
    
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  Stop Capture
  * @param  -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
static void StopCapture(void)
{
#ifdef TRMOSC_LOSC
    BSP_T32A_REFIN_RUNB_SFTSTPB = 1;
    if( t32a_deinit(&timer_refin, T32A_TIMERB) != TXZ_SUCCESS )
    {
        /* no processing */
    }
    NVIC_ClearPendingIRQ( BSP_INTT32A_REFIN_BCAP1_IRQn );
#else
    BSP_T32A_REFIN_RUNA_SFTSTPA = 1;
    
    T32A1_A_Stop();
    
    NVIC_ClearPendingIRQ( INTT32A01ACCAP0_IRQn );
    NVIC_ClearPendingIRQ( INTT32A01ACCAP1_IRQn );
#endif
}

/*--------------------------------------------------*/
/** 
  * @brief  Get Capture Data
  * @param  -
  * @retval Capture value
  * @note   -
  */
/*--------------------------------------------------*/
static uint32_t GetCaptureData(void)
{
#ifdef TRMOSC_LOSC
    uint32_t retval = 0;
    uint32_t captop = 0;
    uint32_t capend = 0;
    
    for (;;)
    {
        NVIC_ClearPendingIRQ( BSP_INTT32A_REFIN_BCAP1_IRQn );
        while( NVIC_GetPendingIRQ(BSP_INTT32A_REFIN_BCAP1_IRQn) == 0 )
        {
            /* waiting raising edge ... */
        }
        captop = (timer_refin.p_instance->CAPB1 & T32A_CAPx1_MASK);

        NVIC_ClearPendingIRQ( BSP_INTT32A_REFIN_BCAP1_IRQn );
        while( NVIC_GetPendingIRQ(BSP_INTT32A_REFIN_BCAP1_IRQn) == 0 )
        {
            /* waiting raising edge ... */
        }
        capend = (timer_refin.p_instance->CAPB1 & T32A_CAPx1_MASK);

        if( captop < capend )
        {
            retval = capend - captop;
        }
        else
        {
            retval = capend + (0xffff - captop);
        }
        break;
    }
#else
    uint32_t retval = 0;
    
    for (;;)
    {
        NVIC_ClearPendingIRQ( INTT32A01ACCAP0_IRQn );
        while( NVIC_GetPendingIRQ(INTT32A01ACCAP0_IRQn) == 0 )
        {
            /* waiting falling edge ... */
        }
        NVIC_ClearPendingIRQ( INTT32A01ACCAP1_IRQn );
        while( NVIC_GetPendingIRQ(INTT32A01ACCAP1_IRQn) == 0 )
        {
            /* waiting raising edge ... */
        }
        retval = (TSB_T32A1->CAPA1 & T32AxCAPx1_MASK);
        break;
    }
#endif
    return(retval); 
}

/*--------------------------------------------------*/
/** 
  * @brief  Calculation of difference
  * @param  Diff  :TRMOSC adjustment Structure
  * @retval TRMOSC_DONE, TRMOSC_ERROR
  * @note   -
  */
/*--------------------------------------------------*/
static int32_t CalcDiff(IOSCADJ_TypeDef *Diff)
{
    uint32_t absdiff;
    int32_t  retval;
    
    if( Diff->TRM_Select_Type == PPG_SELECT )
    {
        Diff->MeasureDiff = (int32_t)((100*FIXEDPOINT)-((Diff->MeasureVal * (100*FIXEDPOINT)) / CAPTUREVAL10MHZ  ));
    }
    else
    {
        Diff->MeasureDiff = (int32_t)((100*FIXEDPOINT)-((Diff->MeasureVal * (100*FIXEDPOINT)) / CAPTUREVAL2400bps));
    }
    
    absdiff = (uint32_t)abs(Diff->MeasureDiff);
    if( absdiff <= MARGINADJUST )
    {
        retval = TRMOSC_DONE;
    }
    else
    {
        retval = TRMOSC_RUN;
    }
    
    return (retval);
}

/*--------------------------------------------------*/
/** 
  * @brief  Calculation of adjustment value
  * @param  Adjust  :TRMOSC adjustment Structure
  * @retval TRMOSC_RUN, TRMOSC_ERROR
  * @note   -
  */
/*--------------------------------------------------*/
static int32_t CalcAdjVal(IOSCADJ_TypeDef *Adjust)
{
    int32_t  retval;
    uint32_t trim;
    uint32_t adjust_step;
    
    adjust_step = (uint32_t)(abs(Adjust->MeasureDiff)/TRIMSTEP);
    /* adjust step (at least 1)check */
    if( adjust_step == 0 )
    {
        adjust_step += 1; 
    }
    
    /* plus diretion */
    if( Adjust->MeasureDiff > 0 )
    {
        difference = (adjust_step*TRIMSTEP)+GetAdjustmentValue();
    }
    /* minus direction */
    else
    {
        difference = -(adjust_step*TRIMSTEP)+GetAdjustmentValue();
    }
     
    /* adujust value */
    trim = (uint32_t)(abs(difference)/TRIMSTEP);
    
    if( difference < 0 )
    {
        trim = TRIM_MAX-trim;
        if( trim > TRIMLIMIT )
        {
            Adjust->Trim = trim;
            retval = TRMOSC_RUN;
        }
        else
        {
            retval = TRMOSC_ERROR;
        }
    }
    else
    {
        if( trim <= TRIMLIMIT )
        {
            Adjust->Trim = trim;
            retval = TRMOSC_RUN;
        }
        else
        {
            retval = TRMOSC_ERROR;
        }
    }
    
    return (retval);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get Adjustment value
  * @param  -
  * @retval Adjustment value
  * @note   -
  */
/*--------------------------------------------------*/
static int32_t GetAdjustmentValue(void)
{
    uint32_t trimvalue;
    int32_t  adjvalue;
    
    if( GetTrimmingControlValue() == TRMOSC_CONTROL_DISABLE )
    {
        trimvalue = GetInitTrimValue();
    }
    else
    {
        trimvalue = GetSetTrimValue();
    }


    if( trimvalue > TRIMLIMIT )
    {
        trimvalue = TRIM_MAX - trimvalue;
        adjvalue = -(TRIMSTEP*trimvalue);
    }
    else
    {
        adjvalue = TRIMSTEP*trimvalue;
    }
    
    return (adjvalue);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get Trimming Control Value
  * @param  -
  * @retval Trimming Control value
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t GetTrimmingControlValue(void)
{
    return (TSB_TRM->OSCEN & TRMOSCEN_MASK);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get Initial Trimming Value
  * @param  -
  * @retval Initial Trimming value
  * @note   -
  */
/*--------------------------------------------------*/
static uint32_t GetInitTrimValue(void)
{
    return ((TSB_TRM->OSCINIT0 & TRIM_MASK) >> 1);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get Seting Trimming value 
  * @param  -
  * @retval setting Trimming value 
  * @note   -
  */
/*--------------------------------------------------*/
uint32_t GetSetTrimValue(void)
{
    return ((TSB_TRM->OSCSET0 & TRIM_MASK) >> 1);
}

/*--------------------------------------------------*/
/**
 *  @}
 */ /* End of group RDA_TRM_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_TRM */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__TRM_B_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

