/** 
 *******************************************************************************
 * @file    rda_trm_b.h
 * @brief   This file provides rda_trm definition.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_TRM_B_H
#define __RDA_TRM_B_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
#include "t32a.h"

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_TRM RDA_TRM
 *  @brief    TRM Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup  MEMORY_CONFIG MEMORY CONFIG
 *  @brief     MEMORY CONFIG
 *  @{
 */

/** 
 *  @}
 */ /* End of group MEMORY_CONFIG */

/** 
 *  @addtogroup TRMOSC_Private_define TRMOSC Private Define
 *  @{
 */
#define TRMOSC_RUN             (1)             /*!< run   */
#define TRMOSC_DONE            (0)             /*!< done  */
#define TRMOSC_ERROR           (-1)            /*!< error */

#ifdef TRMOSC_LOSC
#define CAPTUREVAL10MHZ        (9765)          /*!< Caputer value @10MHz   */
#else
#define CAPTUREVAL10MHZ        (10416)         /*!< Caputer value @10MHz   */
#endif
#define CAPTUREVAL2400bps      (21000)         /*!< Caputer value @2400bps */
#define FIXEDPOINT             (100)           /*!< fixed point 2 */
#define TRIMSTEP               (7)             /*!< trimming step 0.07% * 100 * FIXEDPOINT */
#define MARGINADJUST           (20)            /*!< Adjustment margin 0.2% * 100 * FIEXDPOINT */
#define TRIMLIMIT              (0x0000007FUL)  /*!< Setting limit */
#define TRIM_MAX               (0x00000100UL)  /*!< max value */
/** 
 *  @addtogroup ELOSCConfiguration ELOSC Configuration
 *  @brief    ELOSC Configuration.
 *  @{
 */
#define ELOSC_CFG_WARM_UP_TIME  ((uint32_t)(5000))      /*!< Warm up time(us). */
#define ELOSC_CFG_CLOCK         ((uint32_t)(32768))     /*!< Clock(hz).        */
/** 
 *  @}
 */ /* End of group ELOSCConfiguration */
 
/** 
 *  @addtogroup TRM_Control  Trimming Control
 *  @brief    Trimming Control.
 *  @{
 */
#define  TRMOSC_CONTROL_ENABLE      (0x00000001UL)      /*!< Trimming Control enable   */
#define  TRMOSC_CONTROL_DISABLE     (0x00000000UL)      /*!< Trimming Control disable  */
/**
 *  @}
 */ /* End of group TRM_Control */


/** 
 *  @addtogroup RDA_TRM_Private_define RDA_TRM Private Define
 *  @{
 */
#ifdef TRMOSC_LOSC
#define BSP_T32A_REFIN                 TSB_T32A6
#define BSP_INTT32A_REFIN_BCAP1_IRQn   INTT32A06BCAP1_IRQn
#define BSP_T32A_REFIN_RUNA_SFTSTAA    TSB_T32A6_RUNA_SFTSTAA
#define BSP_T32A_REFIN_RUNB_SFTSTPB    TSB_T32A6_RUNB_SFTSTPB
#else
#define BSP_T32A_REFIN                 TSB_T32A1
#define BSP_INTT32A_REFIN_ACCAP0_IRQn  INTT32A01ACCAP0_IRQn
#define BSP_INTT32A_REFIN_ACCAP1_IRQn  INTT32A01ACCAP1_IRQn
#define BSP_T32A_REFIN_RUNA_SFTSTPA    TSB_T32A1_RUNA_SFTSTPA
#endif
#define BSP_T32A_SOUT                  TSB_T32A3
#define BSP_T32A_SOUT_RUNA_SFTSTAA     TSB_T32A3_RUNA_SFTSTAA

/**
 *  @}
 */ /* End of group RDA_TRM_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/

/*----------------------------------*/
/** 
 * @brief  TRM handle structure definenition.
*/
/*----------------------------------*/
typedef struct {
    uint32_t TrimmingControl;       /*!< Value to TRIMEN   */
    uint32_t TrimmingValue;         /*!< Value to TRIMSETC */
} TRM_ControlTypeDef;

/*----------------------------------*/
/** 
 * @brief Adjustment Information.
*/
/*----------------------------------*/
typedef struct
{
    uint32_t MeasureVal;
    int32_t  MeasureDiff;
    uint32_t Trim;
    uint32_t TRM_Select_Type;
} IOSCADJ_TypeDef;

/**
 *  @}
 */ /* End of group TRM_Private_typedef */

/** 
 *  @addtogroup RDA_TRM_Private_enum RDA_TRM Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Private_typedef RDA_TRM Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_TRM_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TRM_Exported_functions RDA_TRM Exported Functions
 *  @{
 */
void     TRM_Config(void);
int32_t  IOSCAdjustment( uint32_t TRM_Select_Type );
uint32_t GetTrimmingControlValue(void);
uint32_t GetSetTrimValue(void);

/**
 *  @}
 */ /* End of group RDA_TRM_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_TRM */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_TRM_B_H */


