/**
 *******************************************************************************
 * @file    rda_tspi_e.c
 * @brief   This file provides API functions for TSPI rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "tspi.h"

#if defined(__TSPI_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/* no define */

/** 
 *  @addtogroup RDA_TSPI RDA_TSPI
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_config RDA_TSPI Private Config
 *  @{
 */

/** 
 *  @}
 */ /* End of group RDA_TSPI_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup TSPI_MASTER_TRANS_Private_macro TSPI_MASTER_TRANS Private Macro
 *  @{
*/

/** 
 *  @}
 */ /* End of group TSPI_MASTER_TRANS_Private_macro */

 
/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_enum RDA_TSPI Private Enum
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_TSPI_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_typedef RDA_TSPI Private Typedef
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_TSPI_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Private Member                                                              */
/*------------------------------------------------------------------------------*/
/**
 *  @addtogroup RDA_TSPI__Private_variables RDA_TSPI_ Private Variables
 *  @{
 */


/**
 *  @}
 */ /* End of group TSPI_MasterSlave_Private_variables */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_variable RDA_TSPI Private Variable
 *  @{
 */
/* no define */
/**
 *  @}
 */ /* End of group RDA_TSPI_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_fuctions RDA_TSPI Exported Fuctions
 *  @{
 */


/*--------------------------------------------------*/
/** 
  * @brief  TSPI0_Master_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void TSPI0_Master_Config(uint32_t cr1_data, uint32_t cr2_data)
{
    
    /* TSPI Control Register0     */
    TSB_TSPI0->CR0 = TSPI_RESET10 | TSPI_ENABLE;
    TSB_TSPI0->CR0 = TSPI_RESET01 | TSPI_ENABLE;
    
    __NOP();
    __NOP();
    
    TSB_TSPI0->CR1   = cr1_data;
    
    TSB_TSPI0->CR2   = cr2_data;
    
    TSB_TSPI0->BR    = TSPIxBR_MASTER_INIT;
    
    TSB_TSPI0->FMTR0 = TSPIxFMT0_MASTER_TX_INIT;
}

/*--------------------------------------------------*/
/** 
  * @brief  TSPI_Slave_Config
  * @param[in] -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void TSPI0_Slave_Config(uint32_t cr1_data, uint32_t cr2_data)
{
    
    /* TSPI Control Register0     */
    TSB_TSPI0->CR0 = TSPI_RESET10 | TSPI_ENABLE;
    TSB_TSPI0->CR0 = TSPI_RESET01 | TSPI_ENABLE;
    
    __NOP();
    __NOP();
    
    TSB_TSPI0->CR1   = cr1_data;
    
    TSB_TSPI0->CR2   = cr2_data;
    
    TSB_TSPI0->BR    = TSPIxBR_SLAVE_INIT;
    
    TSB_TSPI0->FMTR0 = TSPIxFMT0_SLAVE_RX_INIT;
}

/*--------------------------------------------------*/
/** 
  * @fn     enable_TSPI0_TRXE(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void enable_TSPI0_TRXE(void)
{
    TSB_TSPI0_CR1_TRXE = 1;
}

/*--------------------------------------------------*/
/** 
  * @fn     disable_TSPI0_TRXE(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void disable_TSPI0_TRXE(void)
{
    TSB_TSPI0_CR1_TRXE = 0;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_allflag_TSPI0_ERR(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_allflag_TSPI0_ERR(void)
{
    TSB_TSPI0->ERR = TSPIxERR_TRGERR |
                     TSPIxERR_UDRERR |
                     TSPIxERR_OVRERR |
                     TSPIxERR_PERR   ;
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_TSPI0_INTTXWF(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_TSPI0_INTTXWF(void)
{
    TSB_TSPI0->SR = (uint32_t)(0x00200000);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_INTTXWF(void)
  * @brief  
  * @param  -
  * @return INTTXWF flag
  * @retval - 
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_INTTXWF(void)
{
    bool ret;
    
    /* INTTXWF Status  */
    ret = TSB_TSPI0_SR_INTTXWF;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_TXRUN(void)
  * @brief  
  * @param  -
  * @return TXRUN flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_TXRUN(void)
{
    bool ret;
    
    /* TXRUN Status    */
    ret = TSB_TSPI0_SR_TXRUN;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_TFEMP(void)
  * @brief  
  * @param  -
  * @return TFEMP flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_TFEMP(void)
{
    bool ret;
    
    /* TFEMP Status    */
    ret = TSB_TSPI0_SR_TFEMP;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_param_TSPI0_TFEMPCLR(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_param_TSPI0_TFEMPCLR(void)
{
    /* TFEMP Status Clear    */
    TSB_TSPI0_CR3_TFEMPCLR = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_TSPI0_TLVL_value(void)
  * @brief  
  * @param  -
  * @return TLVL value
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_TSPI0_TLVL_value(void)
{
    uint8_t ret;
    
    /* Tx FIFO Fill Leve  */
    ret = ( TSB_TSPI0->SR & TSPIxSR_TLVL_MASK ) >> TSPIxSR_TLVL_SHIFT;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_TSPI0_RLVL_value(void)
  * @brief  
  * @param  -
  * @return RLVL value
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_TSPI0_RLVL_value(void)
{
    uint8_t ret;
    
    /* Rx FIFO Fill Level  */
    ret = ( TSB_TSPI0->SR & TSPIxSR_RLVL_MASK ) >> TSPIxSR_RLVL_SHIFT;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_TSPI0_DR_value(uint8_t data)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_TSPI0_DR_value(uint8_t data)
{
    TSB_TSPI0->DR = data;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_TSPI0_INTRXFF(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_TSPI0_INTRXFF(void)
{
    TSB_TSPI0->SR = (uint32_t)(0x00000020);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_INTRXFF(void)
  * @brief  
  * @param  -
  * @return INTRXFF flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_INTRXFF(void)
{
    bool ret;
    
    /* INTRXFF Status   */
    ret = TSB_TSPI0_SR_INTRXFF;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_RXRUN(void)
  * @brief  
  * @param  -
  * @return RXRUN flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_RXRUN(void)
{
    bool ret;
    
    /* RXRUN Status    */
    ret = TSB_TSPI0_SR_RXRUN;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_TSPI0_RXEND(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_TSPI0_RXEND(void)
{
    TSB_TSPI0->SR = (uint32_t)(0x00000040);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_RXEND(void)
  * @brief  
  * @param  -
  * @return RXEND flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_RXEND(void)
{
    bool ret;
    
    /* RXEND Status    */
    ret = TSB_TSPI0_SR_RXEND;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_TSPI0_DR_value(void)
  * @brief  
  * @param  -
  * @return DR value
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
uint8_t Get_TSPI0_DR_value(void)
{
    uint8_t ret;
    
    /* Data Read      */
    ret = TSB_TSPI0->DR;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_RFFLL(void)
  * @brief  
  * @param  -
  * @return RFFLL flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_RFFLL(void)
{
    bool ret;
    
    /* RFFLL Status    */
    ret = TSB_TSPI0_SR_RFFLL;
    
    return ( ret );
}

/*--------------------------------------------------*/
/** 
  * @fn     Set_param_TSPI0_RFFLLCLR(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Set_param_TSPI0_RFFLLCLR(void)
{
    TSB_TSPI0_CR3_RFFLLCLR = 1;  
}

/*--------------------------------------------------*/
/** 
  * @fn     Clear_flag_TSPI0_TXEND(void)
  * @brief  
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void Clear_flag_TSPI0_TXEND(void)
{
    TSB_TSPI0->SR = (uint32_t)(0x00400000);
}

/*--------------------------------------------------*/
/** 
  * @fn     Get_param_TSPI0_TXEND(void)
  * @brief  
  * @param  -
  * @return TXEND flag
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
bool Get_param_TSPI0_TXEND(void)
{
    bool ret;
    
    /* TXEND Status    */
    ret = TSB_TSPI0_SR_TXEND;
    
    return ( ret );
}

/**
 *  @}
 */ /* End of group RDA_TSPI_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_TSPI */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__TSPI_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

