/** 
 *******************************************************************************
 * @file    rda_tspi_e.h
 * @brief   This file provides rda_tspi definition.
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __RDA_TSPI_E_H
#define __RDA_TSPI_E_H

#ifdef __cplusplus
extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
  

/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_TSPI RDA_TSPI
 *  @brief    TSPI Driver.
 *  @{
 */
/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_define RDA_TSPI Private Define
 *  @{
 */
/** 
 *  @name  FLAG Macro Definition.
 *  @brief FLAG detection Macro Definition.
 *  @{
 */
#define FLAG_NOT_DETECT 0
#define FLAG_DETECT     1

/** 
 *  @addtogroup  TSPIError TSPI Error 
 *  @brief    Error  .
 *  @{
 */
#define ERROR_TSPI      ((uint32_t)(1))
/** 
 *  @}
 */ /* End of group TSPIError */
/** 
 *  @addtogroup TSPI_SW_Reset SW Reset
 *  @brief    Software Rest Macro Definition.
 *  @{
 */
#define TSPI_RESET10                ((uint32_t)0x00000080)    /*!< RESET Pattarn 10 */
#define TSPI_RESET01                ((uint32_t)0x00000040)    /*!< RESET Pattarn 01 */
/**
 *  @}
 */ /* End of group TSPI_SW_Reset */
 

/** 
 *  @addtogroup TSPI_Enable  TSPI Enable/Disable Control
 *  @brief    Enable/Disable TSPIE Macro Definition.
 *  @{
 */
#define TSPI_DISABLE                ((uint32_t)0x00000000)    /*!< Disable */
#define TSPI_ENABLE                 ((uint32_t)0x00000001)    /*!< Enable  */
/**
 *  @}
 */ /* End of group TSPI_Enable */

/** 
 *  @name  TSPIxCR1 Macro Definition.
 *  @brief TSPIxCR1 Register Macro Definition.
 *  @{
 */
#define TSPIxCR1_INF_ENABLE         ((uint32_t)0x00010000)     /*!< INF=1                                                      */
#define TSPIxCR1_INF_DISABLE        ((uint32_t)0x00000000)     /*!< INF=0                                                      */

#define TSPIxCR1_TRGEN_ENABLE       ((uint32_t)0x00008000)     /*!< TRGEN=1                                                    */
#define TSPIxCR1_TRGEN_DISABLE      ((uint32_t)0x00000000)     /*!< TRGEN=0                                                    */

#define TSPIxCR1_TRXE_ENABLE        ((uint32_t)0x00004000)     /*!< TRXE=1                                                     */
#define TSPIxCR1_TRXE_DISABLE       ((uint32_t)0x00000000)     /*!< TRXE=0                                                     */
#define TSPIxCR1_TRXE_DISABLE_MASK  ((uint32_t)0xFFFFBFFF)     /*!< Mask for TRXE=0                                            */

#define TSPIxCR1_TSPIMS_SIO         ((uint32_t)0x00002000)     /*!< TSPIMS=1                                                   */
#define TSPIxCR1_TSPIMS_SPI         ((uint32_t)0x00000000)     /*!< TSPIMS=0                                                   */

#define TSPIxCR1_MSTR_MASTER        ((uint32_t)0x00001000)     /*!< MSTR=1                                                     */
#define TSPIxCR1_MSTR_SLAVE         ((uint32_t)0x00000000)     /*!< MSTR=0                                                     */

#define TSPIxCR1_TMMD_00            ((uint32_t)0x00000000)     /*!< TMDD=00                                                    */
#define TSPIxCR1_TMMD_01            ((uint32_t)0x00000400)     /*!< TMDD=01                                                    */
#define TSPIxCR1_TMMD_10            ((uint32_t)0x00000800)     /*!< TMDD=10                                                    */
#define TSPIxCR1_TMMD_11            ((uint32_t)0x00000C00)     /*!< TMDD=11                                                    */

#define TSPIxCR1_CSSEL_TSPIxCS0     ((uint32_t)0x00000000)     /*!< CSSEL=00                                                   */
#define TSPIxCR1_CSSEL_TSPIxCS1     ((uint32_t)0x00000100)     /*!< CSSEL=01                                                   */
#define TSPIxCR1_CSSEL_TSPIxCS2     ((uint32_t)0x00000200)     /*!< CSSEL=10                                                   */
#define TSPIxCR1_CSSEL_TSPIxCS3     ((uint32_t)0x00000300)     /*!< CSSEL=11                                                   */

#define TSPIxCR1_FC_CONTINUOUS      ((uint32_t)0x00000000)     /*!< FC=00000000                                                */
#define TSPIxCR1_FC_MASK            ((uint32_t)0x000000FF)     /*!<                                                            */

#define TSPIxCR1_MASTER_TX_INIT     ((uint32_t)0x00001400)     /*!< TRGEN=0,TRXE=0,TSPIMS=0,MSTR=1,TMMD=01,CSSEL=00,FC=00000000 */
#define TSPIxCR1_SLAVE_RX_INIT      ((uint32_t)0x00000800)     /*!< TRGEN=0,TRXE=0,TSPIMS=0,MSTR=0,TMMD=10,CSSEL=00,FC=00000000 */

#define TSPIxCR1_MASTER_RX_INIT     ((uint32_t)0x00001800)     /*!< TRGEN=0,TRXE=0,TSPIMS=0,MSTR=1,TMMD=10,CSSEL=00,FC=00000000 */
#define TSPIxCR1_SLAVE_TX_INIT      ((uint32_t)0x00000400)     /*!< TRGEN=0,TRXE=0,TSPIMS=0,MSTR=0,TMMD=01,CSSEL=00,FC=00000000 */
/**
 *  @}
 */ /* End of name TSPIxCR1 Macro Definition */
/** 
 *  @name  TSPIxCR2 Macro Definition.
 *  @brief TSPIxCR2 Register Macro Definition.
 *  @{
 */
#define TSPIxCR2_MASTER_TX_INIT    ((uint32_t)0x00E10184)
     /*!< TIDLE=11,TXDEMP=1,00,RXDLY=1,TIL=TX_FILL_LEVEL,RIL=0001         ,INTTXFE=1,INTTXWE=0,INTRXFE=0,INTRXWE=0,0,INTERR=1,DMATE=0,DMARE=0 */
#define TSPIxCR2_SLAVE_RX_INIT     ((uint32_t)0x00E10034)
     /*!< TIDLE=11,TXDEMP=1,00,RXDLY=1,TIL=0000         ,RIL=RX_FILL_LEVEL,INTTXFE=0,INTTXWE=0,INTRXFE=1,INTRXWE=1,0,INTERR=1,DMATE=0,DMARE=0 */

#define TSPIxCR2_MASTER_RX_INIT    ((uint32_t)0x00E10034)
     /*!< TIDLE=11,TXDEMP=1,00,RXDLY=1,TIL=0000         ,RIL=RX_FILL_LEVEL,INTTXFE=0,INTTXWE=0,INTRXFE=1,INTRXWE=1,0,INTERR=1,DMATE=0,DMARE=0 */
#define TSPIxCR2_SLAVE_TX_INIT     ((uint32_t)0x00E10184)
     /*!< TIDLE=11,TXDEMP=1,00,RXDLY=1,TIL=TX_FILL_LEVEL,RIL=0001         ,INTTXFE=1,INTTXWE=0,INTRXFE=0,INTRXWE=0,0,INTERR=1,DMATE=0,DMARE=0 */
/**
 *  @}
 */ /* End of name TSPIxCR2 Macro Definition */
/** 
 *  @name  TSPIxFMT0 Macro Definition.
 *  @brief TSPIxFMT0 Register Macro Definition.
 *  @{
 */
#define TSPIxFMT0_MASTER_TX_INIT  ((uint32_t)0x8800CC37)     /*!< DIR=1,0,FL=001000,FINT=0000,CS3POL=0,CS2POL=0,CS1POL=0,CS0POL=0,CKPHA=1,CKPOL=1,CSINT=011,00,CSSCKDL=0011,SCKCSDL=0111 */
#define TSPIxFMT0_SLAVE_RX_INIT   ((uint32_t)0x8800CC37)     /*!< DIR=1,0,FL=001000,FINT=0000,CS3POL=0,CS2POL=0,CS1POL=0,CS0POL=0,CKPHA=1,CKPOL=1,CSINT=011,00,CSSCKDL=0011,SCKCSDL=0111 */
/**
 *  @}
 */ /* End of name TSPIxFMT0 Macro Definition */
/** 
 *  @name  TSPIxBR Macro Definition.
 *  @brief TSPIxBR Register Macro Definition.
 *  @{
 */
#define TSPIxBR_MASTER_INIT  ((uint32_t)0x00000012)       /*!< BRCK=0001,BRS=0010 */
#define TSPIxBR_SLAVE_INIT   ((uint32_t)0x00000012)       /*!< BRCK=0001,BRS=0010 */
/**
 *  @}
 */ /* End of name TSPIxBR Macro Definition */
/** 
 *  @name  TSPIxERR Macro Definition.
 *  @brief TSPIxERR Register Macro Definition.
 *  @{
 */
#define TSPIxERR_TRGERR       ((uint32_t)0x00000008)     /*!< TRGERR=1 */
#define TSPIxERR_UDRERR       ((uint32_t)0x00000004)     /*!< UDRERR=1 */
#define TSPIxERR_OVRERR       ((uint32_t)0x00000002)     /*!< OVRERR=1 */
#define TSPIxERR_PERR         ((uint32_t)0x00000001)     /*!< PERR=1   */
/**
 *  @}
 */ /* End of name TSPIxERR Macro Definition */
 /** 
 *  @name  TSPIxSR Macro Definition.
 *  @brief TSPIxSR Register Macro Definition.
 *  @{
 */
#define TSPIxSR_TLVL_MASK       ((uint32_t)0x000F0000)    /*!<          */
#define TSPIxSR_TLVL_SHIFT      ((uint32_t)16)            /*!<          */
#define TSPIxSR_RLVL_MASK       ((uint32_t)0x0000000F)    /*!<          */
#define TSPIxSR_RLVL_SHIFT      ((uint32_t)0)             /*!<          */
/**
 *  @}
 */ /* End of name TSPIxSR Macro Definition */
/** 
 *  @addtogroup TSPI_TxState  Transmitting State Flag
 *  @brief    Transmitting State Flag Macro Definisiton.
 *  @{
 */
#define TSPI_TX_RUN                      ((uint32_t)0x00800000)    /*!< Active Sending Data */
/**
 *  @}
 */ /* End of group TSPI_TxState */

/** 
 *  @addtogroup TSPI_TxDone  Transmitting Complete Flag
 *  @brief    Transmitting Complete Flag Macro Definisiton.
 *  @{
 */
#define TSPI_TX_DONE_CLR        ((uint32_t)0x00400000)    /*!< Send Data Complete Flag Clear */
/**
 *  @}
 */ /* End of group TSPI_TxDone */

/**
 *  @}
 */ /* End of name FLAG detection Macro Definition */

/**
 *  @}
 */ /* End of group RDA_TSPI_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_enum RDA_TSPI Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_TSPI_Private_enum */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Private_typedef RDA_TSPI Private Typedef
 *  @{
 */

/**
 *  @}
 */ /* End of group RDA_TSPI_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Exported Functions                                                          */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_TSPI_Exported_functions RDA_TSPI Exported Functions
 *  @{
 */

void TSPI0_Master_Config(uint32_t, uint32_t);
void TSPI0_Slave_Config(uint32_t, uint32_t);
void enable_TSPI0_TRXE(void);
void disable_TSPI0_TRXE(void);
void Clear_allflag_TSPI0_ERR(void);
void Clear_flag_TSPI0_INTTXWF(void);
bool Get_param_TSPI0_INTTXWF(void);
bool Get_param_TSPI0_TXRUN(void);
bool Get_param_TSPI0_TFEMP(void);
void Set_param_TSPI0_TFEMPCLR(void);
uint8_t Get_TSPI0_TLVL_value(void);
uint8_t Get_TSPI0_RLVL_value(void);
void Set_TSPI0_DR_value(uint8_t data);
void Clear_flag_TSPI0_INTRXFF(void);
bool Get_param_TSPI0_INTRXFF(void);
bool Get_param_TSPI0_RXRUN(void);
void Clear_flag_TSPI0_RXEND(void);
bool Get_param_TSPI0_RXEND(void);
uint8_t Get_TSPI0_DR_value(void);
bool Get_param_TSPI0_RFFLL(void);
void Set_param_TSPI0_RFFLLCLR(void);
void Clear_flag_TSPI0_TXEND(void);
bool Get_param_TSPI0_TXEND(void);

/**
 *  @}
 */ /* End of group RDA_TSPI_Exported_functions */

/**
 *  @}
 */ /* End of group RDA_TSPI */

/**
 *  @}
 */ /* End of group Periph_Driver */

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* __RDC_TSPI_E_H */


