/**
 *******************************************************************************
 * @file    rda_uart_c.c
 * @brief   This file provides API functions for UART rda.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "uart.h"

#if defined(__UART_H)
/**
 *  @addtogroup Periph_Driver Peripheral Driver
 *  @{
 */

/** 
 *  @addtogroup RDA_UART RDA_UART
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_config RDA_UART Private Config
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group RDA_UART_Private_config */

/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_define RDA_UART Private Define
 *  @{
 */

/** 
 *  @name  NULL Pointer
 *  @brief NULL Pointer.
 *  @{
 */
#define UART_IO_IO_NULL           ((void *)0)
/**
 *  @}
 */ /* End of name NULL Pointer */
/** 
 *  @addtogroup BaudRateConfiguration BaudRate Configuration
 *  @brief    BaudRate .
 *  @{
 */
#define CFG_BAUDRATE             ((uint32_t)(115200))
#define CFG_BAUDRATE_SET_VAL     ((uint32_t)(0x00A6002B))
#define CFG_BAUDRATE_SET_VAL_10M ((uint32_t)(0x00A50005))
/** 
 *  @}
 */ /* End of group BaudRateConfiguration */
/** 
 *  @addtogroup UART_DataConfiguration  Data Configuration
 *  @brief    Data Configuration Macro Definisiton.
 *  @{
 */
#define UART_DATA_DIRECTION_LSB         ((uint32_t)0x00000000)    /*!< LSB first */
#define UART_STOP_BIT_1                 ((uint32_t)0x00000000)    /*!< 1 bit */
#define UART_PARITY_BIT_ODD             ((uint32_t)0x00000000)    /*!< Odd Parity  */
#define UART_PARITY_DISABLE             ((uint32_t)0x00000000)    /*!< Disable */
#define UART_DATA_LENGTH_8              ((uint32_t)0x00000001)    /*!< 8 bit */
 /**
 *  @}
 */ /* End of group UART_DataLength */
/** 
 *  @addtogroup UART_RxInterrupt  Rx Interrpt
 *  @brief    Available Receive Interrupt Macro Definisiton.
 *  @{
 */
#define UART_RX_DMARE                   ((uint32_t)0x00000001)    /*!< Available.     */
/**
 *  @}
 */ /* End of group UART_RxInterrupt */
/**
 *  @addtogroup UART_TxEnable  Transmitting Enable
 *  @brief    Transmitting Enable Macro Definisiton.
 *  @{
 */
#define UART_TXE_ENABLE                 ((uint32_t)0x00000002)    /*!< Transmitting Enable */
#define UART_TXE_DISABLE                ((uint32_t)0xFFFFFFFD)    /*!< Transmitting Disable */
/**
 *  @}
 */ /* End of group UART_TxEnable */
/** 
 *  @addtogroup UART_RxEnable  Receiving Enable
 *  @brief    Receiving Enable Macro Definisiton.
 *  @{
 */
#define UART_RXE_ENABLE                 ((uint32_t)0x00000001)    /*!< Receiving Enable */
#define UART_RXE_DISABLE                ((uint32_t)0x00000000)    /*!< Receiving Disable */
/**
 *  @}
 */ /* End of group UART_RxEnable */
/** 
 *  @addtogroup UART_RxState  Rx State
 *  @brief    Receive State Macro Definisiton.
 *  @{
 */
#define UART_RX_STATE_RUN               ((uint32_t)0x00000080)    /*!< Run      */
/**
 *  @}
 */ /* End of group UART_RxState */
/** 
 *  @addtogroup UART_Prescaler  Prescaler
 *  @brief    Prescaler Macro Definisiton.
 *  @{
 */
#define UART_PLESCALER_1                ((uint32_t)0x00000000)    /*!< 1/1   */
/**
 *  @}
 */ /* End of group UART_Prescaler */
/** 
 *  @addtogroup UART_TxInterrupt  Tx Interrpt
 *  @brief    Available Transmit Interrupt Macro Definisiton.
 *  @{
 */
#define UART_TX_INT_ENABLE              ((uint32_t)0x00000040)    /*!< Available.     */
/**
 *  @}
 */ /* End of group UART_TxInterrupt */
/** 
 *  @addtogroup UART_TxDMA  Tx DMA
 *  @brief    Available Transmit Interrupt Macro Definisiton.
 *  @{
 */
#define UART_TX_DMATE                   ((uint32_t)0x00000002)    /*!< Available.     */
/**
 *  @}
 */ /* End of group UART_TxDMA */
/** 
 *  @addtogroup UART_TxState  Tx State
 *  @brief    Transmitting State Macro Definisiton.
 *  @{
 */
#define UART_TX_STATE_RUN               ((uint32_t)0x00008000)    /*!< Run       */
/**
 *  @}
 */ /* End of group UART_TxState */
/** 
 *  @addtogroup UART_RxInterrupt  Rx Interrpt
 *  @brief    Available Receive Interrupt Macro Definisiton.
 *  @{
 */
#define UART_RX_INT_ENABLE              ((uint32_t)0x00000010)    /*!< Available.     */
/**
 *  @}
 */ /* End of group UART_RxInterrupt */
/** 
 *  @addtogroup UARTxDR  UARTxDR Register
 *  @brief    UARTxDR Register Definition.
 *  @{
 */
 /** 
 *  @addtogroup UART_ErrInterrupt  Err Interrpt
 *  @brief    Available Err Interrupt Macro Definisiton.
 *  @{
 */
#define UART_ERR_INT_ENABLE              ((uint32_t)0x00000004)    /*!< Available.     */
/**
 *  @}
 */ /* End of group UART_ErrInterrupt */
 
/* DR */
#define UARTxDR_DR_8BIT_MASK      ((uint32_t)0x000000FF)    /*!< DR     :Mask for 8bit */
/**
 *  @}
 */ /* End of group UARTxDR */
/** 
 *  @addtogroup UARTxSR  UARTxSR Register
 *  @brief    UARTxSR Register Definition.
 *  @{
 */
/* TXEND */
#define UARTxSR_TXEND_MASK        ((uint32_t)0x00004000)    /*!< TEXND :Mask.               */
#define UARTxSR_TXEND_R_END       ((uint32_t)0x00004000)    /*!< TXEND :[read]  Transfer done. */
#define UARTxSR_TXEND_W_CLEAR     ((uint32_t)0x00004000)    /*!< TXEND :[write] Clear Flag. */
/* TXFF */
#define UARTxSR_TXFF_MASK         ((uint32_t)0x00002000)    /*!< TXFF  :Mask.               */
#define UARTxSR_TXFF_R_REACHED    ((uint32_t)0x00002000)    /*!< TXFF  :[read]  Reached the transfer level. */
#define UARTxSR_TXFF_W_CLEAR      ((uint32_t)0x00002000)    /*!< TXFF  :[write] Clear Flag. */
/* TLVL */
#define UARTxSR_TLVL_MASK         ((uint32_t)0x00000F00)    /*!< TLVL  :Mask.               */
/* RXEND */
#define UARTxSR_RXEND_MASK        ((uint32_t)0x00000040)    /*!< RXEND :Mask.               */
#define UARTxSR_RXEND_R_END       ((uint32_t)0x00000040)    /*!< RXEND :[read]  Receive done. */
#define UARTxSR_RXEND_W_CLEAR     ((uint32_t)0x00000040)    /*!< RXEND :[write] Clear Flag. */
/* RXFF */
#define UARTxSR_RXFF_MASK         ((uint32_t)0x00000020)    /*!< RXFF  :Mask.               */
#define UARTxSR_RXFF_R_REACHED    ((uint32_t)0x00000020)    /*!< RXFF  :[read]  Receive done. */
#define UARTxSR_RXFF_W_CLEAR      ((uint32_t)0x00000020)    /*!< RXFF  :[write] Clear Flag. */
/* RLVL */
#define UARTxSR_RLVL_MASK         ((uint32_t)0x0000000F)    /*!< RLVL  :Mask.               */
/**
 *  @}
 */ /* End of group UARTxSR */
/** 
 *  @addtogroup UARTxERR  UARTxERR Register
 *  @brief    UARTxERR Register Definition.
 *  @{
 */
/* TRGERR */
#define UARTxERR_TRGERR_MASK      ((uint32_t)0x00000010)    /*!< TRGERR :Mask.               */
#define UARTxERR_TRGERR_R_ERR     ((uint32_t)0x00000010)    /*!< TRGERR :[read]  Error.      */
#define UARTxERR_TRGERR_W_CLEAR   ((uint32_t)0x00000010)    /*!< TRGERR :[write] Clear Flag. */
/* OVRERR */
#define UARTxERR_OVRERR_MASK      ((uint32_t)0x00000008)    /*!< OVRERR :Mask.               */
#define UARTxERR_OVRERR_R_ERR     ((uint32_t)0x00000008)    /*!< OVRERR :[read]  Error.      */
#define UARTxERR_OVRERR_W_CLEAR   ((uint32_t)0x00000008)    /*!< OVRERR :[write] Clear Flag. */
/* PERR */
#define UARTxERR_PERR_MASK        ((uint32_t)0x00000004)    /*!< PERR   :Mask.               */
#define UARTxERR_PERR_R_ERR       ((uint32_t)0x00000004)    /*!< PERR   :[read]  Error.      */
#define UARTxERR_PERR_W_CLEAR     ((uint32_t)0x00000004)    /*!< PERR   :[write] Clear Flag. */
/* FERR */
#define UARTxERR_FERR_MASK        ((uint32_t)0x00000002)    /*!< FERR   :Mask.               */
#define UARTxERR_FERR_R_ERR       ((uint32_t)0x00000002)    /*!< FERR   :[read]  Error.      */
#define UARTxERR_FERR_W_CLEAR     ((uint32_t)0x00000002)    /*!< FERR   :[write] Clear Flag. */
/* BERR */
#define UARTxERR_BERR_MASK        ((uint32_t)0x00000001)    /*!< BERR   :Mask.               */
#define UARTxERR_BERR_R_ERR       ((uint32_t)0x00000001)    /*!< BERR   :[read]  Error.      */
#define UARTxERR_BERR_W_CLEAR     ((uint32_t)0x00000001)    /*!< BERR   :[write] Clear Flag. */
/**
 *  @}
 */ /* End of group UARTxERR */
/** 
 *  @addtogroup UART_FifoMax  Max Num of FIFO
 *  @brief    Max Num of Tx/Rx Fifo.
 *  @{
 */
#define UART_TX_FIFO_MAX                ((uint32_t)0x00000008)    /*!< TX FIFO Max.   */
#define UART_RX_FIFO_MAX                ((uint32_t)0x00000008)    /*!< RX FIFO Max.   */
/**
 *  @}
 */ /* End of group UART_FifoMax */
/** 
 *  @addtogroup UART_Interrupt  UART Interrpt
 *  @brief    Available Transmit Interrupt Macro Definisiton.
 *  @{
 */
#define UART_INT_DISABLE             ((uint32_t)0x00000000)    /*!< Not Available. */
/**
 *  @}
 */ /* End of group UART_Interrupt */


/**
 *  @}
 */ /* End of group RDA_UART_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_enum RDA_UART Private Enum
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_UART_Private_enum */

/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_typedef RDA_UART Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_UART_Private_typedef */

/*------------------------------------------------------------------------------*/
/*  Variable Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_variable RDA_UART Private Variable
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group RDA_UART_Private_variable */

/*------------------------------------------------------------------------------*/
/*  Exported Function                                                           */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup RDA_UART_Private_fuctions RDA_UART Exported Fuctions
 *  @{
 */

/*--------------------------------------------------*/
/** 
  * @brief  UART_Configure(TRANS)
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void UART0_TX_Config(void)
{

    TSB_UART0->SWRST = 0x2U;
    TSB_UART0->SWRST = 0x1U;
  
    while( TSB_UART0->SWRST == 0x80 )
    {
    }
    /* oversampling by 115200 baud */
    /* Fsysme = 80MHz, KEN = 1:Enable, N+(64-K)/64 division K:0x2B N:0x2B */
    TSB_UART0->BRD = CFG_BAUDRATE_SET_VAL;
    TSB_UART0->CLK = (UART_PLESCALER_1 << 4);
    /* 8 data bit, 1 start bit, 1 stop bit, no parity */
    TSB_UART0->CR0 = (UART_DATA_DIRECTION_LSB | UART_STOP_BIT_1 | UART_PARITY_BIT_ODD | UART_PARITY_DISABLE | UART_DATA_LENGTH_8);
    /* Transmit interrupt Enable    */
    TSB_UART0->CR1 = (UART_TX_INT_ENABLE | UART_ERR_INT_ENABLE);

}

/*--------------------------------------------------*/
/** 
  * @brief  UART_TX_DMAC_Config(TRANS)
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void UART0_TX_DMAC_Config(void)
{

    TSB_UART0->SWRST = 0x2U;
    TSB_UART0->SWRST = 0x1U;

    while( TSB_UART0->SWRST == 0x80 )
    {
    }
    /* oversampling by 115200 baud */
    /* Fsysme = 80MHz, KEN = 1:Enable, N+(64-K)/64 division K:0x2B N:0x2B */
    TSB_UART0->BRD = CFG_BAUDRATE_SET_VAL;
    TSB_UART0->CLK = (UART_PLESCALER_1 << 4);
    /* 8 data bit, 1 start bit, 1 stop bit, no parity */
    TSB_UART0->CR0 = (UART_DATA_DIRECTION_LSB | UART_STOP_BIT_1 | UART_PARITY_BIT_ODD | UART_PARITY_DISABLE | UART_DATA_LENGTH_8);
    /* Transmit interrupt Enable    */
    TSB_UART0->CR1 = (UART_TX_DMATE| UART_ERR_INT_ENABLE);

}

/*--------------------------------------------------*/
/** 
  * @brief  UART_Configure(RECEIVE)
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void UART0_RX_Config(void)
{

    TSB_UART0->SWRST = 0x2U;
    TSB_UART0->SWRST = 0x1U;

    while( TSB_UART0->SWRST == 0x80 )
    {
    }
    /* oversampling by 115200 baud */
    /* Fsysme = 80MHz, KEN = 1:Enable, N+(64-K)/64 division K:0x2B N:0x2B */
    TSB_UART0->BRD = CFG_BAUDRATE_SET_VAL;
    TSB_UART0->CLK = (UART_PLESCALER_1 << 4);
    /* 8 data bit, 1 start bit, 1 stop bit, no parity */
    TSB_UART0->CR0 = (UART_DATA_DIRECTION_LSB | UART_STOP_BIT_1 | UART_PARITY_BIT_ODD | UART_PARITY_DISABLE | UART_DATA_LENGTH_8);
    /* Reception interrupt Enable    */
    TSB_UART0->CR1 = (UART_RX_INT_ENABLE|UART_ERR_INT_ENABLE);
    enable_UART0_RXE();

}

/*--------------------------------------------------*/
/** 
  * @brief  UART_RX_DMAC_Config(RECEIVE)
  * @param  -
  * @return -
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void UART0_RX_DMAC_Config(void)
{

    TSB_UART0->SWRST = 0x2U;
    TSB_UART0->SWRST = 0x1U;

    while( TSB_UART0->SWRST == 0x80 )
    {
    }
    /* oversampling by 115200 baud */
    /* Fsysme = 80MHz, KEN = 1:Enable, N+(64-K)/64 division K:0x2B N:0x2B */
    TSB_UART0->BRD = CFG_BAUDRATE_SET_VAL;
    TSB_UART0->CLK = (UART_PLESCALER_1 << 4);
    /* 8 data bit, 1 start bit, 1 stop bit, no parity */
    TSB_UART0->CR0 = (UART_DATA_DIRECTION_LSB | UART_STOP_BIT_1 | UART_PARITY_BIT_ODD | UART_PARITY_DISABLE | UART_DATA_LENGTH_8);
    /* Transmit interrupt Enable    */
    TSB_UART0->CR1 = (UART_RX_DMARE|UART_ERR_INT_ENABLE);
    /*--- UARTxTRANS ---*/
    /* Write to RXE(=1). */
    enable_UART0_RXE();

}

/*--------------------------------------------------*/
/** 
  * @brief  Disable UART0 TXE.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void disable_UART0_TXE(void)
{
    TSB_UART0_TRANS_TXE = 0;
}

/*--------------------------------------------------*/
/** 
  * @brief  Enable UART0 TXE.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void enable_UART0_TXE(void)
{
    TSB_UART0_TRANS_TXE = 1;
}

/*--------------------------------------------------*/
/** 
  * @brief  Disable UART0 RXE.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void disable_UART0_RXE(void)
{
    TSB_UART0_TRANS_RXE = 0;
}

/*--------------------------------------------------*/
/** 
  * @brief  Enable UART0 RXE.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void enable_UART0_RXE(void)
{
    TSB_UART0_TRANS_RXE = 1;
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_param_UART0_TXRUN.
  * @param  -
  * @retval TSB_UART0_SR_TXRUN
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
bool Get_param_UART0_TXRUN(void)
{
    return (TSB_UART0_SR_TXRUN);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_param_UART0_RXRUN.
  * @param  -
  * @retval TSB_UART0_SR_RXRUN
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
bool Get_param_UART0_RXRUN(void)
{
    return (TSB_UART0_SR_RXRUN);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_UART0_DR_value.
  * @param  -
  * @retval TSB_UART0->DR[7:0]
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
uint32_t Get_UART0_DR_value(void)
{
    /* CR0_SM = 8bit length */
    return (TSB_UART0->DR & 0x000000FF);
}

/*--------------------------------------------------*/
/** 
  * @brief  Set_UART0_DR_value.
  * @param  value (use [7:0])
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Set_UART0_DR_value(uint32_t value)
{
    /* CR0_SM = 8bit length */
    TSB_UART0->DR = (value & 0x000000FF);
}

/*--------------------------------------------------*/
/** 
  * @brief  Clear_flag_UART0_TXEND.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Clear_flag_UART0_TXEND(void)
{
    TSB_UART0_SR_TXFF = 1;
    TSB_UART0_SR_TXEND = 1;
}

/*--------------------------------------------------*/
/** 
  * @brief  Clear_flag_UART0_RXEND.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Clear_flag_UART0_RXEND(void)
{
    TSB_UART0_SR_RXFF = 1;
    TSB_UART0_SR_RXEND = 1;
}

/*--------------------------------------------------*/
/** 
  * @brief  Clear_allflag_UART0_ERR.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Clear_allflag_UART0_ERR(void)
{
    /* UART0 ERR flag All Clear */
    TSB_UART0->ERR |= 0x0000001F;
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_UART0_Fill_level.
  * @param  -
  * @retval TSB_UART0->SR[3:0]
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
uint32_t Get_UART0_Fill_level(void)
{
    return (TSB_UART0->SR & 0x0000000F);
}

/*--------------------------------------------------*/
/** 
  * @brief  Get_param_UART0_OVRERR.
  * @param  -
  * @retval TSB_UART0_ERR_OVRERR
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
bool Get_param_UART0_OVRERR(void)
{
    return (TSB_UART0_ERR_OVRERR);
}
/*--------------------------------------------------*/
/** 
  * @brief  Clear_flag_UART0_OVRERR.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Clear_flag_UART0_OVRERR(void)
{
    TSB_UART0_ERR_OVRERR = 1;
}


/* Self-Diagnosis */
/*--------------------------------------------------*/
/** 
  * @brief  UART0test_Config.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void UART0test_Config(void)
{

    /* Software Reset */
    TSB_UART0->SWRST = 0x2U;
    TSB_UART0->SWRST = 0x1U;
    while( TSB_UART0->SWRST == 0x80 )
    {
    }

    /* oversampling by 115200 baud */
    /*  Fsysme = 80MHz, KEN = 1:Enable, N+(64-K)/64 division K:0x2B N:0x2B */
    TSB_UART0->BRD = CFG_BAUDRATE_SET_VAL;
    TSB_UART0->CLK = (UART_PLESCALER_1 << 4);

    /* 8 data bit, 1 start bit, 1 stop bit, no parity */
    TSB_UART0->CR0 = (UART_DATA_DIRECTION_LSB | UART_STOP_BIT_1 | UART_PARITY_BIT_ODD | \
                      UART_PARITY_DISABLE | UART_DATA_LENGTH_8);
    TSB_UART0->TRANS = (UART_TXE_ENABLE | UART_RXE_ENABLE);

    /* Transmit interrupt Enable    */
    TSB_UART0->CR1 = (UART_TX_INT_ENABLE | UART_RX_INT_ENABLE);

}

/*--------------------------------------------------*/
/** 
  * @brief  UART0test_disable_INT.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void UART0test_disable_INT(void)
{
    TSB_UART0->CR1 = (UART_INT_DISABLE);

}
/*--------------------------------------------------*/
/** 
  * @brief  Set_param_UART0_LPB.
  * @param  -
  * @retval -
  * @note   Bitband Access
  */
/*--------------------------------------------------*/
void Set_param_UART0_LPB(void)
{
    TSB_UART0->CR0 |= (1 << 15);  /* set LPB (bit15) */

}


/**
 *  @}
 */ /* End of group RDA_UART_Exported_functions */

/**
 *  @} 
 */ /* End of group RDA_UART */

/**
 *  @} 
 */ /* End of group Periph_Driver */

#endif /* defined(__UART_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

