/** 
 *******************************************************************************
 * @file    uart_io.h
 * @brief   External reference declaration for Uart(USB-UART) Input/Output.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */
/*------------------------------------------------------------------------------*/
/*  Define to prevent recursive inclusion                                       */
/*------------------------------------------------------------------------------*/
#ifndef __UART_IO_H
#define __UART_IO_H

#include "TSB_CMSIS_CORE.h"
#include "driver_com.h"
#ifdef __cplusplus
extern "C" {
#endif

/**
 *  @addtogroup UTILITY UTILITY
 *  @{
 */
/** 
 *  @addtogroup UART_IO
 *  @brief    UART_IO Driver.
 *  @{
 */

/** 
 *  @addtogroup UART_IO_Exported_define
 *  @{
 */
#define BSP_UART_USB            TSB_UART0

#define UART_IO_SEND_MAX       ((uint32_t)32)   /*!< Size of send max. (byte)    */
#define UART_IO_RECEIVE_MAX    ((uint32_t)32)   /*!< Size of receive max. (byte) */
/** 
 *  @}
 */ /* End of group UART_IO_Exported_define */


/*------------------------------------------------------------------------------*/
/*  Functions                                                                   */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup UART_IO_fuction
 *  @{
 */
void uart_io_initialize(void);
void uart_io_finalize(void);
int  uart_io_put_char(int c);
int  uart_io_get_char(void);

/**
 *  @}
 */ /* End of group UART_IO_function */

/**
 *  @}
 */ /* End of group UART_IO */

/**
 *  @}
 */ /* End of group UTILITY */
#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __UART_IO_H */

