/**
 *******************************************************************************
 * @file    sys_timer.c
 * @brief   This file provides API functions for driver common part.\n
 * @version V1.0.0
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2020
 *******************************************************************************
 */

#ifdef __cplusplus
 extern "C" {
#endif

/*------------------------------------------------------------------------------*/
/*  Includes                                                                    */
/*------------------------------------------------------------------------------*/
#include "sys_timer.h"

#if defined(__SYS_TIMER_H)
/**
 *  @addtogroup UTILITY UTILITY
 *  @{
 */

/** 
 *  @addtogroup SYS_TIMER
 *  @{
 */

/*------------------------------------------------------------------------------*/
/*  Macro Function                                                              */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_macro SYS_TIMER Private Macro
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SYS_TIMER_Private_macro */


/*------------------------------------------------------------------------------*/
/*  Configuration                                                               */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_define SYS_TIMER Private Define
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SYS_TIMER_Private_define */


/*------------------------------------------------------------------------------*/
/*  Macro Definition                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_define SYS_TIMER Private Define
 *  @{
 */
/** 
 *  @addtogroup wait Configuration
 *  @brief    wait Configuration.
 *  @{
 */
#define WAIT_UNIT_1US          ((uint32_t)(1000000))     /*!< 1S-1us transfor unit.   */
#define WAIT_FORLOOP_STEPS     ((uint32_t)(5))           /*!< for loop steps.         */
/** 
 *  @}
 */ /* End of group waitConfiguration */
 
/* no define */

/** 
 *  @}
 */ /* End of group SYS_TIMER_Private_define */


/*------------------------------------------------------------------------------*/
/*  Enumerated Type Definition                                                  */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_define SYS_TIMER Private Define
 *  @{
 */

/* no define */

/** 
 *  @}
 */ /* End of group SYS_TIMER_Private_define */


/*------------------------------------------------------------------------------*/
/*  Structure Definition                                                        */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_typedef SYS_TIMER Private Typedef
 *  @{
 */

/* no define */

/**
 *  @}
 */ /* End of group SYS_TIMER_Private_typedef */


/*------------------------------------------------------------------------------*/
/*  Private Function                                                            */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Private_fuctions SYS_TIMER Private Fuctions
 *  @{
 */


/**
 *  @}
 */ /* End of group SYS_TIMER_Private_functions */

/*------------------------------------------------------------------------------*/
/*  Public Function                                                             */
/*------------------------------------------------------------------------------*/
/** 
 *  @addtogroup SYS_TIMER_Exported_functions
 *  @{
 */
/*--------------------------------------------------*/
/** 
  * @brief  wait Function(us)
  * @param  uint32_t :count(unit:us).
  * @return void
  * @retval -
  * @note   -
  */
/*--------------------------------------------------*/
void wait(uint32_t count)
{
    uint32_t i,steps;

    /*-----------------------------------------*/
    /* step : 1000000us = fsys :1              */
    /* step = EOSC_SYS_CLOCK/1000000           */
    /*-----------------------------------------*/
    /* system core clock update */
    SystemCoreClockUpdate();
    steps = count * (SystemCoreClock / WAIT_UNIT_1US) / WAIT_FORLOOP_STEPS;

    for( i = 0; i < steps; ++i)
    {
        __NOP();
    }
}

/**
 *  @}
 */ /* End of group SYS_TIMER_Exported_functions */

/**
 *  @} 
 */ /* End of group SYS_TIMER */

/**
 *  @} 
 */ /* End of group UTILITY */

#endif /* defined(__SYS_TIMER_H)  */

#ifdef __cplusplus
}
#endif /* __cplusplus */

